Class: Google::Apis::NetworkconnectivityV1::AcceptSpokeUpdateRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

The request for HubService.AcceptSpokeUpdate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AcceptSpokeUpdateRequest

Returns a new instance of AcceptSpokeUpdateRequest.



112
113
114
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 112

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#request_idString

Optional. A request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server knows to ignore the request if it has already been completed. The server guarantees that a request doesn't result in creation of duplicate commitments for at least 60 minutes. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check to see whether the original operation was received. If it was, the server ignores the second request. This behavior prevents clients from mistakenly creating duplicate commitments. The request ID must be a valid UUID, with the exception that zero UUID is not supported (00000000-0000-0000-0000- 000000000000). Corresponds to the JSON property requestId

Returns:

  • (String)


100
101
102
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 100

def request_id
  @request_id
end

#spoke_etagString

Required. The etag of the spoke to accept update. Corresponds to the JSON property spokeEtag

Returns:

  • (String)


105
106
107
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 105

def spoke_etag
  @spoke_etag
end

#spoke_uriString

Required. The URI of the spoke to accept update. Corresponds to the JSON property spokeUri

Returns:

  • (String)


110
111
112
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 110

def spoke_uri
  @spoke_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



117
118
119
120
121
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 117

def update!(**args)
  @request_id = args[:request_id] if args.key?(:request_id)
  @spoke_etag = args[:spoke_etag] if args.key?(:spoke_etag)
  @spoke_uri = args[:spoke_uri] if args.key?(:spoke_uri)
end