Class: Google::Apis::NetworkconnectivityV1::AllocationOptions
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::AllocationOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
Range auto-allocation options, to be optionally used when CIDR block is not explicitly set.
Instance Attribute Summary collapse
-
#allocation_strategy ⇒ String
Optional.
-
#first_available_ranges_lookup_size ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AllocationOptions
constructor
A new instance of AllocationOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AllocationOptions
Returns a new instance of AllocationOptions.
142 143 144 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 142 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allocation_strategy ⇒ String
Optional. Allocation strategy Not setting this field when the allocation is
requested means an implementation defined strategy is used.
Corresponds to the JSON property allocationStrategy
133 134 135 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 133 def allocation_strategy @allocation_strategy end |
#first_available_ranges_lookup_size ⇒ Fixnum
Optional. This field must be set only when allocation_strategy is set to
RANDOM_FIRST_N_AVAILABLE. The value should be the maximum expected parallelism
of range creation requests issued to the same space of peered netwroks.
Corresponds to the JSON property firstAvailableRangesLookupSize
140 141 142 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 140 def first_available_ranges_lookup_size @first_available_ranges_lookup_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
147 148 149 150 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 147 def update!(**args) @allocation_strategy = args[:allocation_strategy] if args.key?(:allocation_strategy) @first_available_ranges_lookup_size = args[:first_available_ranges_lookup_size] if args.key?(:first_available_ranges_lookup_size) end |