Class: Google::Apis::NetworkconnectivityV1::AutoAccept

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

The auto-accept setting for a group controls whether proposed spokes are automatically attached to the hub. If auto-accept is enabled, the spoke immediately is attached to the hub and becomes part of the group. In this case, the new spoke is in the ACTIVE state. If auto-accept is disabled, the spoke goes to the INACTIVE state, and it must be reviewed and accepted by a hub administrator.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutoAccept

Returns a new instance of AutoAccept.



240
241
242
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 240

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_accept_projectsArray<String>

Optional. A list of project ids or project numbers for which you want to enable auto-accept. The auto-accept setting is applied to spokes being created or updated in these projects. Corresponds to the JSON property autoAcceptProjects

Returns:

  • (Array<String>)


238
239
240
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 238

def auto_accept_projects
  @auto_accept_projects
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



245
246
247
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 245

def update!(**args)
  @auto_accept_projects = args[:auto_accept_projects] if args.key?(:auto_accept_projects)
end