Class: Google::Apis::NetworkconnectivityV1::AutoCreatedSubnetworkInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

Information for the automatically created subnetwork and its associated IR.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutoCreatedSubnetworkInfo

Returns a new instance of AutoCreatedSubnetworkInfo.



286
287
288
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 286

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#delinkedBoolean Also known as: delinked?

Output only. Indicates whether the subnetwork is delinked from the Service Connection Policy. Only set if the subnetwork mode is AUTO_CREATED during creation. Corresponds to the JSON property delinked

Returns:

  • (Boolean)


259
260
261
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 259

def delinked
  @delinked
end

#internal_rangeString

Output only. URI of the automatically created Internal Range. Only set if the subnetwork mode is AUTO_CREATED during creation. Corresponds to the JSON property internalRange

Returns:

  • (String)


266
267
268
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 266

def internal_range
  @internal_range
end

#internal_range_refString

Output only. URI of the automatically created Internal Range reference. Only set if the subnetwork mode is AUTO_CREATED during creation. Corresponds to the JSON property internalRangeRef

Returns:

  • (String)


272
273
274
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 272

def internal_range_ref
  @internal_range_ref
end

#subnetworkString

Output only. URI of the automatically created subnetwork. Only set if the subnetwork mode is AUTO_CREATED during creation. Corresponds to the JSON property subnetwork

Returns:

  • (String)


278
279
280
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 278

def subnetwork
  @subnetwork
end

#subnetwork_refString

Output only. URI of the automatically created subnetwork reference. Only set if the subnetwork mode is AUTO_CREATED during creation. Corresponds to the JSON property subnetworkRef

Returns:

  • (String)


284
285
286
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 284

def subnetwork_ref
  @subnetwork_ref
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



291
292
293
294
295
296
297
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 291

def update!(**args)
  @delinked = args[:delinked] if args.key?(:delinked)
  @internal_range = args[:internal_range] if args.key?(:internal_range)
  @internal_range_ref = args[:internal_range_ref] if args.key?(:internal_range_ref)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
  @subnetwork_ref = args[:subnetwork_ref] if args.key?(:subnetwork_ref)
end