Class: Google::Apis::NetworkconnectivityV1::AutomatedDnsRecord

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

Represents a DNS record managed by the AutomatedDnsRecord API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutomatedDnsRecord

Returns a new instance of AutomatedDnsRecord.



450
451
452
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 450

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumer_networkString

Required. Immutable. The full resource path of the consumer network this AutomatedDnsRecord is visible to. Example: "projects/projectNumOrId/global/ networks/networkName". Corresponds to the JSON property consumerNetwork

Returns:

  • (String)


347
348
349
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 347

def consumer_network
  @consumer_network
end

#create_timeString

Output only. The timestamp of when the record was created. Corresponds to the JSON property createTime

Returns:

  • (String)


352
353
354
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 352

def create_time
  @create_time
end

#creation_modeString

Required. Immutable. The creation mode of the AutomatedDnsRecord. This field is immutable. Corresponds to the JSON property creationMode

Returns:

  • (String)


358
359
360
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 358

def creation_mode
  @creation_mode
end

#current_configGoogle::Apis::NetworkconnectivityV1::Config

Defines the configuration of a DNS record. Corresponds to the JSON property currentConfig



363
364
365
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 363

def current_config
  @current_config
end

#descriptionString

A human-readable description of the record. Corresponds to the JSON property description

Returns:

  • (String)


368
369
370
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 368

def description
  @description
end

#dns_suffixString

Required. Immutable. The dns suffix for this record to use in longest-suffix matching. Requires a trailing dot. Example: "example.com." Corresponds to the JSON property dnsSuffix

Returns:

  • (String)


374
375
376
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 374

def dns_suffix
  @dns_suffix
end

#dns_zoneString

Output only. DnsZone is the DNS zone managed by automation. Format: projects/ project/managedZones/managedZone Corresponds to the JSON property dnsZone

Returns:

  • (String)


380
381
382
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 380

def dns_zone
  @dns_zone
end

#etagString

Optional. The etag is computed by the server, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


386
387
388
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 386

def etag
  @etag
end

#fqdnString

Output only. The FQDN created by combining the hostname and dns suffix. Should include a trailing dot. Corresponds to the JSON property fqdn

Returns:

  • (String)


392
393
394
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 392

def fqdn
  @fqdn
end

#hostnameString

Required. Immutable. The hostname for the DNS record. This value will be prepended to the dns_suffix to create the full domain name (FQDN) for the record. For example, if hostname is "corp.db" and dns_suffix is "example. com.", the resulting record will be "corp.db.example.com.". Should not include a trailing dot. Corresponds to the JSON property hostname

Returns:

  • (String)


401
402
403
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 401

def hostname
  @hostname
end

#labelsHash<String,String>

Optional. User-defined labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


406
407
408
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 406

def labels
  @labels
end

#nameString

Immutable. Identifier. The name of an AutomatedDnsRecord. Format: projects/ project/locations/location/automatedDnsRecords/automated_dns_record See: https://google.aip.dev/122#fields-representing-resource-names Corresponds to the JSON property name

Returns:

  • (String)


413
414
415
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 413

def name
  @name
end

#original_configGoogle::Apis::NetworkconnectivityV1::Config

Defines the configuration of a DNS record. Corresponds to the JSON property originalConfig



418
419
420
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 418

def original_config
  @original_config
end

#record_typeString

Required. Immutable. The identifier of a supported record type. Corresponds to the JSON property recordType

Returns:

  • (String)


423
424
425
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 423

def record_type
  @record_type
end

#service_classString

Required. Immutable. The service class identifier which authorizes this AutomatedDnsRecord. Any API calls targeting this AutomatedDnsRecord must have networkconnectivity.serviceclasses.use IAM permission for the provided service class. Corresponds to the JSON property serviceClass

Returns:

  • (String)


431
432
433
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 431

def service_class
  @service_class
end

#stateString

Output only. The current operational state of this AutomatedDnsRecord as managed by Service Connectivity Automation. Corresponds to the JSON property state

Returns:

  • (String)


437
438
439
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 437

def state
  @state
end

#state_detailsString

Output only. A human-readable message providing more context about the current state, such as an error description if the state is FAILED_DEPROGRAMMING. Corresponds to the JSON property stateDetails

Returns:

  • (String)


443
444
445
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 443

def state_details
  @state_details
end

#update_timeString

Output only. The timestamp of when the record was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


448
449
450
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 448

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 455

def update!(**args)
  @consumer_network = args[:consumer_network] if args.key?(:consumer_network)
  @create_time = args[:create_time] if args.key?(:create_time)
  @creation_mode = args[:creation_mode] if args.key?(:creation_mode)
  @current_config = args[:current_config] if args.key?(:current_config)
  @description = args[:description] if args.key?(:description)
  @dns_suffix = args[:dns_suffix] if args.key?(:dns_suffix)
  @dns_zone = args[:dns_zone] if args.key?(:dns_zone)
  @etag = args[:etag] if args.key?(:etag)
  @fqdn = args[:fqdn] if args.key?(:fqdn)
  @hostname = args[:hostname] if args.key?(:hostname)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @original_config = args[:original_config] if args.key?(:original_config)
  @record_type = args[:record_type] if args.key?(:record_type)
  @service_class = args[:service_class] if args.key?(:service_class)
  @state = args[:state] if args.key?(:state)
  @state_details = args[:state_details] if args.key?(:state_details)
  @update_time = args[:update_time] if args.key?(:update_time)
end