Class: Google::Apis::NetworkconnectivityV1::Config

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

Defines the configuration of a DNS record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Config

Returns a new instance of Config.



655
656
657
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 655

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#rrdatasArray<String>

Required. The list of resource record data strings. The content and format of these strings depend on the AutomatedDnsRecord.type. For many common record types, this list may contain multiple strings. As defined in RFC 1035 (section 5) and RFC 1034 (section 3.6.1) -- see examples. Examples: A record: ["192.0.2. 1"] or ["192.0.2.1", "192.0.2.2"] TXT record: ["This is a text record"] CNAME record: ["target.example.com."] AAAA record: ["::1"] or ["2001:0db8:85a3:0000: 0000:8a2e:0370:7334", "2001:0db8:85a3:0000:0000:8a2e:0370:7335"] Corresponds to the JSON property rrdatas

Returns:

  • (Array<String>)


648
649
650
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 648

def rrdatas
  @rrdatas
end

#ttlString

Required. Number of seconds that this DNS record can be cached by resolvers. Corresponds to the JSON property ttl

Returns:

  • (String)


653
654
655
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 653

def ttl
  @ttl
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



660
661
662
663
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 660

def update!(**args)
  @rrdatas = args[:rrdatas] if args.key?(:rrdatas)
  @ttl = args[:ttl] if args.key?(:ttl)
end