Class: Google::Apis::NetworkconnectivityV1::DnsAutomationStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

The status of DNS automation for a PSC connection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DnsAutomationStatus

Returns a new instance of DnsAutomationStatus.



1021
1022
1023
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1021

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::NetworkconnectivityV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



1009
1010
1011
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1009

def error
  @error
end

#fqdnString

Output only. The fully qualified domain name of the DNS record. Corresponds to the JSON property fqdn

Returns:

  • (String)


1014
1015
1016
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1014

def fqdn
  @fqdn
end

#stateString

Output only. The current state of DNS automation. Corresponds to the JSON property state

Returns:

  • (String)


1019
1020
1021
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1019

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1026
1027
1028
1029
1030
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1026

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @fqdn = args[:fqdn] if args.key?(:fqdn)
  @state = args[:state] if args.key?(:state)
end