Class: Google::Apis::NetworkconnectivityV1::GoogleRpcStatus
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::GoogleRpcStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Instance Attribute Summary collapse
-
#code ⇒ Fixnum
The status code, which should be an enum value of google.rpc.Code.
-
#details ⇒ Array<Hash<String,Object>>
A list of messages that carry the error details.
-
#message ⇒ String
A developer-facing error message, which should be in English.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleRpcStatus
constructor
A new instance of GoogleRpcStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleRpcStatus
Returns a new instance of GoogleRpcStatus.
1334 1335 1336 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1334 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ Fixnum
The status code, which should be an enum value of google.rpc.Code.
Corresponds to the JSON property code
1319 1320 1321 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1319 def code @code end |
#details ⇒ Array<Hash<String,Object>>
A list of messages that carry the error details. There is a common set of
message types for APIs to use.
Corresponds to the JSON property details
1325 1326 1327 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1325 def details @details end |
#message ⇒ String
A developer-facing error message, which should be in English. Any user-facing
error message should be localized and sent in the google.rpc.Status.details
field, or localized by the client.
Corresponds to the JSON property message
1332 1333 1334 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1332 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1339 1340 1341 1342 1343 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1339 def update!(**args) @code = args[:code] if args.key?(:code) @details = args[:details] if args.key?(:details) @message = args[:message] if args.key?(:message) end |