Class: Google::Apis::NetworkconnectivityV1::Group

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

A group represents a subset of spokes attached to a hub.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Group

Returns a new instance of Group.



1408
1409
1410
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1408

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_acceptGoogle::Apis::NetworkconnectivityV1::AutoAccept

The auto-accept setting for a group controls whether proposed spokes are automatically attached to the hub. If auto-accept is enabled, the spoke immediately is attached to the hub and becomes part of the group. In this case, the new spoke is in the ACTIVE state. If auto-accept is disabled, the spoke goes to the INACTIVE state, and it must be reviewed and accepted by a hub administrator. Corresponds to the JSON property autoAccept



1358
1359
1360
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1358

def auto_accept
  @auto_accept
end

#create_timeString

Output only. The time the group was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1363
1364
1365
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1363

def create_time
  @create_time
end

#descriptionString

Optional. The description of the group. Corresponds to the JSON property description

Returns:

  • (String)


1368
1369
1370
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1368

def description
  @description
end

#labelsHash<String,String>

Optional. Labels in key-value pair format. For more information about labels, see Requirements for labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1375
1376
1377
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1375

def labels
  @labels
end

#nameString

Immutable. The name of the group. Group names must be unique. They use the following form: projects/project_number/locations/global/hubs/hub/groups/ group_id` Corresponds to the JSON propertyname`

Returns:

  • (String)


1382
1383
1384
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1382

def name
  @name
end

#route_tableString

Output only. The name of the route table that corresponds to this group. They use the following form: projects/project_number/locations/global/hubs/ hub_id/routeTables/route_table_id` Corresponds to the JSON propertyrouteTable`

Returns:

  • (String)


1389
1390
1391
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1389

def route_table
  @route_table
end

#stateString

Output only. The current lifecycle state of this group. Corresponds to the JSON property state

Returns:

  • (String)


1394
1395
1396
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1394

def state
  @state
end

#uidString

Output only. The Google-generated UUID for the group. This value is unique across all group resources. If a group is deleted and another with the same name is created, the new route table is assigned a different unique_id. Corresponds to the JSON property uid

Returns:

  • (String)


1401
1402
1403
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1401

def uid
  @uid
end

#update_timeString

Output only. The time the group was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1406
1407
1408
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1406

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
1423
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1413

def update!(**args)
  @auto_accept = args[:auto_accept] if args.key?(:auto_accept)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @route_table = args[:route_table] if args.key?(:route_table)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end