Class: Google::Apis::NetworkconnectivityV1::IpRangeReservation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

A list of IP ranges that are reserved for this gateway's internal intfrastructure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IpRangeReservation

Returns a new instance of IpRangeReservation.



1888
1889
1890
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1888

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_rangeString

Required. A block of IP addresses used to allocate supporting infrastructure for this gateway. This block must not overlap with subnets in any spokes or peer VPC networks that the gateway can communicate with. Example: "10.1.2.0/24" Corresponds to the JSON property ipRange

Returns:

  • (String)


1886
1887
1888
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1886

def ip_range
  @ip_range
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1893
1894
1895
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1893

def update!(**args)
  @ip_range = args[:ip_range] if args.key?(:ip_range)
end