Class: Google::Apis::NetworkconnectivityV1::LinkedVpcNetwork

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

An existing VPC network.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LinkedVpcNetwork

Returns a new instance of LinkedVpcNetwork.



2139
2140
2141
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2139

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exclude_export_rangesArray<String>

Optional. IP ranges encompassing the subnets to be excluded from peering. Corresponds to the JSON property excludeExportRanges

Returns:

  • (Array<String>)


2104
2105
2106
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2104

def exclude_export_ranges
  @exclude_export_ranges
end

#include_export_rangesArray<String>

Optional. IP ranges allowed to be included from peering. Corresponds to the JSON property includeExportRanges

Returns:

  • (Array<String>)


2109
2110
2111
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2109

def include_export_ranges
  @include_export_ranges
end

#producer_vpc_spokesArray<String>

Output only. The list of Producer VPC spokes that this VPC spoke is a service consumer VPC spoke for. These producer VPCs are connected through VPC peering to this spoke's backing VPC network. Because they are directly connected through VPC peering, NCC export filters do not apply between the service consumer VPC spoke and any of its producer VPC spokes. This VPC spoke cannot be deleted as long as any of these producer VPC spokes are connected to the NCC Hub. Corresponds to the JSON property producerVpcSpokes

Returns:

  • (Array<String>)


2120
2121
2122
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2120

def producer_vpc_spokes
  @producer_vpc_spokes
end

#proposed_exclude_export_rangesArray<String>

Output only. The proposed exclude export IP ranges waiting for hub administrator's approval. Corresponds to the JSON property proposedExcludeExportRanges

Returns:

  • (Array<String>)


2126
2127
2128
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2126

def proposed_exclude_export_ranges
  @proposed_exclude_export_ranges
end

#proposed_include_export_rangesArray<String>

Output only. The proposed include export IP ranges waiting for hub administrator's approval. Corresponds to the JSON property proposedIncludeExportRanges

Returns:

  • (Array<String>)


2132
2133
2134
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2132

def proposed_include_export_ranges
  @proposed_include_export_ranges
end

#uriString

Required. The URI of the VPC network resource. Corresponds to the JSON property uri

Returns:

  • (String)


2137
2138
2139
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2137

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2144
2145
2146
2147
2148
2149
2150
2151
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2144

def update!(**args)
  @exclude_export_ranges = args[:exclude_export_ranges] if args.key?(:exclude_export_ranges)
  @include_export_ranges = args[:include_export_ranges] if args.key?(:include_export_ranges)
  @producer_vpc_spokes = args[:producer_vpc_spokes] if args.key?(:producer_vpc_spokes)
  @proposed_exclude_export_ranges = args[:proposed_exclude_export_ranges] if args.key?(:proposed_exclude_export_ranges)
  @proposed_include_export_ranges = args[:proposed_include_export_ranges] if args.key?(:proposed_include_export_ranges)
  @uri = args[:uri] if args.key?(:uri)
end