Class: Google::Apis::NetworkconnectivityV1::LinkedVpnTunnels
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::LinkedVpnTunnels
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
A collection of Cloud VPN tunnel resources. These resources should be redundant HA VPN tunnels that all advertise the same prefixes to Google Cloud. Alternatively, in a passive/active configuration, all tunnels should be capable of advertising the same prefixes.
Instance Attribute Summary collapse
-
#exclude_export_ranges ⇒ Array<String>
Optional.
-
#exclude_import_ranges ⇒ Array<String>
Optional.
-
#include_export_ranges ⇒ Array<String>
Optional.
-
#include_import_ranges ⇒ Array<String>
Optional.
-
#site_to_site_data_transfer ⇒ Boolean
(also: #site_to_site_data_transfer?)
A value that controls whether site-to-site data transfer is enabled for these resources.
-
#uris ⇒ Array<String>
The URIs of linked VPN tunnel resources.
-
#vpc_network ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LinkedVpnTunnels
constructor
A new instance of LinkedVpnTunnels.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LinkedVpnTunnels
Returns a new instance of LinkedVpnTunnels.
2204 2205 2206 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2204 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exclude_export_ranges ⇒ Array<String>
Optional. Dynamic routes overlapped/encompassed by exclude export ranges are
excluded during export to hub.
Corresponds to the JSON property excludeExportRanges
2165 2166 2167 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2165 def exclude_export_ranges @exclude_export_ranges end |
#exclude_import_ranges ⇒ Array<String>
Optional. Hub routes overlapped/encompassed by exclude import ranges are
excluded during import from hub.
Corresponds to the JSON property excludeImportRanges
2171 2172 2173 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2171 def exclude_import_ranges @exclude_import_ranges end |
#include_export_ranges ⇒ Array<String>
Optional. Dynamic routes fully encompassed by include export ranges are
included during export to hub.
Corresponds to the JSON property includeExportRanges
2177 2178 2179 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2177 def include_export_ranges @include_export_ranges end |
#include_import_ranges ⇒ Array<String>
Optional. Hub routes fully encompassed by include import ranges are included
during import from hub.
Corresponds to the JSON property includeImportRanges
2183 2184 2185 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2183 def include_import_ranges @include_import_ranges end |
#site_to_site_data_transfer ⇒ Boolean Also known as: site_to_site_data_transfer?
A value that controls whether site-to-site data transfer is enabled for these
resources. Data transfer is available only in supported locations.
Corresponds to the JSON property siteToSiteDataTransfer
2191 2192 2193 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2191 def site_to_site_data_transfer @site_to_site_data_transfer end |
#uris ⇒ Array<String>
The URIs of linked VPN tunnel resources.
Corresponds to the JSON property uris
2197 2198 2199 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2197 def uris @uris end |
#vpc_network ⇒ String
Output only. The VPC network where these VPN tunnels are located.
Corresponds to the JSON property vpcNetwork
2202 2203 2204 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2202 def vpc_network @vpc_network end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2209 2210 2211 2212 2213 2214 2215 2216 2217 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2209 def update!(**args) @exclude_export_ranges = args[:exclude_export_ranges] if args.key?(:exclude_export_ranges) @exclude_import_ranges = args[:exclude_import_ranges] if args.key?(:exclude_import_ranges) @include_export_ranges = args[:include_export_ranges] if args.key?(:include_export_ranges) @include_import_ranges = args[:include_import_ranges] if args.key?(:include_import_ranges) @site_to_site_data_transfer = args[:site_to_site_data_transfer] if args.key?(:site_to_site_data_transfer) @uris = args[:uris] if args.key?(:uris) @vpc_network = args[:vpc_network] if args.key?(:vpc_network) end |