Class: Google::Apis::NetworkconnectivityV1::ListGroupsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

Response for HubService.ListGroups method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListGroupsResponse

Returns a new instance of ListGroupsResponse.



2337
2338
2339
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2337

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#groupsArray<Google::Apis::NetworkconnectivityV1::Group>

The requested groups. Corresponds to the JSON property groups



2323
2324
2325
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2323

def groups
  @groups
end

#next_page_tokenString

The token for the next page of the response. To see more results, use this value as the page_token for your next request. If this value is empty, there are no more results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2330
2331
2332
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2330

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Hubs that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2335
2336
2337
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2335

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2342
2343
2344
2345
2346
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2342

def update!(**args)
  @groups = args[:groups] if args.key?(:groups)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end