Class: Google::Apis::NetworkconnectivityV1::ListHubsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::ListHubsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
Response for HubService.ListHubs method.
Instance Attribute Summary collapse
-
#hubs ⇒ Array<Google::Apis::NetworkconnectivityV1::Hub>
The requested hubs.
-
#next_page_token ⇒ String
The token for the next page of the response.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListHubsResponse
constructor
A new instance of ListHubsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListHubsResponse
Returns a new instance of ListHubsResponse.
2404 2405 2406 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2404 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hubs ⇒ Array<Google::Apis::NetworkconnectivityV1::Hub>
The requested hubs.
Corresponds to the JSON property hubs
2390 2391 2392 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2390 def hubs @hubs end |
#next_page_token ⇒ String
The token for the next page of the response. To see more results, use this
value as the page_token for your next request. If this value is empty, there
are no more results.
Corresponds to the JSON property nextPageToken
2397 2398 2399 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2397 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
2402 2403 2404 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2402 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2409 2410 2411 2412 2413 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2409 def update!(**args) @hubs = args[:hubs] if args.key?(:hubs) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |