Class: Google::Apis::NetworkconnectivityV1::ListMulticloudDataTransferSupportedServicesResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::ListMulticloudDataTransferSupportedServicesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
Response message to list the services in your project in regions that are eligible for Data Transfer Essentials configuration.
Instance Attribute Summary collapse
-
#multicloud_data_transfer_supported_services ⇒ Array<Google::Apis::NetworkconnectivityV1::MulticloudDataTransferSupportedService>
The list of supported services.
-
#next_page_token ⇒ String
The next page token.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListMulticloudDataTransferSupportedServicesResponse
constructor
A new instance of ListMulticloudDataTransferSupportedServicesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListMulticloudDataTransferSupportedServicesResponse
Returns a new instance of ListMulticloudDataTransferSupportedServicesResponse.
2337 2338 2339 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2337 def initialize(**args) update!(**args) end |
Instance Attribute Details
#multicloud_data_transfer_supported_services ⇒ Array<Google::Apis::NetworkconnectivityV1::MulticloudDataTransferSupportedService>
The list of supported services.
Corresponds to the JSON property multicloudDataTransferSupportedServices
2330 2331 2332 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2330 def multicloud_data_transfer_supported_services @multicloud_data_transfer_supported_services end |
#next_page_token ⇒ String
The next page token.
Corresponds to the JSON property nextPageToken
2335 2336 2337 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2335 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2342 2343 2344 2345 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2342 def update!(**args) @multicloud_data_transfer_supported_services = args[:multicloud_data_transfer_supported_services] if args.key?(:multicloud_data_transfer_supported_services) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |