Class: Google::Apis::NetworkconnectivityV1::ListRouteTablesResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::ListRouteTablesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
Response for HubService.ListRouteTables method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The token for the next page of the response.
-
#route_tables ⇒ Array<Google::Apis::NetworkconnectivityV1::RouteTable>
The requested route tables.
-
#unreachable ⇒ Array<String>
Hubs that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListRouteTablesResponse
constructor
A new instance of ListRouteTablesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListRouteTablesResponse
Returns a new instance of ListRouteTablesResponse.
2464 2465 2466 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2464 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The token for the next page of the response. To see more results, use this
value as the page_token for your next request. If this value is empty, there
are no more results.
Corresponds to the JSON property nextPageToken
2452 2453 2454 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2452 def next_page_token @next_page_token end |
#route_tables ⇒ Array<Google::Apis::NetworkconnectivityV1::RouteTable>
The requested route tables.
Corresponds to the JSON property routeTables
2457 2458 2459 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2457 def route_tables @route_tables end |
#unreachable ⇒ Array<String>
Hubs that could not be reached.
Corresponds to the JSON property unreachable
2462 2463 2464 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2462 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2469 2470 2471 2472 2473 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2469 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @route_tables = args[:route_tables] if args.key?(:route_tables) @unreachable = args[:unreachable] if args.key?(:unreachable) end |