Class: Google::Apis::NetworkconnectivityV1::ListRoutesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

Response for HubService.ListRoutes method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListRoutesResponse

Returns a new instance of ListRoutesResponse.



2710
2711
2712
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2710

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The token for the next page of the response. To see more results, use this value as the page_token for your next request. If this value is empty, there are no more results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2698
2699
2700
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2698

def next_page_token
  @next_page_token
end

#routesArray<Google::Apis::NetworkconnectivityV1::Route>

The requested routes. Corresponds to the JSON property routes



2703
2704
2705
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2703

def routes
  @routes
end

#unreachableArray<String>

RouteTables that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2708
2709
2710
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2708

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2715
2716
2717
2718
2719
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2715

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @routes = args[:routes] if args.key?(:routes)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end