Class: Google::Apis::NetworkconnectivityV1::ListSpokesResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::ListSpokesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
The response for HubService.ListSpokes.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The token for the next page of the response.
-
#spokes ⇒ Array<Google::Apis::NetworkconnectivityV1::Spoke>
The requested spokes.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListSpokesResponse
constructor
A new instance of ListSpokesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListSpokesResponse
Returns a new instance of ListSpokesResponse.
2840 2841 2842 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2840 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The token for the next page of the response. To see more results, use this
value as the page_token for your next request. If this value is empty, there
are no more results.
Corresponds to the JSON property nextPageToken
2828 2829 2830 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2828 def next_page_token @next_page_token end |
#spokes ⇒ Array<Google::Apis::NetworkconnectivityV1::Spoke>
The requested spokes.
Corresponds to the JSON property spokes
2833 2834 2835 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2833 def spokes @spokes end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
2838 2839 2840 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2838 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2845 2846 2847 2848 2849 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2845 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @spokes = args[:spokes] if args.key?(:spokes) @unreachable = args[:unreachable] if args.key?(:unreachable) end |