Class: Google::Apis::NetworkconnectivityV1::ListTransportsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::ListTransportsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
Message for response to listing Transports.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#transports ⇒ Array<Google::Apis::NetworkconnectivityV1::Transport>
The list of Transport.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListTransportsResponse
constructor
A new instance of ListTransportsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListTransportsResponse
Returns a new instance of ListTransportsResponse.
2902 2903 2904 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2902 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
2890 2891 2892 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2890 def next_page_token @next_page_token end |
#transports ⇒ Array<Google::Apis::NetworkconnectivityV1::Transport>
The list of Transport.
Corresponds to the JSON property transports
2895 2896 2897 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2895 def transports @transports end |
#unreachable ⇒ Array<String>
Unordered list. Locations that could not be reached.
Corresponds to the JSON property unreachable
2900 2901 2902 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2900 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2907 2908 2909 2910 2911 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2907 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @transports = args[:transports] if args.key?(:transports) @unreachable = args[:unreachable] if args.key?(:unreachable) end |