Class: Google::Apis::NetworkconnectivityV1::MulticloudDataTransferSupportedService
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::MulticloudDataTransferSupportedService
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
A service in your project in a region that is eligible for Data Transfer Essentials configuration.
Instance Attribute Summary collapse
-
#name ⇒ String
Identifier.
-
#service_configs ⇒ Array<Google::Apis::NetworkconnectivityV1::ServiceConfig>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MulticloudDataTransferSupportedService
constructor
A new instance of MulticloudDataTransferSupportedService.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MulticloudDataTransferSupportedService
Returns a new instance of MulticloudDataTransferSupportedService.
3083 3084 3085 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3083 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Identifier. The name of the service.
Corresponds to the JSON property name
3075 3076 3077 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3075 def name @name end |
#service_configs ⇒ Array<Google::Apis::NetworkconnectivityV1::ServiceConfig>
Output only. The network service tier or regional endpoint supported for the
service.
Corresponds to the JSON property serviceConfigs
3081 3082 3083 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3081 def service_configs @service_configs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3088 3089 3090 3091 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3088 def update!(**args) @name = args[:name] if args.key?(:name) @service_configs = args[:service_configs] if args.key?(:service_configs) end |