Class: Google::Apis::NetworkconnectivityV1::NextHopRouterApplianceInstance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

A route next hop that leads to a Router appliance instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NextHopRouterApplianceInstance

Returns a new instance of NextHopRouterApplianceInstance.



3152
3153
3154
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3152

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#site_to_site_data_transferBoolean Also known as: site_to_site_data_transfer?

Indicates whether site-to-site data transfer is allowed for this Router appliance instance resource. Data transfer is available only in supported locations. Corresponds to the JSON property siteToSiteDataTransfer

Returns:

  • (Boolean)


3139
3140
3141
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3139

def site_to_site_data_transfer
  @site_to_site_data_transfer
end

#uriString

The URI of the Router appliance instance. Corresponds to the JSON property uri

Returns:

  • (String)


3145
3146
3147
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3145

def uri
  @uri
end

#vpc_networkString

The VPC network where this VM is located. Corresponds to the JSON property vpcNetwork

Returns:

  • (String)


3150
3151
3152
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3150

def vpc_network
  @vpc_network
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3157
3158
3159
3160
3161
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3157

def update!(**args)
  @site_to_site_data_transfer = args[:site_to_site_data_transfer] if args.key?(:site_to_site_data_transfer)
  @uri = args[:uri] if args.key?(:uri)
  @vpc_network = args[:vpc_network] if args.key?(:vpc_network)
end