Class: Google::Apis::NetworkconnectivityV1::OperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::OperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
Represents the metadata of the long-running operation.
Instance Attribute Summary collapse
-
#api_version ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#requested_cancellation ⇒ Boolean
(also: #requested_cancellation?)
Output only.
-
#status_message ⇒ String
Output only.
-
#target ⇒ String
Output only.
-
#verb ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationMetadata
constructor
A new instance of OperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationMetadata
Returns a new instance of OperationMetadata.
3292 3293 3294 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3292 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
Output only. API version used to start the operation.
Corresponds to the JSON property apiVersion
3256 3257 3258 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3256 def api_version @api_version end |
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
3261 3262 3263 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3261 def create_time @create_time end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
3266 3267 3268 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3266 def end_time @end_time end |
#requested_cancellation ⇒ Boolean Also known as: requested_cancellation?
Output only. Identifies whether the user has requested cancellation of the
operation. Operations that have been cancelled successfully have google.
longrunning.Operation.error value with a google.rpc.Status.code of 1,
corresponding to Code.CANCELLED.
Corresponds to the JSON property requestedCancellation
3274 3275 3276 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3274 def requested_cancellation @requested_cancellation end |
#status_message ⇒ String
Output only. Human-readable status of the operation, if any.
Corresponds to the JSON property statusMessage
3280 3281 3282 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3280 def @status_message end |
#target ⇒ String
Output only. Server-defined resource path for the target of the operation.
Corresponds to the JSON property target
3285 3286 3287 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3285 def target @target end |
#verb ⇒ String
Output only. Name of the verb executed by the operation.
Corresponds to the JSON property verb
3290 3291 3292 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3290 def verb @verb end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3297 3298 3299 3300 3301 3302 3303 3304 3305 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3297 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation) @status_message = args[:status_message] if args.key?(:status_message) @target = args[:target] if args.key?(:target) @verb = args[:verb] if args.key?(:verb) end |