Class: Google::Apis::NetworkconnectivityV1::PolicyBasedRoute

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

Policy-based routes route L4 network traffic based on not just destination IP address, but also source IP address, protocol, and more. If a policy-based route conflicts with other types of routes, the policy-based route always takes precedence.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PolicyBasedRoute

Returns a new instance of PolicyBasedRoute.



3527
3528
3529
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3527

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when the policy-based route was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3444
3445
3446
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3444

def create_time
  @create_time
end

#descriptionString

Optional. An optional description of this resource. Provide this field when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


3450
3451
3452
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3450

def description
  @description
end

#filterGoogle::Apis::NetworkconnectivityV1::Filter

Filter matches L4 traffic. Corresponds to the JSON property filter



3455
3456
3457
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3455

def filter
  @filter
end

#interconnect_attachmentGoogle::Apis::NetworkconnectivityV1::InterconnectAttachment

InterconnectAttachment that this route applies to. Corresponds to the JSON property interconnectAttachment



3460
3461
3462
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3460

def interconnect_attachment
  @interconnect_attachment
end

#kindString

Output only. Type of this resource. Always networkconnectivity# policyBasedRoute for policy-based Route resources. Corresponds to the JSON property kind

Returns:

  • (String)


3466
3467
3468
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3466

def kind
  @kind
end

#labelsHash<String,String>

User-defined labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3471
3472
3473
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3471

def labels
  @labels
end

#nameString

Immutable. Identifier. A unique name of the resource in the form of projects/ project_number/locations/global/PolicyBasedRoutes/policy_based_route_id` Corresponds to the JSON propertyname`

Returns:

  • (String)


3477
3478
3479
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3477

def name
  @name
end

#networkString

Required. Fully-qualified URL of the network that this route applies to, for example: projects/my-project/global/networks/my-network. Corresponds to the JSON property network

Returns:

  • (String)


3483
3484
3485
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3483

def network
  @network
end

#next_hop_ilb_ipString

Optional. The IP address of a global-access-enabled L4 ILB that is the next hop for matching packets. For this version, only nextHopIlbIp is supported. Corresponds to the JSON property nextHopIlbIp

Returns:

  • (String)


3489
3490
3491
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3489

def next_hop_ilb_ip
  @next_hop_ilb_ip
end

#next_hop_other_routesString

Optional. Other routes that will be referenced to determine the next hop of the packet. Corresponds to the JSON property nextHopOtherRoutes

Returns:

  • (String)


3495
3496
3497
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3495

def next_hop_other_routes
  @next_hop_other_routes
end

#priorityFixnum

Optional. The priority of this policy-based route. Priority is used to break ties in cases where there are more than one matching policy-based routes found. In cases where multiple policy-based routes are matched, the one with the lowest-numbered priority value wins. The default value is 1000. The priority value must be from 1 to 65535, inclusive. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


3504
3505
3506
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3504

def priority
  @priority
end

Output only. Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


3509
3510
3511
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3509

def self_link
  @self_link
end

#update_timeString

Output only. Time when the policy-based route was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3514
3515
3516
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3514

def update_time
  @update_time
end

#virtual_machineGoogle::Apis::NetworkconnectivityV1::VirtualMachine

VM instances that this policy-based route applies to. Corresponds to the JSON property virtualMachine



3519
3520
3521
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3519

def virtual_machine
  @virtual_machine
end

#warningsArray<Google::Apis::NetworkconnectivityV1::Warnings>

Output only. If potential misconfigurations are detected for this route, this field will be populated with warning messages. Corresponds to the JSON property warnings



3525
3526
3527
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3525

def warnings
  @warnings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3532
3533
3534
3535
3536
3537
3538
3539
3540
3541
3542
3543
3544
3545
3546
3547
3548
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3532

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @filter = args[:filter] if args.key?(:filter)
  @interconnect_attachment = args[:interconnect_attachment] if args.key?(:interconnect_attachment)
  @kind = args[:kind] if args.key?(:kind)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @next_hop_ilb_ip = args[:next_hop_ilb_ip] if args.key?(:next_hop_ilb_ip)
  @next_hop_other_routes = args[:next_hop_other_routes] if args.key?(:next_hop_other_routes)
  @priority = args[:priority] if args.key?(:priority)
  @self_link = args[:self_link] if args.key?(:self_link)
  @update_time = args[:update_time] if args.key?(:update_time)
  @virtual_machine = args[:virtual_machine] if args.key?(:virtual_machine)
  @warnings = args[:warnings] if args.key?(:warnings)
end