Class: Google::Apis::NetworkconnectivityV1::PscPropagationStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

The status of one or more propagated Private Service Connect connections in a hub.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PscPropagationStatus

Returns a new instance of PscPropagationStatus.



3863
3864
3865
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3863

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

The propagation status. Corresponds to the JSON property code

Returns:

  • (String)


3830
3831
3832
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3830

def code
  @code
end

#messageString

The human-readable summary of the Private Service Connect connection propagation status. Corresponds to the JSON property message

Returns:

  • (String)


3836
3837
3838
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3836

def message
  @message
end

#source_forwarding_ruleString

The name of the forwarding rule exported to the hub. Corresponds to the JSON property sourceForwardingRule

Returns:

  • (String)


3841
3842
3843
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3841

def source_forwarding_rule
  @source_forwarding_rule
end

#source_groupString

The name of the group that the source spoke belongs to. Corresponds to the JSON property sourceGroup

Returns:

  • (String)


3846
3847
3848
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3846

def source_group
  @source_group
end

#source_spokeString

The name of the spoke that the source forwarding rule belongs to. Corresponds to the JSON property sourceSpoke

Returns:

  • (String)


3851
3852
3853
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3851

def source_spoke
  @source_spoke
end

#target_groupString

The name of the group that the target spoke belongs to. Corresponds to the JSON property targetGroup

Returns:

  • (String)


3856
3857
3858
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3856

def target_group
  @target_group
end

#target_spokeString

The name of the spoke that the source forwarding rule propagates to. Corresponds to the JSON property targetSpoke

Returns:

  • (String)


3861
3862
3863
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3861

def target_spoke
  @target_spoke
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3868
3869
3870
3871
3872
3873
3874
3875
3876
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3868

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @message = args[:message] if args.key?(:message)
  @source_forwarding_rule = args[:source_forwarding_rule] if args.key?(:source_forwarding_rule)
  @source_group = args[:source_group] if args.key?(:source_group)
  @source_spoke = args[:source_spoke] if args.key?(:source_spoke)
  @target_group = args[:target_group] if args.key?(:target_group)
  @target_spoke = args[:target_spoke] if args.key?(:target_spoke)
end