Class: Google::Apis::NetworkconnectivityV1::QueryHubStatusResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

The response for HubService.QueryHubStatus.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueryHubStatusResponse

Returns a new instance of QueryHubStatusResponse.



3479
3480
3481
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3479

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hub_status_entriesArray<Google::Apis::NetworkconnectivityV1::HubStatusEntry>

The list of hub status. Corresponds to the JSON property hubStatusEntries



3470
3471
3472
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3470

def hub_status_entries
  @hub_status_entries
end

#next_page_tokenString

The token for the next page of the response. To see more results, use this value as the page_token for your next request. If this value is empty, there are no more results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3477
3478
3479
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3477

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3484
3485
3486
3487
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3484

def update!(**args)
  @hub_status_entries = args[:hub_status_entries] if args.key?(:hub_status_entries)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end