Class: Google::Apis::NetworkconnectivityV1::RegionalEndpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

The RegionalEndpoint resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionalEndpoint

Returns a new instance of RegionalEndpoint.



3983
3984
3985
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3983

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_typeString

Required. The access type of this regional endpoint. This field is reflected in the PSC Forwarding Rule configuration to enable global access. Corresponds to the JSON property accessType

Returns:

  • (String)


3914
3915
3916
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3914

def access_type
  @access_type
end

#addressString

Optional. The IP Address of the Regional Endpoint. When no address is provided, an IP from the subnetwork is allocated. Use one of the following formats: * IPv4 address as in 10.0.0.1 * Address resource URI as in projects/project/ regions/region/addresses/address_name`for an IPv4 or IPv6 address. Corresponds to the JSON propertyaddress`

Returns:

  • (String)


3922
3923
3924
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3922

def address
  @address
end

#create_timeString

Output only. Time when the RegionalEndpoint was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3927
3928
3929
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3927

def create_time
  @create_time
end

#descriptionString

Optional. A description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


3932
3933
3934
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3932

def description
  @description
end

#ip_addressString

Output only. The literal IP address of the PSC Forwarding Rule created on behalf of the customer. This field is deprecated. Use address instead. Corresponds to the JSON property ipAddress

Returns:

  • (String)


3938
3939
3940
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3938

def ip_address
  @ip_address
end

#labelsHash<String,String>

User-defined labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3943
3944
3945
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3943

def labels
  @labels
end

#nameString

Output only. The name of a RegionalEndpoint. Pattern: projects/project/ locations/location/regionalEndpoints/^[-a-z0-9](?:[-a-z0-9]0,44)[a-z0-9]$. Corresponds to the JSON property name

Returns:

  • (String)


3949
3950
3951
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3949

def name
  @name
end

#networkString

Optional. The name of the VPC network for this private regional endpoint. Format: projects/project/global/networks/network` Corresponds to the JSON propertynetwork`

Returns:

  • (String)


3955
3956
3957
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3955

def network
  @network
end

#psc_forwarding_ruleString

Output only. The resource reference of the PSC Forwarding Rule created on behalf of the customer. Format: //compute.googleapis.com/projects/project/ regions/region/forwardingRules/forwarding_rule_name` Corresponds to the JSON propertypscForwardingRule`

Returns:

  • (String)


3962
3963
3964
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3962

def psc_forwarding_rule
  @psc_forwarding_rule
end

#subnetworkString

Optional. The name of the subnetwork from which the IP address will be allocated. Format: projects/project/regions/region/subnetworks/ subnetwork` Corresponds to the JSON propertysubnetwork`

Returns:

  • (String)


3969
3970
3971
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3969

def subnetwork
  @subnetwork
end

#target_google_apiString

Required. The service endpoint this private regional endpoint connects to. Format: `apiname.region.p.rep.googleapis.comExample: "cloudkms.us- central1.p.rep.googleapis.com". Corresponds to the JSON propertytargetGoogleApi`

Returns:

  • (String)


3976
3977
3978
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3976

def target_google_api
  @target_google_api
end

#update_timeString

Output only. Time when the RegionalEndpoint was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3981
3982
3983
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3981

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3988
3989
3990
3991
3992
3993
3994
3995
3996
3997
3998
3999
4000
4001
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3988

def update!(**args)
  @access_type = args[:access_type] if args.key?(:access_type)
  @address = args[:address] if args.key?(:address)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @psc_forwarding_rule = args[:psc_forwarding_rule] if args.key?(:psc_forwarding_rule)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
  @target_google_api = args[:target_google_api] if args.key?(:target_google_api)
  @update_time = args[:update_time] if args.key?(:update_time)
end