Class: Google::Apis::NetworkconnectivityV1::Route

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

A route defines a path from VM instances within a spoke to a specific destination resource. Only VPC spokes have routes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Route

Returns a new instance of Route.



4188
4189
4190
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4188

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time the route was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4093
4094
4095
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4093

def create_time
  @create_time
end

#descriptionString

An optional description of the route. Corresponds to the JSON property description

Returns:

  • (String)


4098
4099
4100
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4098

def description
  @description
end

#ip_cidr_rangeString

The destination IP address range. Corresponds to the JSON property ipCidrRange

Returns:

  • (String)


4103
4104
4105
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4103

def ip_cidr_range
  @ip_cidr_range
end

#labelsHash<String,String>

Optional labels in key-value pair format. For more information about labels, see Requirements for labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4110
4111
4112
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4110

def labels
  @labels
end

#locationString

Output only. The origin location of the route. Uses the following form: " projects/project/locations/location" Example: projects/1234/locations/us- central1 Corresponds to the JSON property location

Returns:

  • (String)


4117
4118
4119
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4117

def location
  @location
end

#nameString

Immutable. The name of the route. Route names must be unique. Route names use the following form: projects/project_number/locations/global/hubs/hub/ routeTables/route_table_id/routes/route_id` Corresponds to the JSON propertyname`

Returns:

  • (String)


4124
4125
4126
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4124

def name
  @name
end

#next_hop_interconnect_attachmentGoogle::Apis::NetworkconnectivityV1::NextHopInterconnectAttachment

A route next hop that leads to an interconnect attachment resource. Corresponds to the JSON property nextHopInterconnectAttachment



4129
4130
4131
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4129

def next_hop_interconnect_attachment
  @next_hop_interconnect_attachment
end

#next_hop_router_appliance_instanceGoogle::Apis::NetworkconnectivityV1::NextHopRouterApplianceInstance

A route next hop that leads to a Router appliance instance. Corresponds to the JSON property nextHopRouterApplianceInstance



4134
4135
4136
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4134

def next_hop_router_appliance_instance
  @next_hop_router_appliance_instance
end

#next_hop_spokeGoogle::Apis::NetworkconnectivityV1::NextHopSpoke

A route next hop that leads to a spoke resource. Corresponds to the JSON property nextHopSpoke



4139
4140
4141
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4139

def next_hop_spoke
  @next_hop_spoke
end

#next_hop_vpc_networkGoogle::Apis::NetworkconnectivityV1::NextHopVpcNetwork

Immutable. The destination VPC network for packets on this route. Corresponds to the JSON property nextHopVpcNetwork



4144
4145
4146
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4144

def next_hop_vpc_network
  @next_hop_vpc_network
end

#next_hop_vpn_tunnelGoogle::Apis::NetworkconnectivityV1::NextHopVpnTunnel

A route next hop that leads to a VPN tunnel resource. Corresponds to the JSON property nextHopVpnTunnel



4149
4150
4151
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4149

def next_hop_vpn_tunnel
  @next_hop_vpn_tunnel
end

#priorityFixnum

Output only. The priority of this route. Priority is used to break ties in cases where a destination matches more than one route. In these cases the route with the lowest-numbered priority value wins. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


4156
4157
4158
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4156

def priority
  @priority
end

#spokeString

Immutable. The spoke that this route leads to. Example: projects/12345/ locations/global/spokes/SPOKE Corresponds to the JSON property spoke

Returns:

  • (String)


4162
4163
4164
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4162

def spoke
  @spoke
end

#stateString

Output only. The current lifecycle state of the route. Corresponds to the JSON property state

Returns:

  • (String)


4167
4168
4169
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4167

def state
  @state
end

#typeString

Output only. The route's type. Its type is determined by the properties of its IP address range. Corresponds to the JSON property type

Returns:

  • (String)


4173
4174
4175
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4173

def type
  @type
end

#uidString

Output only. The Google-generated UUID for the route. This value is unique across all Network Connectivity Center route resources. If a route is deleted and another with the same name is created, the new route is assigned a different uid. Corresponds to the JSON property uid

Returns:

  • (String)


4181
4182
4183
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4181

def uid
  @uid
end

#update_timeString

Output only. The time the route was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4186
4187
4188
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4186

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4193
4194
4195
4196
4197
4198
4199
4200
4201
4202
4203
4204
4205
4206
4207
4208
4209
4210
4211
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4193

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range)
  @labels = args[:labels] if args.key?(:labels)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @next_hop_interconnect_attachment = args[:next_hop_interconnect_attachment] if args.key?(:next_hop_interconnect_attachment)
  @next_hop_router_appliance_instance = args[:next_hop_router_appliance_instance] if args.key?(:next_hop_router_appliance_instance)
  @next_hop_spoke = args[:next_hop_spoke] if args.key?(:next_hop_spoke)
  @next_hop_vpc_network = args[:next_hop_vpc_network] if args.key?(:next_hop_vpc_network)
  @next_hop_vpn_tunnel = args[:next_hop_vpn_tunnel] if args.key?(:next_hop_vpn_tunnel)
  @priority = args[:priority] if args.key?(:priority)
  @spoke = args[:spoke] if args.key?(:spoke)
  @state = args[:state] if args.key?(:state)
  @type = args[:type] if args.key?(:type)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end