Class: Google::Apis::NetworkconnectivityV1::RouteTable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouteTable

Returns a new instance of RouteTable.



4369
4370
4371
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4369

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time the route table was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4330
4331
4332
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4330

def create_time
  @create_time
end

#descriptionString

An optional description of the route table. Corresponds to the JSON property description

Returns:

  • (String)


4335
4336
4337
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4335

def description
  @description
end

#labelsHash<String,String>

Optional labels in key-value pair format. For more information about labels, see Requirements for labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4342
4343
4344
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4342

def labels
  @labels
end

#nameString

Immutable. The name of the route table. Route table names must be unique. They use the following form: projects/project_number/locations/global/hubs/hub/ routeTables/route_table_id` Corresponds to the JSON propertyname`

Returns:

  • (String)


4349
4350
4351
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4349

def name
  @name
end

#stateString

Output only. The current lifecycle state of this route table. Corresponds to the JSON property state

Returns:

  • (String)


4354
4355
4356
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4354

def state
  @state
end

#uidString

Output only. The Google-generated UUID for the route table. This value is unique across all route table resources. If a route table is deleted and another with the same name is created, the new route table is assigned a different uid. Corresponds to the JSON property uid

Returns:

  • (String)


4362
4363
4364
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4362

def uid
  @uid
end

#update_timeString

Output only. The time the route table was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4367
4368
4369
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4367

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4374
4375
4376
4377
4378
4379
4380
4381
4382
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4374

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end