Class: Google::Apis::NetworkconnectivityV1::ServiceConnectionMap

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

The ServiceConnectionMap resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceConnectionMap

Returns a new instance of ServiceConnectionMap.



4605
4606
4607
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4605

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumer_psc_configsArray<Google::Apis::NetworkconnectivityV1::ConsumerPscConfig>

The PSC configurations on consumer side. Corresponds to the JSON property consumerPscConfigs



4536
4537
4538
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4536

def consumer_psc_configs
  @consumer_psc_configs
end

#consumer_psc_connectionsArray<Google::Apis::NetworkconnectivityV1::ConsumerPscConnection>

Output only. PSC connection details on consumer side. Corresponds to the JSON property consumerPscConnections



4541
4542
4543
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4541

def consumer_psc_connections
  @consumer_psc_connections
end

#create_timeString

Output only. Time when the ServiceConnectionMap was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4546
4547
4548
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4546

def create_time
  @create_time
end

#descriptionString

A description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


4551
4552
4553
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4551

def description
  @description
end

#etagString

Optional. The etag is computed by the server, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


4557
4558
4559
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4557

def etag
  @etag
end

#infrastructureString

Output only. The infrastructure used for connections between consumers/ producers. Corresponds to the JSON property infrastructure

Returns:

  • (String)


4563
4564
4565
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4563

def infrastructure
  @infrastructure
end

#labelsHash<String,String>

User-defined labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4568
4569
4570
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4568

def labels
  @labels
end

#nameString

Immutable. The name of a ServiceConnectionMap. Format: projects/project/ locations/location/serviceConnectionMaps/service_connection_map See: https: //google.aip.dev/122#fields-representing-resource-names Corresponds to the JSON property name

Returns:

  • (String)


4575
4576
4577
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4575

def name
  @name
end

#producer_psc_configsArray<Google::Apis::NetworkconnectivityV1::ProducerPscConfig>

The PSC configurations on producer side. Corresponds to the JSON property producerPscConfigs



4580
4581
4582
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4580

def producer_psc_configs
  @producer_psc_configs
end

#service_classString

The service class identifier this ServiceConnectionMap is for. The user of ServiceConnectionMap create API needs to have networkconnectivity. serviceClasses.use IAM permission for the service class. Corresponds to the JSON property serviceClass

Returns:

  • (String)


4587
4588
4589
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4587

def service_class
  @service_class
end

#service_class_uriString

Output only. The service class uri this ServiceConnectionMap is for. Corresponds to the JSON property serviceClassUri

Returns:

  • (String)


4592
4593
4594
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4592

def service_class_uri
  @service_class_uri
end

#tokenString

The token provided by the consumer. This token authenticates that the consumer can create a connection within the specified project and network. Corresponds to the JSON property token

Returns:

  • (String)


4598
4599
4600
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4598

def token
  @token
end

#update_timeString

Output only. Time when the ServiceConnectionMap was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4603
4604
4605
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4603

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4610
4611
4612
4613
4614
4615
4616
4617
4618
4619
4620
4621
4622
4623
4624
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4610

def update!(**args)
  @consumer_psc_configs = args[:consumer_psc_configs] if args.key?(:consumer_psc_configs)
  @consumer_psc_connections = args[:consumer_psc_connections] if args.key?(:consumer_psc_connections)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @infrastructure = args[:infrastructure] if args.key?(:infrastructure)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @producer_psc_configs = args[:producer_psc_configs] if args.key?(:producer_psc_configs)
  @service_class = args[:service_class] if args.key?(:service_class)
  @service_class_uri = args[:service_class_uri] if args.key?(:service_class_uri)
  @token = args[:token] if args.key?(:token)
  @update_time = args[:update_time] if args.key?(:update_time)
end