Class: Google::Apis::NetworkconnectivityV1::ServiceConnectionPolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

The ServiceConnectionPolicy resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceConnectionPolicy

Returns a new instance of ServiceConnectionPolicy.



3995
3996
3997
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3995

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_created_subnet_infoGoogle::Apis::NetworkconnectivityV1::AutoCreatedSubnetworkInfo

Information for the automatically created subnetwork and its associated IR. Corresponds to the JSON property autoCreatedSubnetInfo



3928
3929
3930
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3928

def auto_created_subnet_info
  @auto_created_subnet_info
end

#create_timeString

Output only. Time when the ServiceConnectionPolicy was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3933
3934
3935
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3933

def create_time
  @create_time
end

#descriptionString

A description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


3938
3939
3940
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3938

def description
  @description
end

#etagString

Optional. The etag is computed by the server, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


3944
3945
3946
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3944

def etag
  @etag
end

#infrastructureString

Output only. The type of underlying resources used to create the connection. Corresponds to the JSON property infrastructure

Returns:

  • (String)


3949
3950
3951
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3949

def infrastructure
  @infrastructure
end

#labelsHash<String,String>

User-defined labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3954
3955
3956
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3954

def labels
  @labels
end

#nameString

Immutable. The name of a ServiceConnectionPolicy. Format: projects/project/ locations/location/serviceConnectionPolicies/service_connection_policy See: https://google.aip.dev/122#fields-representing-resource-names Corresponds to the JSON property name

Returns:

  • (String)


3961
3962
3963
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3961

def name
  @name
end

#networkString

The resource path of the consumer network. Example: - projects/projectNumOrId /global/networks/resourceId. Corresponds to the JSON property network

Returns:

  • (String)


3967
3968
3969
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3967

def network
  @network
end

#psc_configGoogle::Apis::NetworkconnectivityV1::PscConfig

Configuration used for Private Service Connect connections. Used when Infrastructure is PSC. Corresponds to the JSON property pscConfig



3973
3974
3975
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3973

def psc_config
  @psc_config
end

#psc_connectionsArray<Google::Apis::NetworkconnectivityV1::PscConnection>

Output only. [Output only] Information about each Private Service Connect connection. Corresponds to the JSON property pscConnections



3979
3980
3981
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3979

def psc_connections
  @psc_connections
end

#service_classString

The service class identifier for which this ServiceConnectionPolicy is for. The service class identifier is a unique, symbolic representation of a ServiceClass. It is provided by the Service Producer. Google services have a prefix of gcp or google-cloud. For example, gcp-memorystore-redis or google- cloud-sql. 3rd party services do not. For example, test-service-a3dfcx. Corresponds to the JSON property serviceClass

Returns:

  • (String)


3988
3989
3990
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3988

def service_class
  @service_class
end

#update_timeString

Output only. Time when the ServiceConnectionPolicy was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3993
3994
3995
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3993

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4000
4001
4002
4003
4004
4005
4006
4007
4008
4009
4010
4011
4012
4013
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4000

def update!(**args)
  @auto_created_subnet_info = args[:auto_created_subnet_info] if args.key?(:auto_created_subnet_info)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @infrastructure = args[:infrastructure] if args.key?(:infrastructure)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @psc_config = args[:psc_config] if args.key?(:psc_config)
  @psc_connections = args[:psc_connections] if args.key?(:psc_connections)
  @service_class = args[:service_class] if args.key?(:service_class)
  @update_time = args[:update_time] if args.key?(:update_time)
end