Class: Google::Apis::NetworkconnectivityV1::SpokeStateCount
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::SpokeStateCount
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
The number of spokes that are in a particular state and associated with a given hub.
Instance Attribute Summary collapse
-
#count ⇒ Fixnum
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SpokeStateCount
constructor
A new instance of SpokeStateCount.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SpokeStateCount
Returns a new instance of SpokeStateCount.
5010 5011 5012 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5010 def initialize(**args) update!(**args) end |
Instance Attribute Details
#count ⇒ Fixnum
Output only. The total number of spokes that are in this state and associated
with a given hub.
Corresponds to the JSON property count
5003 5004 5005 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5003 def count @count end |
#state ⇒ String
Output only. The state of the spokes.
Corresponds to the JSON property state
5008 5009 5010 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5008 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5015 5016 5017 5018 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5015 def update!(**args) @count = args[:count] if args.key?(:count) @state = args[:state] if args.key?(:state) end |