Class: Google::Apis::NetworkconnectivityV1::SpokeSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

Summarizes information about the spokes associated with a hub. The summary includes a count of spokes according to type and according to state. If any spokes are inactive, the summary also lists the reasons they are inactive, including a count for each reason.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SpokeSummary

Returns a new instance of SpokeSummary.



4963
4964
4965
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4963

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#spoke_state_countsArray<Google::Apis::NetworkconnectivityV1::SpokeStateCount>

Output only. Counts the number of spokes that are in each state and associated with a given hub. Corresponds to the JSON property spokeStateCounts



4949
4950
4951
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4949

def spoke_state_counts
  @spoke_state_counts
end

#spoke_state_reason_countsArray<Google::Apis::NetworkconnectivityV1::SpokeStateReasonCount>

Output only. Counts the number of spokes that are inactive for each possible reason and associated with a given hub. Corresponds to the JSON property spokeStateReasonCounts



4955
4956
4957
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4955

def spoke_state_reason_counts
  @spoke_state_reason_counts
end

#spoke_type_countsArray<Google::Apis::NetworkconnectivityV1::SpokeTypeCount>

Output only. Counts the number of spokes of each type that are associated with a specific hub. Corresponds to the JSON property spokeTypeCounts



4961
4962
4963
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4961

def spoke_type_counts
  @spoke_type_counts
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4968
4969
4970
4971
4972
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4968

def update!(**args)
  @spoke_state_counts = args[:spoke_state_counts] if args.key?(:spoke_state_counts)
  @spoke_state_reason_counts = args[:spoke_state_reason_counts] if args.key?(:spoke_state_reason_counts)
  @spoke_type_counts = args[:spoke_type_counts] if args.key?(:spoke_type_counts)
end