Class: Google::Apis::NetworkconnectivityV1::StateReason
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::StateReason
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
The reason for the current state of the spoke.
Instance Attribute Summary collapse
-
#code ⇒ String
The code associated with this reason.
-
#message ⇒ String
Human-readable details about this reason.
-
#user_details ⇒ String
Additional information provided by the user in the RejectSpoke call.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StateReason
constructor
A new instance of StateReason.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StateReason
Returns a new instance of StateReason.
5158 5159 5160 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5158 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
The code associated with this reason.
Corresponds to the JSON property code
5146 5147 5148 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5146 def code @code end |
#message ⇒ String
Human-readable details about this reason.
Corresponds to the JSON property message
5151 5152 5153 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5151 def @message end |
#user_details ⇒ String
Additional information provided by the user in the RejectSpoke call.
Corresponds to the JSON property userDetails
5156 5157 5158 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5156 def user_details @user_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5163 5164 5165 5166 5167 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5163 def update!(**args) @code = args[:code] if args.key?(:code) @message = args[:message] if args.key?(:message) @user_details = args[:user_details] if args.key?(:user_details) end |