Class: Google::Apis::NetworkconnectivityV1::StateTimeline

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

The timeline of the pending states for a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StateTimeline

Returns a new instance of StateTimeline.



4882
4883
4884
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4882

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#statesArray<Google::Apis::NetworkconnectivityV1::StateMetadata>

Output only. The state and activation time details of the resource state. Corresponds to the JSON property states



4880
4881
4882
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4880

def states
  @states
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4887
4888
4889
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4887

def update!(**args)
  @states = args[:states] if args.key?(:states)
end