Class: Google::Apis::NetworkconnectivityV1::AutoCreatedSubnetworkInfo
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::AutoCreatedSubnetworkInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
Information for the automatically created subnetwork and its associated IR.
Instance Attribute Summary collapse
-
#delinked ⇒ Boolean
(also: #delinked?)
Output only.
-
#internal_range ⇒ String
Output only.
-
#internal_range_ref ⇒ String
Output only.
-
#subnetwork ⇒ String
Output only.
-
#subnetwork_ref ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutoCreatedSubnetworkInfo
constructor
A new instance of AutoCreatedSubnetworkInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutoCreatedSubnetworkInfo
Returns a new instance of AutoCreatedSubnetworkInfo.
286 287 288 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 286 def initialize(**args) update!(**args) end |
Instance Attribute Details
#delinked ⇒ Boolean Also known as: delinked?
Output only. Indicates whether the subnetwork is delinked from the Service
Connection Policy. Only set if the subnetwork mode is AUTO_CREATED during
creation.
Corresponds to the JSON property delinked
259 260 261 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 259 def delinked @delinked end |
#internal_range ⇒ String
Output only. URI of the automatically created Internal Range. Only set if the
subnetwork mode is AUTO_CREATED during creation.
Corresponds to the JSON property internalRange
266 267 268 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 266 def internal_range @internal_range end |
#internal_range_ref ⇒ String
Output only. URI of the automatically created Internal Range reference. Only
set if the subnetwork mode is AUTO_CREATED during creation.
Corresponds to the JSON property internalRangeRef
272 273 274 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 272 def internal_range_ref @internal_range_ref end |
#subnetwork ⇒ String
Output only. URI of the automatically created subnetwork. Only set if the
subnetwork mode is AUTO_CREATED during creation.
Corresponds to the JSON property subnetwork
278 279 280 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 278 def subnetwork @subnetwork end |
#subnetwork_ref ⇒ String
Output only. URI of the automatically created subnetwork reference. Only set
if the subnetwork mode is AUTO_CREATED during creation.
Corresponds to the JSON property subnetworkRef
284 285 286 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 284 def subnetwork_ref @subnetwork_ref end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
291 292 293 294 295 296 297 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 291 def update!(**args) @delinked = args[:delinked] if args.key?(:delinked) @internal_range = args[:internal_range] if args.key?(:internal_range) @internal_range_ref = args[:internal_range_ref] if args.key?(:internal_range_ref) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) @subnetwork_ref = args[:subnetwork_ref] if args.key?(:subnetwork_ref) end |