Class: Google::Apis::NetworkconnectivityV1::AutomatedDnsCreationSpec
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::AutomatedDnsCreationSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
The specification for automatically creating a DNS record.
Instance Attribute Summary collapse
-
#dns_suffix ⇒ String
Required.
-
#hostname ⇒ String
Required.
-
#ttl ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutomatedDnsCreationSpec
constructor
A new instance of AutomatedDnsCreationSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutomatedDnsCreationSpec
Returns a new instance of AutomatedDnsCreationSpec.
317 318 319 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 317 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dns_suffix ⇒ String
Required. The DNS suffix to use for the DNS record. Must end with a dot. This
should be a valid DNS domain name as per RFC 1035. Each label (between dots)
can contain letters, digits, and hyphens, and must not start or end with a
hyphen. Example: "my-service.example.com.", "internal."
Corresponds to the JSON property dnsSuffix
301 302 303 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 301 def dns_suffix @dns_suffix end |
#hostname ⇒ String
Required. The hostname (the first label of the FQDN) to use for the DNS record.
This should be a valid DNS label as per RFC 1035. Generally, this means the
hostname can contain letters, digits, and hyphens, and must not start or end
with a hyphen. Example: "my-instance", "db-1"
Corresponds to the JSON property hostname
309 310 311 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 309 def hostname @hostname end |
#ttl ⇒ String
Optional. The Time To Live for the DNS record, in seconds. If not provided, a
default of 30 seconds will be used.
Corresponds to the JSON property ttl
315 316 317 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 315 def ttl @ttl end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
322 323 324 325 326 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 322 def update!(**args) @dns_suffix = args[:dns_suffix] if args.key?(:dns_suffix) @hostname = args[:hostname] if args.key?(:hostname) @ttl = args[:ttl] if args.key?(:ttl) end |