Class: Google::Apis::NetworkconnectivityV1::ConsumerPscConfig
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::ConsumerPscConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
Allow the producer to specify which consumers can connect to it.
Instance Attribute Summary collapse
-
#consumer_instance_project ⇒ String
Required.
-
#disable_global_access ⇒ Boolean
(also: #disable_global_access?)
This is used in PSC consumer ForwardingRule to control whether the PSC endpoint can be accessed from another region.
-
#ip_version ⇒ String
The requested IP version for the PSC connection.
-
#network ⇒ String
The resource path of the consumer network where PSC connections are allowed to be created in.
-
#producer_instance_id ⇒ String
Immutable.
-
#producer_instance_metadata ⇒ Hash<String,String>
Immutable.
-
#project ⇒ String
The consumer project where PSC connections are allowed to be created in.
-
#service_attachment_ip_address_map ⇒ Hash<String,String>
Optional.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConsumerPscConfig
constructor
A new instance of ConsumerPscConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConsumerPscConfig
Returns a new instance of ConsumerPscConfig.
728 729 730 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 728 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consumer_instance_project ⇒ String
Required. The project ID or project number of the consumer project. This
project is the one that the consumer uses to interact with the producer
instance. From the perspective of a consumer who's created a producer instance,
this is the project of the producer instance. Format: 'projects/' Eg. '
projects/consumer-project' or 'projects/1234'
Corresponds to the JSON property consumerInstanceProject
677 678 679 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 677 def consumer_instance_project @consumer_instance_project end |
#disable_global_access ⇒ Boolean Also known as: disable_global_access?
This is used in PSC consumer ForwardingRule to control whether the PSC
endpoint can be accessed from another region.
Corresponds to the JSON property disableGlobalAccess
683 684 685 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 683 def disable_global_access @disable_global_access end |
#ip_version ⇒ String
The requested IP version for the PSC connection.
Corresponds to the JSON property ipVersion
689 690 691 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 689 def ip_version @ip_version end |
#network ⇒ String
The resource path of the consumer network where PSC connections are allowed to
be created in. Note, this network does not need be in the ConsumerPscConfig.
project in the case of SharedVPC. Example: projects/projectNumOrId/global/
networks/networkId.
Corresponds to the JSON property network
697 698 699 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 697 def network @network end |
#producer_instance_id ⇒ String
Immutable. Deprecated. Use producer_instance_metadata instead. An immutable
identifier for the producer instance.
Corresponds to the JSON property producerInstanceId
703 704 705 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 703 def producer_instance_id @producer_instance_id end |
#producer_instance_metadata ⇒ Hash<String,String>
Immutable. An immutable map for the producer instance metadata.
Corresponds to the JSON property producerInstanceMetadata
708 709 710 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 708 def @producer_instance_metadata end |
#project ⇒ String
The consumer project where PSC connections are allowed to be created in.
Corresponds to the JSON property project
713 714 715 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 713 def project @project end |
#service_attachment_ip_address_map ⇒ Hash<String,String>
Optional. A map to store mapping between customer vip and target service
attachment. This field can be used to specify a static IP address for a PSC
connection.
Corresponds to the JSON property serviceAttachmentIpAddressMap
720 721 722 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 720 def @service_attachment_ip_address_map end |
#state ⇒ String
Output only. Overall state of PSC Connections management for this consumer psc
config.
Corresponds to the JSON property state
726 727 728 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 726 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
733 734 735 736 737 738 739 740 741 742 743 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 733 def update!(**args) @consumer_instance_project = args[:consumer_instance_project] if args.key?(:consumer_instance_project) @disable_global_access = args[:disable_global_access] if args.key?(:disable_global_access) @ip_version = args[:ip_version] if args.key?(:ip_version) @network = args[:network] if args.key?(:network) @producer_instance_id = args[:producer_instance_id] if args.key?(:producer_instance_id) @producer_instance_metadata = args[:producer_instance_metadata] if args.key?(:producer_instance_metadata) @project = args[:project] if args.key?(:project) @service_attachment_ip_address_map = args[:service_attachment_ip_address_map] if args.key?(:service_attachment_ip_address_map) @state = args[:state] if args.key?(:state) end |