Class: Google::Apis::NetworkconnectivityV1::ConsumerPscConnection
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::ConsumerPscConnection
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
PSC connection details on consumer side.
Instance Attribute Summary collapse
-
#dns_automation_status ⇒ Google::Apis::NetworkconnectivityV1::DnsAutomationStatus
The status of DNS automation for a PSC connection.
-
#error ⇒ Google::Apis::NetworkconnectivityV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#error_info ⇒ Google::Apis::NetworkconnectivityV1::GoogleRpcErrorInfo
Describes the cause of the error with structured details.
-
#error_type ⇒ String
The error type indicates whether the error is consumer facing, producer facing or system internal.
-
#forwarding_rule ⇒ String
The URI of the consumer forwarding rule created.
-
#gce_operation ⇒ String
The last Compute Engine operation to setup PSC connection.
-
#ip ⇒ String
The IP literal allocated on the consumer network for the PSC forwarding rule that is created to connect to the producer service attachment in this service connection map.
-
#ip_version ⇒ String
The requested IP version for the PSC connection.
-
#network ⇒ String
The consumer network whose PSC forwarding rule is connected to the service attachments in this service connection map.
-
#producer_instance_id ⇒ String
Immutable.
-
#producer_instance_metadata ⇒ Hash<String,String>
Immutable.
-
#project ⇒ String
The consumer project whose PSC forwarding rule is connected to the service attachments in this service connection map.
-
#psc_connection_id ⇒ String
The PSC connection id of the PSC forwarding rule connected to the service attachments in this service connection map.
-
#selected_subnetwork ⇒ String
Output only.
-
#service_attachment_uri ⇒ String
The URI of a service attachment which is the target of the PSC connection.
-
#state ⇒ String
The state of the PSC connection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConsumerPscConnection
constructor
A new instance of ConsumerPscConnection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConsumerPscConnection
Returns a new instance of ConsumerPscConnection.
852 853 854 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 852 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dns_automation_status ⇒ Google::Apis::NetworkconnectivityV1::DnsAutomationStatus
The status of DNS automation for a PSC connection.
Corresponds to the JSON property dnsAutomationStatus
753 754 755 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 753 def dns_automation_status @dns_automation_status end |
#error ⇒ Google::Apis::NetworkconnectivityV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
763 764 765 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 763 def error @error end |
#error_info ⇒ Google::Apis::NetworkconnectivityV1::GoogleRpcErrorInfo
Describes the cause of the error with structured details. Example of an error
when contacting the "pubsub.googleapis.com" API when it is not enabled: "
reason": "API_DISABLED" "domain": "googleapis.com" "metadata": "resource": "
projects/123", "service": "pubsub.googleapis.com" This response indicates
that the pubsub.googleapis.com API is not enabled. Example of an error that is
returned when attempting to create a Spanner instance in a region that is out
of stock: "reason": "STOCKOUT" "domain": "spanner.googleapis.com", "metadata"
: "availableRegions": "us-central1,us-east2"
Corresponds to the JSON property errorInfo
775 776 777 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 775 def error_info @error_info end |
#error_type ⇒ String
The error type indicates whether the error is consumer facing, producer facing
or system internal.
Corresponds to the JSON property errorType
781 782 783 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 781 def error_type @error_type end |
#forwarding_rule ⇒ String
The URI of the consumer forwarding rule created. Example: projects/
projectNumOrId/regions/us-east1/networks/resourceId.
Corresponds to the JSON property forwardingRule
787 788 789 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 787 def forwarding_rule @forwarding_rule end |
#gce_operation ⇒ String
The last Compute Engine operation to setup PSC connection.
Corresponds to the JSON property gceOperation
792 793 794 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 792 def gce_operation @gce_operation end |
#ip ⇒ String
The IP literal allocated on the consumer network for the PSC forwarding rule
that is created to connect to the producer service attachment in this service
connection map.
Corresponds to the JSON property ip
799 800 801 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 799 def ip @ip end |
#ip_version ⇒ String
The requested IP version for the PSC connection.
Corresponds to the JSON property ipVersion
804 805 806 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 804 def ip_version @ip_version end |
#network ⇒ String
The consumer network whose PSC forwarding rule is connected to the service
attachments in this service connection map. Note that the network could be on
a different project (shared VPC).
Corresponds to the JSON property network
811 812 813 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 811 def network @network end |
#producer_instance_id ⇒ String
Immutable. Deprecated. Use producer_instance_metadata instead. An immutable
identifier for the producer instance.
Corresponds to the JSON property producerInstanceId
817 818 819 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 817 def producer_instance_id @producer_instance_id end |
#producer_instance_metadata ⇒ Hash<String,String>
Immutable. An immutable map for the producer instance metadata.
Corresponds to the JSON property producerInstanceMetadata
822 823 824 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 822 def @producer_instance_metadata end |
#project ⇒ String
The consumer project whose PSC forwarding rule is connected to the service
attachments in this service connection map.
Corresponds to the JSON property project
828 829 830 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 828 def project @project end |
#psc_connection_id ⇒ String
The PSC connection id of the PSC forwarding rule connected to the service
attachments in this service connection map.
Corresponds to the JSON property pscConnectionId
834 835 836 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 834 def psc_connection_id @psc_connection_id end |
#selected_subnetwork ⇒ String
Output only. The URI of the selected subnetwork selected to allocate IP
address for this connection.
Corresponds to the JSON property selectedSubnetwork
840 841 842 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 840 def selected_subnetwork @selected_subnetwork end |
#service_attachment_uri ⇒ String
The URI of a service attachment which is the target of the PSC connection.
Corresponds to the JSON property serviceAttachmentUri
845 846 847 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 845 def @service_attachment_uri end |
#state ⇒ String
The state of the PSC connection.
Corresponds to the JSON property state
850 851 852 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 850 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 857 def update!(**args) @dns_automation_status = args[:dns_automation_status] if args.key?(:dns_automation_status) @error = args[:error] if args.key?(:error) @error_info = args[:error_info] if args.key?(:error_info) @error_type = args[:error_type] if args.key?(:error_type) @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule) @gce_operation = args[:gce_operation] if args.key?(:gce_operation) @ip = args[:ip] if args.key?(:ip) @ip_version = args[:ip_version] if args.key?(:ip_version) @network = args[:network] if args.key?(:network) @producer_instance_id = args[:producer_instance_id] if args.key?(:producer_instance_id) @producer_instance_metadata = args[:producer_instance_metadata] if args.key?(:producer_instance_metadata) @project = args[:project] if args.key?(:project) @psc_connection_id = args[:psc_connection_id] if args.key?(:psc_connection_id) @selected_subnetwork = args[:selected_subnetwork] if args.key?(:selected_subnetwork) @service_attachment_uri = args[:service_attachment_uri] if args.key?(:service_attachment_uri) @state = args[:state] if args.key?(:state) end |