Class: Google::Apis::NetworkconnectivityV1::ConsumerPscConnection

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

PSC connection details on consumer side.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConsumerPscConnection

Returns a new instance of ConsumerPscConnection.



673
674
675
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 673

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dns_automation_statusGoogle::Apis::NetworkconnectivityV1::DnsAutomationStatus

The status of DNS automation for a PSC connection. Corresponds to the JSON property dnsAutomationStatus



574
575
576
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 574

def dns_automation_status
  @dns_automation_status
end

#errorGoogle::Apis::NetworkconnectivityV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



584
585
586
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 584

def error
  @error
end

#error_infoGoogle::Apis::NetworkconnectivityV1::GoogleRpcErrorInfo

Describes the cause of the error with structured details. Example of an error when contacting the "pubsub.googleapis.com" API when it is not enabled: " reason": "API_DISABLED" "domain": "googleapis.com" "metadata": "resource": " projects/123", "service": "pubsub.googleapis.com" This response indicates that the pubsub.googleapis.com API is not enabled. Example of an error that is returned when attempting to create a Spanner instance in a region that is out of stock: "reason": "STOCKOUT" "domain": "spanner.googleapis.com", "metadata" : "availableRegions": "us-central1,us-east2" Corresponds to the JSON property errorInfo



596
597
598
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 596

def error_info
  @error_info
end

#error_typeString

The error type indicates whether the error is consumer facing, producer facing or system internal. Corresponds to the JSON property errorType

Returns:

  • (String)


602
603
604
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 602

def error_type
  @error_type
end

#forwarding_ruleString

The URI of the consumer forwarding rule created. Example: projects/ projectNumOrId/regions/us-east1/networks/resourceId. Corresponds to the JSON property forwardingRule

Returns:

  • (String)


608
609
610
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 608

def forwarding_rule
  @forwarding_rule
end

#gce_operationString

The last Compute Engine operation to setup PSC connection. Corresponds to the JSON property gceOperation

Returns:

  • (String)


613
614
615
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 613

def gce_operation
  @gce_operation
end

#ipString

The IP literal allocated on the consumer network for the PSC forwarding rule that is created to connect to the producer service attachment in this service connection map. Corresponds to the JSON property ip

Returns:

  • (String)


620
621
622
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 620

def ip
  @ip
end

#ip_versionString

The requested IP version for the PSC connection. Corresponds to the JSON property ipVersion

Returns:

  • (String)


625
626
627
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 625

def ip_version
  @ip_version
end

#networkString

The consumer network whose PSC forwarding rule is connected to the service attachments in this service connection map. Note that the network could be on a different project (shared VPC). Corresponds to the JSON property network

Returns:

  • (String)


632
633
634
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 632

def network
  @network
end

#producer_instance_idString

Immutable. Deprecated. Use producer_instance_metadata instead. An immutable identifier for the producer instance. Corresponds to the JSON property producerInstanceId

Returns:

  • (String)


638
639
640
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 638

def producer_instance_id
  @producer_instance_id
end

#producer_instance_metadataHash<String,String>

Immutable. An immutable map for the producer instance metadata. Corresponds to the JSON property producerInstanceMetadata

Returns:

  • (Hash<String,String>)


643
644
645
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 643

def 
  @producer_instance_metadata
end

#projectString

The consumer project whose PSC forwarding rule is connected to the service attachments in this service connection map. Corresponds to the JSON property project

Returns:

  • (String)


649
650
651
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 649

def project
  @project
end

#psc_connection_idString

The PSC connection id of the PSC forwarding rule connected to the service attachments in this service connection map. Corresponds to the JSON property pscConnectionId

Returns:

  • (String)


655
656
657
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 655

def psc_connection_id
  @psc_connection_id
end

#selected_subnetworkString

Output only. The URI of the selected subnetwork selected to allocate IP address for this connection. Corresponds to the JSON property selectedSubnetwork

Returns:

  • (String)


661
662
663
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 661

def selected_subnetwork
  @selected_subnetwork
end

#service_attachment_uriString

The URI of a service attachment which is the target of the PSC connection. Corresponds to the JSON property serviceAttachmentUri

Returns:

  • (String)


666
667
668
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 666

def service_attachment_uri
  @service_attachment_uri
end

#stateString

The state of the PSC connection. Corresponds to the JSON property state

Returns:

  • (String)


671
672
673
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 671

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 678

def update!(**args)
  @dns_automation_status = args[:dns_automation_status] if args.key?(:dns_automation_status)
  @error = args[:error] if args.key?(:error)
  @error_info = args[:error_info] if args.key?(:error_info)
  @error_type = args[:error_type] if args.key?(:error_type)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @gce_operation = args[:gce_operation] if args.key?(:gce_operation)
  @ip = args[:ip] if args.key?(:ip)
  @ip_version = args[:ip_version] if args.key?(:ip_version)
  @network = args[:network] if args.key?(:network)
  @producer_instance_id = args[:producer_instance_id] if args.key?(:producer_instance_id)
  @producer_instance_metadata = args[:producer_instance_metadata] if args.key?(:producer_instance_metadata)
  @project = args[:project] if args.key?(:project)
  @psc_connection_id = args[:psc_connection_id] if args.key?(:psc_connection_id)
  @selected_subnetwork = args[:selected_subnetwork] if args.key?(:selected_subnetwork)
  @service_attachment_uri = args[:service_attachment_uri] if args.key?(:service_attachment_uri)
  @state = args[:state] if args.key?(:state)
end