Class: Google::Apis::NetworkconnectivityV1::Destination

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

The Destination resource. It specifies the IP prefix and the associated autonomous system numbers (ASN) that you want to include in a MulticloudDataTransferConfig resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Destination

Returns a new instance of Destination.



762
763
764
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 762

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when the Destination resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


707
708
709
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 707

def create_time
  @create_time
end

#descriptionString

Optional. A description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


712
713
714
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 712

def description
  @description
end

#endpointsArray<Google::Apis::NetworkconnectivityV1::DestinationEndpoint>

Required. Unordered list. The list of DestinationEndpoint resources configured for the IP prefix. Corresponds to the JSON property endpoints



718
719
720
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 718

def endpoints
  @endpoints
end

#etagString

The etag is computed by the server, and might be sent with update and delete requests so that the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


724
725
726
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 724

def etag
  @etag
end

#ip_prefixString

Required. Immutable. The IP prefix that represents your workload on another CSP. Corresponds to the JSON property ipPrefix

Returns:

  • (String)


730
731
732
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 730

def ip_prefix
  @ip_prefix
end

#labelsHash<String,String>

Optional. User-defined labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


735
736
737
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 735

def labels
  @labels
end

#nameString

Identifier. The name of the Destination resource. Format: projects/project /locations/location/multicloudDataTransferConfigs/ multicloud_data_transfer_config/destinations/destination`. Corresponds to the JSON propertyname`

Returns:

  • (String)


742
743
744
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 742

def name
  @name
end

#state_timelineGoogle::Apis::NetworkconnectivityV1::StateTimeline

The timeline of the pending states for a resource. Corresponds to the JSON property stateTimeline



747
748
749
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 747

def state_timeline
  @state_timeline
end

#uidString

Output only. The Google-generated unique ID for the Destination resource. This value is unique across all Destination resources. If a resource is deleted and another with the same name is created, the new resource is assigned a different and unique ID. Corresponds to the JSON property uid

Returns:

  • (String)


755
756
757
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 755

def uid
  @uid
end

#update_timeString

Output only. Time when the Destination resource was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


760
761
762
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 760

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



767
768
769
770
771
772
773
774
775
776
777
778
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 767

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @endpoints = args[:endpoints] if args.key?(:endpoints)
  @etag = args[:etag] if args.key?(:etag)
  @ip_prefix = args[:ip_prefix] if args.key?(:ip_prefix)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @state_timeline = args[:state_timeline] if args.key?(:state_timeline)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end