Class: Google::Apis::NetworkconnectivityV1::Destination
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::Destination
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
The Destination resource. It specifies the IP prefix and the associated
autonomous system numbers (ASN) that you want to include in a
MulticloudDataTransferConfig resource.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#endpoints ⇒ Array<Google::Apis::NetworkconnectivityV1::DestinationEndpoint>
Required.
-
#etag ⇒ String
The etag is computed by the server, and might be sent with update and delete requests so that the client has an up-to-date value before proceeding.
-
#ip_prefix ⇒ String
Required.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#state_timeline ⇒ Google::Apis::NetworkconnectivityV1::StateTimeline
The timeline of the pending states for a resource.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Destination
constructor
A new instance of Destination.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Destination
Returns a new instance of Destination.
762 763 764 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 762 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Time when the Destination resource was created.
Corresponds to the JSON property createTime
707 708 709 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 707 def create_time @create_time end |
#description ⇒ String
Optional. A description of this resource.
Corresponds to the JSON property description
712 713 714 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 712 def description @description end |
#endpoints ⇒ Array<Google::Apis::NetworkconnectivityV1::DestinationEndpoint>
Required. Unordered list. The list of DestinationEndpoint resources
configured for the IP prefix.
Corresponds to the JSON property endpoints
718 719 720 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 718 def endpoints @endpoints end |
#etag ⇒ String
The etag is computed by the server, and might be sent with update and delete
requests so that the client has an up-to-date value before proceeding.
Corresponds to the JSON property etag
724 725 726 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 724 def etag @etag end |
#ip_prefix ⇒ String
Required. Immutable. The IP prefix that represents your workload on another
CSP.
Corresponds to the JSON property ipPrefix
730 731 732 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 730 def ip_prefix @ip_prefix end |
#labels ⇒ Hash<String,String>
Optional. User-defined labels.
Corresponds to the JSON property labels
735 736 737 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 735 def labels @labels end |
#name ⇒ String
Identifier. The name of the Destination resource. Format: projects/project
/locations/location/multicloudDataTransferConfigs/
multicloud_data_transfer_config/destinations/destination`.
Corresponds to the JSON propertyname`
742 743 744 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 742 def name @name end |
#state_timeline ⇒ Google::Apis::NetworkconnectivityV1::StateTimeline
The timeline of the pending states for a resource.
Corresponds to the JSON property stateTimeline
747 748 749 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 747 def state_timeline @state_timeline end |
#uid ⇒ String
Output only. The Google-generated unique ID for the Destination resource.
This value is unique across all Destination resources. If a resource is
deleted and another with the same name is created, the new resource is
assigned a different and unique ID.
Corresponds to the JSON property uid
755 756 757 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 755 def uid @uid end |
#update_time ⇒ String
Output only. Time when the Destination resource was updated.
Corresponds to the JSON property updateTime
760 761 762 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 760 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
767 768 769 770 771 772 773 774 775 776 777 778 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 767 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @endpoints = args[:endpoints] if args.key?(:endpoints) @etag = args[:etag] if args.key?(:etag) @ip_prefix = args[:ip_prefix] if args.key?(:ip_prefix) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @state_timeline = args[:state_timeline] if args.key?(:state_timeline) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |