Class: Google::Apis::NetworkconnectivityV1::DnsAutomationStatus
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::DnsAutomationStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
The status of DNS automation for a PSC connection.
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::NetworkconnectivityV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#fqdn ⇒ String
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DnsAutomationStatus
constructor
A new instance of DnsAutomationStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DnsAutomationStatus
Returns a new instance of DnsAutomationStatus.
1021 1022 1023 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1021 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::NetworkconnectivityV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
1009 1010 1011 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1009 def error @error end |
#fqdn ⇒ String
Output only. The fully qualified domain name of the DNS record.
Corresponds to the JSON property fqdn
1014 1015 1016 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1014 def fqdn @fqdn end |
#state ⇒ String
Output only. The current state of DNS automation.
Corresponds to the JSON property state
1019 1020 1021 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1019 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1026 1027 1028 1029 1030 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1026 def update!(**args) @error = args[:error] if args.key?(:error) @fqdn = args[:fqdn] if args.key?(:fqdn) @state = args[:state] if args.key?(:state) end |