Class: Google::Apis::NetworkconnectivityV1::GatewayAdvertisedRoute
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::GatewayAdvertisedRoute
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
A gateway advertised route is a route that a gateway spoke advertises somewhere.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
An optional description of the gateway advertised route.
-
#ip_range ⇒ String
Immutable.
-
#labels ⇒ Hash<String,String>
Optional labels in key-value pair format.
-
#name ⇒ String
Identifier.
-
#priority ⇒ Fixnum
Optional.
-
#recipient ⇒ String
Optional.
-
#state ⇒ String
Output only.
-
#unique_id ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GatewayAdvertisedRoute
constructor
A new instance of GatewayAdvertisedRoute.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GatewayAdvertisedRoute
Returns a new instance of GatewayAdvertisedRoute.
1254 1255 1256 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1254 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time the gateway advertised route was created.
Corresponds to the JSON property createTime
1195 1196 1197 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1195 def create_time @create_time end |
#description ⇒ String
An optional description of the gateway advertised route.
Corresponds to the JSON property description
1200 1201 1202 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1200 def description @description end |
#ip_range ⇒ String
Immutable. This route's advertised IP address range. Must be a valid CIDR-
formatted prefix. If an IP address is provided without a subnet mask, it is
interpreted as, for IPv4, a /32 singular IP address range, and, for IPv6, /
128.
Corresponds to the JSON property ipRange
1208 1209 1210 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1208 def ip_range @ip_range end |
#labels ⇒ Hash<String,String>
Optional labels in key-value pair format. For more information about labels,
see Requirements for labels.
Corresponds to the JSON property labels
1215 1216 1217 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1215 def labels @labels end |
#name ⇒ String
Identifier. The name of the gateway advertised route. Route names must be
unique and use the following form: projects/project_number/locations/
region/spokes/spoke/gatewayAdvertisedRoutes/gateway_advertised_route_id`
Corresponds to the JSON propertyname`
1222 1223 1224 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1222 def name @name end |
#priority ⇒ Fixnum
Optional. The priority of this advertised route. You can choose a value from
0 to 65335. If you don't provide a value, Google Cloud assigns a priority
of 100 to the ranges.
Corresponds to the JSON property priority
1229 1230 1231 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1229 def priority @priority end |
#recipient ⇒ String
Optional. The recipient of this advertised route.
Corresponds to the JSON property recipient
1234 1235 1236 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1234 def recipient @recipient end |
#state ⇒ String
Output only. The current lifecycle state of this gateway advertised route.
Corresponds to the JSON property state
1239 1240 1241 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1239 def state @state end |
#unique_id ⇒ String
Output only. The Google-generated UUID for the gateway advertised route. This
value is unique across all gateway advertised route resources. If a gateway
advertised route is deleted and another with the same name is created, the new
route is assigned a different unique_id.
Corresponds to the JSON property uniqueId
1247 1248 1249 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1247 def unique_id @unique_id end |
#update_time ⇒ String
Output only. The time the gateway advertised route was last updated.
Corresponds to the JSON property updateTime
1252 1253 1254 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1252 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1259 1260 1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1259 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @ip_range = args[:ip_range] if args.key?(:ip_range) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @priority = args[:priority] if args.key?(:priority) @recipient = args[:recipient] if args.key?(:recipient) @state = args[:state] if args.key?(:state) @unique_id = args[:unique_id] if args.key?(:unique_id) @update_time = args[:update_time] if args.key?(:update_time) end |