Class: Google::Apis::NetworkconnectivityV1::Hub
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::Hub
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
A Network Connectivity Center hub is a global management resource to which you attach spokes. A single hub can contain spokes from multiple regions. However, if any of a hub's spokes use the site-to-site data transfer feature, the resources associated with those spokes must all be in the same VPC network. Spokes that do not use site-to-site data transfer can be associated with any VPC network in your project.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#export_psc ⇒ Boolean
(also: #export_psc?)
Optional.
-
#labels ⇒ Hash<String,String>
Optional labels in key-value pair format.
-
#name ⇒ String
Immutable.
-
#policy_mode ⇒ String
Optional.
-
#preset_topology ⇒ String
Optional.
-
#route_tables ⇒ Array<String>
Output only.
-
#routing_vpcs ⇒ Array<Google::Apis::NetworkconnectivityV1::RoutingVpc>
Output only.
-
#spoke_summary ⇒ Google::Apis::NetworkconnectivityV1::SpokeSummary
Summarizes information about the spokes associated with a hub.
-
#state ⇒ String
Output only.
-
#unique_id ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Hub
constructor
A new instance of Hub.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Hub
Returns a new instance of Hub.
1649 1650 1651 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1649 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time the hub was created.
Corresponds to the JSON property createTime
1565 1566 1567 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1565 def create_time @create_time end |
#description ⇒ String
Optional. An optional description of the hub.
Corresponds to the JSON property description
1570 1571 1572 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1570 def description @description end |
#export_psc ⇒ Boolean Also known as: export_psc?
Optional. Whether Private Service Connect connection propagation is enabled
for the hub. If true, Private Service Connect endpoints in VPC spokes attached
to the hub are made accessible to other VPC spokes attached to the hub. The
default value is false.
Corresponds to the JSON property exportPsc
1578 1579 1580 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1578 def export_psc @export_psc end |
#labels ⇒ Hash<String,String>
Optional labels in key-value pair format. For more information about labels,
see Requirements for labels.
Corresponds to the JSON property labels
1586 1587 1588 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1586 def labels @labels end |
#name ⇒ String
Immutable. The name of the hub. Hub names must be unique. They use the
following form: projects/project_number/locations/global/hubs/hub_id`
Corresponds to the JSON propertyname`
1592 1593 1594 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1592 def name @name end |
#policy_mode ⇒ String
Optional. The policy mode of this hub. This field can be either PRESET or
CUSTOM. If unspecified, the policy_mode defaults to PRESET.
Corresponds to the JSON property policyMode
1598 1599 1600 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1598 def policy_mode @policy_mode end |
#preset_topology ⇒ String
Optional. The topology implemented in this hub. Currently, this field is only
used when policy_mode = PRESET. The available preset topologies are MESH and
STAR. If preset_topology is unspecified and policy_mode = PRESET, the
preset_topology defaults to MESH. When policy_mode = CUSTOM, the
preset_topology is set to PRESET_TOPOLOGY_UNSPECIFIED.
Corresponds to the JSON property presetTopology
1607 1608 1609 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1607 def preset_topology @preset_topology end |
#route_tables ⇒ Array<String>
Output only. The route tables that belong to this hub. They use the following
form: projects/project_number/locations/global/hubs/hub_id/routeTables/
route_table_id`This field is read-only. Network Connectivity Center
automatically populates it based on the route tables nested under the hub.
Corresponds to the JSON propertyrouteTables`
1615 1616 1617 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1615 def route_tables @route_tables end |
#routing_vpcs ⇒ Array<Google::Apis::NetworkconnectivityV1::RoutingVpc>
Output only. The VPC networks associated with this hub's spokes. This field is
read-only. Network Connectivity Center automatically populates it based on the
set of spokes attached to the hub.
Corresponds to the JSON property routingVpcs
1622 1623 1624 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1622 def routing_vpcs @routing_vpcs end |
#spoke_summary ⇒ Google::Apis::NetworkconnectivityV1::SpokeSummary
Summarizes information about the spokes associated with a hub. The summary
includes a count of spokes according to type and according to state. If any
spokes are inactive, the summary also lists the reasons they are inactive,
including a count for each reason.
Corresponds to the JSON property spokeSummary
1630 1631 1632 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1630 def spoke_summary @spoke_summary end |
#state ⇒ String
Output only. The current lifecycle state of this hub.
Corresponds to the JSON property state
1635 1636 1637 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1635 def state @state end |
#unique_id ⇒ String
Output only. The Google-generated UUID for the hub. This value is unique
across all hub resources. If a hub is deleted and another with the same name
is created, the new hub is assigned a different unique_id.
Corresponds to the JSON property uniqueId
1642 1643 1644 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1642 def unique_id @unique_id end |
#update_time ⇒ String
Output only. The time the hub was last updated.
Corresponds to the JSON property updateTime
1647 1648 1649 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1647 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1654 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @export_psc = args[:export_psc] if args.key?(:export_psc) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @policy_mode = args[:policy_mode] if args.key?(:policy_mode) @preset_topology = args[:preset_topology] if args.key?(:preset_topology) @route_tables = args[:route_tables] if args.key?(:route_tables) @routing_vpcs = args[:routing_vpcs] if args.key?(:routing_vpcs) @spoke_summary = args[:spoke_summary] if args.key?(:spoke_summary) @state = args[:state] if args.key?(:state) @unique_id = args[:unique_id] if args.key?(:unique_id) @update_time = args[:update_time] if args.key?(:update_time) end |