Class: Google::Apis::NetworkconnectivityV1::HubStatusEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

A hub status entry represents the status of a set of propagated Private Service Connect connections grouped by certain fields.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HubStatusEntry

Returns a new instance of HubStatusEntry.



1389
1390
1391
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1389

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

The number of propagated Private Service Connect connections with this status. If the group_by field was not set in the request message, the value of this field is 1. Corresponds to the JSON property count

Returns:

  • (Fixnum)


1375
1376
1377
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1375

def count
  @count
end

#group_byString

The fields that this entry is grouped by. This has the same value as the group_by field in the request message. Corresponds to the JSON property groupBy

Returns:

  • (String)


1381
1382
1383
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1381

def group_by
  @group_by
end

#psc_propagation_statusGoogle::Apis::NetworkconnectivityV1::PscPropagationStatus

The status of one or more propagated Private Service Connect connections in a hub. Corresponds to the JSON property pscPropagationStatus



1387
1388
1389
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1387

def psc_propagation_status
  @psc_propagation_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1394
1395
1396
1397
1398
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1394

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @group_by = args[:group_by] if args.key?(:group_by)
  @psc_propagation_status = args[:psc_propagation_status] if args.key?(:psc_propagation_status)
end