Class: Google::Apis::NetworkconnectivityV1::LinkedInterconnectAttachments
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::LinkedInterconnectAttachments
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
A collection of VLAN attachment resources. These resources should be redundant attachments that all advertise the same prefixes to Google Cloud. Alternatively, in active/passive configurations, all attachments should be capable of advertising the same prefixes.
Instance Attribute Summary collapse
-
#exclude_export_ranges ⇒ Array<String>
Optional.
-
#exclude_import_ranges ⇒ Array<String>
Optional.
-
#include_export_ranges ⇒ Array<String>
Optional.
-
#include_import_ranges ⇒ Array<String>
Optional.
-
#site_to_site_data_transfer ⇒ Boolean
(also: #site_to_site_data_transfer?)
A value that controls whether site-to-site data transfer is enabled for these resources.
-
#uris ⇒ Array<String>
The URIs of linked interconnect attachment resources Corresponds to the JSON property
uris. -
#vpc_network ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LinkedInterconnectAttachments
constructor
A new instance of LinkedInterconnectAttachments.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LinkedInterconnectAttachments
Returns a new instance of LinkedInterconnectAttachments.
1799 1800 1801 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1799 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exclude_export_ranges ⇒ Array<String>
Optional. Dynamic routes overlapped/encompassed by exclude export ranges are
excluded during export to hub.
Corresponds to the JSON property excludeExportRanges
1760 1761 1762 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1760 def exclude_export_ranges @exclude_export_ranges end |
#exclude_import_ranges ⇒ Array<String>
Optional. Hub routes overlapped/encompassed by exclude import ranges are
excluded during import from hub.
Corresponds to the JSON property excludeImportRanges
1766 1767 1768 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1766 def exclude_import_ranges @exclude_import_ranges end |
#include_export_ranges ⇒ Array<String>
Optional. Dynamic routes fully encompassed by include export ranges are
included during export to hub.
Corresponds to the JSON property includeExportRanges
1772 1773 1774 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1772 def include_export_ranges @include_export_ranges end |
#include_import_ranges ⇒ Array<String>
Optional. Hub routes fully encompassed by include import ranges are included
during import from hub.
Corresponds to the JSON property includeImportRanges
1778 1779 1780 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1778 def include_import_ranges @include_import_ranges end |
#site_to_site_data_transfer ⇒ Boolean Also known as: site_to_site_data_transfer?
A value that controls whether site-to-site data transfer is enabled for these
resources. Data transfer is available only in supported locations.
Corresponds to the JSON property siteToSiteDataTransfer
1786 1787 1788 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1786 def site_to_site_data_transfer @site_to_site_data_transfer end |
#uris ⇒ Array<String>
The URIs of linked interconnect attachment resources
Corresponds to the JSON property uris
1792 1793 1794 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1792 def uris @uris end |
#vpc_network ⇒ String
Output only. The VPC network where these VLAN attachments are located.
Corresponds to the JSON property vpcNetwork
1797 1798 1799 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1797 def vpc_network @vpc_network end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1804 1805 1806 1807 1808 1809 1810 1811 1812 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1804 def update!(**args) @exclude_export_ranges = args[:exclude_export_ranges] if args.key?(:exclude_export_ranges) @exclude_import_ranges = args[:exclude_import_ranges] if args.key?(:exclude_import_ranges) @include_export_ranges = args[:include_export_ranges] if args.key?(:include_export_ranges) @include_import_ranges = args[:include_import_ranges] if args.key?(:include_import_ranges) @site_to_site_data_transfer = args[:site_to_site_data_transfer] if args.key?(:site_to_site_data_transfer) @uris = args[:uris] if args.key?(:uris) @vpc_network = args[:vpc_network] if args.key?(:vpc_network) end |