Class: Google::Apis::NetworkconnectivityV1::LinkedInterconnectAttachments

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

A collection of VLAN attachment resources. These resources should be redundant attachments that all advertise the same prefixes to Google Cloud. Alternatively, in active/passive configurations, all attachments should be capable of advertising the same prefixes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LinkedInterconnectAttachments

Returns a new instance of LinkedInterconnectAttachments.



1781
1782
1783
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1781

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#include_import_rangesArray<String>

Optional. Hub routes fully encompassed by include import ranges are included during import from hub. Corresponds to the JSON property includeImportRanges

Returns:

  • (Array<String>)


1760
1761
1762
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1760

def include_import_ranges
  @include_import_ranges
end

#site_to_site_data_transferBoolean Also known as: site_to_site_data_transfer?

A value that controls whether site-to-site data transfer is enabled for these resources. Data transfer is available only in supported locations. Corresponds to the JSON property siteToSiteDataTransfer

Returns:

  • (Boolean)


1768
1769
1770
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1768

def site_to_site_data_transfer
  @site_to_site_data_transfer
end

#urisArray<String>

The URIs of linked interconnect attachment resources Corresponds to the JSON property uris

Returns:

  • (Array<String>)


1774
1775
1776
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1774

def uris
  @uris
end

#vpc_networkString

Output only. The VPC network where these VLAN attachments are located. Corresponds to the JSON property vpcNetwork

Returns:

  • (String)


1779
1780
1781
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1779

def vpc_network
  @vpc_network
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1786
1787
1788
1789
1790
1791
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1786

def update!(**args)
  @include_import_ranges = args[:include_import_ranges] if args.key?(:include_import_ranges)
  @site_to_site_data_transfer = args[:site_to_site_data_transfer] if args.key?(:site_to_site_data_transfer)
  @uris = args[:uris] if args.key?(:uris)
  @vpc_network = args[:vpc_network] if args.key?(:vpc_network)
end