Class: Google::Apis::NetworkconnectivityV1::LinkedRouterApplianceInstances
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::LinkedRouterApplianceInstances
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
A collection of router appliance instances. If you configure multiple router appliance instances to receive data from the same set of sites outside of Google Cloud, we recommend that you associate those instances with the same spoke.
Instance Attribute Summary collapse
-
#exclude_export_ranges ⇒ Array<String>
Optional.
-
#exclude_import_ranges ⇒ Array<String>
Optional.
-
#include_export_ranges ⇒ Array<String>
Optional.
-
#include_import_ranges ⇒ Array<String>
Optional.
-
#instances ⇒ Array<Google::Apis::NetworkconnectivityV1::RouterApplianceInstance>
The list of router appliance instances.
-
#site_to_site_data_transfer ⇒ Boolean
(also: #site_to_site_data_transfer?)
A value that controls whether site-to-site data transfer is enabled for these resources.
-
#vpc_network ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LinkedRouterApplianceInstances
constructor
A new instance of LinkedRouterApplianceInstances.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LinkedRouterApplianceInstances
Returns a new instance of LinkedRouterApplianceInstances.
2081 2082 2083 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2081 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exclude_export_ranges ⇒ Array<String>
Optional. Dynamic routes overlapped/encompassed by exclude export ranges are
excluded during export to hub.
Corresponds to the JSON property excludeExportRanges
2041 2042 2043 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2041 def exclude_export_ranges @exclude_export_ranges end |
#exclude_import_ranges ⇒ Array<String>
Optional. Hub routes overlapped/encompassed by exclude import ranges are
excluded during import from hub.
Corresponds to the JSON property excludeImportRanges
2047 2048 2049 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2047 def exclude_import_ranges @exclude_import_ranges end |
#include_export_ranges ⇒ Array<String>
Optional. Dynamic routes fully encompassed by include export ranges are
included during export to hub.
Corresponds to the JSON property includeExportRanges
2053 2054 2055 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2053 def include_export_ranges @include_export_ranges end |
#include_import_ranges ⇒ Array<String>
Optional. Hub routes fully encompassed by include import ranges are included
during import from hub.
Corresponds to the JSON property includeImportRanges
2059 2060 2061 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2059 def include_import_ranges @include_import_ranges end |
#instances ⇒ Array<Google::Apis::NetworkconnectivityV1::RouterApplianceInstance>
The list of router appliance instances.
Corresponds to the JSON property instances
2064 2065 2066 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2064 def instances @instances end |
#site_to_site_data_transfer ⇒ Boolean Also known as: site_to_site_data_transfer?
A value that controls whether site-to-site data transfer is enabled for these
resources. Data transfer is available only in supported locations.
Corresponds to the JSON property siteToSiteDataTransfer
2072 2073 2074 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2072 def site_to_site_data_transfer @site_to_site_data_transfer end |
#vpc_network ⇒ String
Output only. The VPC network where these router appliance instances are
located.
Corresponds to the JSON property vpcNetwork
2079 2080 2081 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2079 def vpc_network @vpc_network end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2086 2087 2088 2089 2090 2091 2092 2093 2094 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2086 def update!(**args) @exclude_export_ranges = args[:exclude_export_ranges] if args.key?(:exclude_export_ranges) @exclude_import_ranges = args[:exclude_import_ranges] if args.key?(:exclude_import_ranges) @include_export_ranges = args[:include_export_ranges] if args.key?(:include_export_ranges) @include_import_ranges = args[:include_import_ranges] if args.key?(:include_import_ranges) @instances = args[:instances] if args.key?(:instances) @site_to_site_data_transfer = args[:site_to_site_data_transfer] if args.key?(:site_to_site_data_transfer) @vpc_network = args[:vpc_network] if args.key?(:vpc_network) end |