Class: Google::Apis::NetworkconnectivityV1::LinkedRouterApplianceInstances

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

A collection of router appliance instances. If you configure multiple router appliance instances to receive data from the same set of sites outside of Google Cloud, we recommend that you associate those instances with the same spoke.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LinkedRouterApplianceInstances

Returns a new instance of LinkedRouterApplianceInstances.



1932
1933
1934
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1932

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exclude_export_rangesArray<String>

Optional. Dynamic routes overlapped/encompassed by exclude export ranges are excluded during export to hub. Corresponds to the JSON property excludeExportRanges

Returns:

  • (Array<String>)


1892
1893
1894
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1892

def exclude_export_ranges
  @exclude_export_ranges
end

#exclude_import_rangesArray<String>

Optional. Hub routes overlapped/encompassed by exclude import ranges are excluded during import from hub. Corresponds to the JSON property excludeImportRanges

Returns:

  • (Array<String>)


1898
1899
1900
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1898

def exclude_import_ranges
  @exclude_import_ranges
end

#include_export_rangesArray<String>

Optional. Dynamic routes fully encompassed by include export ranges are included during export to hub. Corresponds to the JSON property includeExportRanges

Returns:

  • (Array<String>)


1904
1905
1906
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1904

def include_export_ranges
  @include_export_ranges
end

#include_import_rangesArray<String>

Optional. Hub routes fully encompassed by include import ranges are included during import from hub. Corresponds to the JSON property includeImportRanges

Returns:

  • (Array<String>)


1910
1911
1912
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1910

def include_import_ranges
  @include_import_ranges
end

#instancesArray<Google::Apis::NetworkconnectivityV1::RouterApplianceInstance>

The list of router appliance instances. Corresponds to the JSON property instances



1915
1916
1917
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1915

def instances
  @instances
end

#site_to_site_data_transferBoolean Also known as: site_to_site_data_transfer?

A value that controls whether site-to-site data transfer is enabled for these resources. Data transfer is available only in supported locations. Corresponds to the JSON property siteToSiteDataTransfer

Returns:

  • (Boolean)


1923
1924
1925
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1923

def site_to_site_data_transfer
  @site_to_site_data_transfer
end

#vpc_networkString

Output only. The VPC network where these router appliance instances are located. Corresponds to the JSON property vpcNetwork

Returns:

  • (String)


1930
1931
1932
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1930

def vpc_network
  @vpc_network
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1937
1938
1939
1940
1941
1942
1943
1944
1945
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1937

def update!(**args)
  @exclude_export_ranges = args[:exclude_export_ranges] if args.key?(:exclude_export_ranges)
  @exclude_import_ranges = args[:exclude_import_ranges] if args.key?(:exclude_import_ranges)
  @include_export_ranges = args[:include_export_ranges] if args.key?(:include_export_ranges)
  @include_import_ranges = args[:include_import_ranges] if args.key?(:include_import_ranges)
  @instances = args[:instances] if args.key?(:instances)
  @site_to_site_data_transfer = args[:site_to_site_data_transfer] if args.key?(:site_to_site_data_transfer)
  @vpc_network = args[:vpc_network] if args.key?(:vpc_network)
end