Class: Google::Apis::NetworkconnectivityV1::LinkedRouterApplianceInstances

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

A collection of router appliance instances. If you configure multiple router appliance instances to receive data from the same set of sites outside of Google Cloud, we recommend that you associate those instances with the same spoke.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LinkedRouterApplianceInstances

Returns a new instance of LinkedRouterApplianceInstances.



1893
1894
1895
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1893

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#include_import_rangesArray<String>

Optional. Hub routes fully encompassed by include import ranges are included during import from hub. Corresponds to the JSON property includeImportRanges

Returns:

  • (Array<String>)


1871
1872
1873
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1871

def include_import_ranges
  @include_import_ranges
end

#instancesArray<Google::Apis::NetworkconnectivityV1::RouterApplianceInstance>

The list of router appliance instances. Corresponds to the JSON property instances



1876
1877
1878
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1876

def instances
  @instances
end

#site_to_site_data_transferBoolean Also known as: site_to_site_data_transfer?

A value that controls whether site-to-site data transfer is enabled for these resources. Data transfer is available only in supported locations. Corresponds to the JSON property siteToSiteDataTransfer

Returns:

  • (Boolean)


1884
1885
1886
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1884

def site_to_site_data_transfer
  @site_to_site_data_transfer
end

#vpc_networkString

Output only. The VPC network where these router appliance instances are located. Corresponds to the JSON property vpcNetwork

Returns:

  • (String)


1891
1892
1893
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1891

def vpc_network
  @vpc_network
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1898
1899
1900
1901
1902
1903
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1898

def update!(**args)
  @include_import_ranges = args[:include_import_ranges] if args.key?(:include_import_ranges)
  @instances = args[:instances] if args.key?(:instances)
  @site_to_site_data_transfer = args[:site_to_site_data_transfer] if args.key?(:site_to_site_data_transfer)
  @vpc_network = args[:vpc_network] if args.key?(:vpc_network)
end