Class: Google::Apis::NetworkconnectivityV1::LinkedVpcNetwork
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::LinkedVpcNetwork
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
An existing VPC network.
Instance Attribute Summary collapse
-
#exclude_export_ranges ⇒ Array<String>
Optional.
-
#include_export_ranges ⇒ Array<String>
Optional.
-
#producer_vpc_spokes ⇒ Array<String>
Output only.
-
#proposed_exclude_export_ranges ⇒ Array<String>
Output only.
-
#proposed_include_export_ranges ⇒ Array<String>
Output only.
-
#uri ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LinkedVpcNetwork
constructor
A new instance of LinkedVpcNetwork.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LinkedVpcNetwork
Returns a new instance of LinkedVpcNetwork.
1990 1991 1992 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1990 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exclude_export_ranges ⇒ Array<String>
Optional. IP ranges encompassing the subnets to be excluded from peering.
Corresponds to the JSON property excludeExportRanges
1955 1956 1957 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1955 def exclude_export_ranges @exclude_export_ranges end |
#include_export_ranges ⇒ Array<String>
Optional. IP ranges allowed to be included from peering.
Corresponds to the JSON property includeExportRanges
1960 1961 1962 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1960 def include_export_ranges @include_export_ranges end |
#producer_vpc_spokes ⇒ Array<String>
Output only. The list of Producer VPC spokes that this VPC spoke is a service
consumer VPC spoke for. These producer VPCs are connected through VPC peering
to this spoke's backing VPC network. Because they are directly connected
through VPC peering, NCC export filters do not apply between the service
consumer VPC spoke and any of its producer VPC spokes. This VPC spoke cannot
be deleted as long as any of these producer VPC spokes are connected to the
NCC Hub.
Corresponds to the JSON property producerVpcSpokes
1971 1972 1973 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1971 def producer_vpc_spokes @producer_vpc_spokes end |
#proposed_exclude_export_ranges ⇒ Array<String>
Output only. The proposed exclude export IP ranges waiting for hub
administrator's approval.
Corresponds to the JSON property proposedExcludeExportRanges
1977 1978 1979 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1977 def proposed_exclude_export_ranges @proposed_exclude_export_ranges end |
#proposed_include_export_ranges ⇒ Array<String>
Output only. The proposed include export IP ranges waiting for hub
administrator's approval.
Corresponds to the JSON property proposedIncludeExportRanges
1983 1984 1985 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1983 def proposed_include_export_ranges @proposed_include_export_ranges end |
#uri ⇒ String
Required. The URI of the VPC network resource.
Corresponds to the JSON property uri
1988 1989 1990 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1988 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1995 1996 1997 1998 1999 2000 2001 2002 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1995 def update!(**args) @exclude_export_ranges = args[:exclude_export_ranges] if args.key?(:exclude_export_ranges) @include_export_ranges = args[:include_export_ranges] if args.key?(:include_export_ranges) @producer_vpc_spokes = args[:producer_vpc_spokes] if args.key?(:producer_vpc_spokes) @proposed_exclude_export_ranges = args[:proposed_exclude_export_ranges] if args.key?(:proposed_exclude_export_ranges) @proposed_include_export_ranges = args[:proposed_include_export_ranges] if args.key?(:proposed_include_export_ranges) @uri = args[:uri] if args.key?(:uri) end |