Class: Google::Apis::NetworkconnectivityV1::LinkedVpcNetwork
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::LinkedVpcNetwork
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
An existing VPC network.
Instance Attribute Summary collapse
-
#exclude_export_ranges ⇒ Array<String>
Optional.
-
#include_export_ranges ⇒ Array<String>
Optional.
-
#producer_vpc_spokes ⇒ Array<String>
Output only.
-
#proposed_exclude_export_ranges ⇒ Array<String>
Output only.
-
#proposed_include_export_ranges ⇒ Array<String>
Output only.
-
#uri ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LinkedVpcNetwork
constructor
A new instance of LinkedVpcNetwork.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LinkedVpcNetwork
Returns a new instance of LinkedVpcNetwork.
1769 1770 1771 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1769 def initialize(**args) update!(**args) end |
Instance Attribute Details
#exclude_export_ranges ⇒ Array<String>
Optional. IP ranges encompassing the subnets to be excluded from peering.
Corresponds to the JSON property excludeExportRanges
1734 1735 1736 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1734 def exclude_export_ranges @exclude_export_ranges end |
#include_export_ranges ⇒ Array<String>
Optional. IP ranges allowed to be included from peering.
Corresponds to the JSON property includeExportRanges
1739 1740 1741 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1739 def include_export_ranges @include_export_ranges end |
#producer_vpc_spokes ⇒ Array<String>
Output only. The list of Producer VPC spokes that this VPC spoke is a service
consumer VPC spoke for. These producer VPCs are connected through VPC peering
to this spoke's backing VPC network. Because they are directly connected
through VPC peering, NCC export filters do not apply between the service
consumer VPC spoke and any of its producer VPC spokes. This VPC spoke cannot
be deleted as long as any of these producer VPC spokes are connected to the
NCC Hub.
Corresponds to the JSON property producerVpcSpokes
1750 1751 1752 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1750 def producer_vpc_spokes @producer_vpc_spokes end |
#proposed_exclude_export_ranges ⇒ Array<String>
Output only. The proposed exclude export IP ranges waiting for hub
administration's approval.
Corresponds to the JSON property proposedExcludeExportRanges
1756 1757 1758 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1756 def proposed_exclude_export_ranges @proposed_exclude_export_ranges end |
#proposed_include_export_ranges ⇒ Array<String>
Output only. The proposed include export IP ranges waiting for hub
administration's approval.
Corresponds to the JSON property proposedIncludeExportRanges
1762 1763 1764 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1762 def proposed_include_export_ranges @proposed_include_export_ranges end |
#uri ⇒ String
Required. The URI of the VPC network resource.
Corresponds to the JSON property uri
1767 1768 1769 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1767 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1774 1775 1776 1777 1778 1779 1780 1781 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1774 def update!(**args) @exclude_export_ranges = args[:exclude_export_ranges] if args.key?(:exclude_export_ranges) @include_export_ranges = args[:include_export_ranges] if args.key?(:include_export_ranges) @producer_vpc_spokes = args[:producer_vpc_spokes] if args.key?(:producer_vpc_spokes) @proposed_exclude_export_ranges = args[:proposed_exclude_export_ranges] if args.key?(:proposed_exclude_export_ranges) @proposed_include_export_ranges = args[:proposed_include_export_ranges] if args.key?(:proposed_include_export_ranges) @uri = args[:uri] if args.key?(:uri) end |