Class: Google::Apis::NetworkconnectivityV1::LinkedVpnTunnels

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

A collection of Cloud VPN tunnel resources. These resources should be redundant HA VPN tunnels that all advertise the same prefixes to Google Cloud. Alternatively, in a passive/active configuration, all tunnels should be capable of advertising the same prefixes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LinkedVpnTunnels

Returns a new instance of LinkedVpnTunnels.



2055
2056
2057
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2055

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exclude_export_rangesArray<String>

Optional. Dynamic routes overlapped/encompassed by exclude export ranges are excluded during export to hub. Corresponds to the JSON property excludeExportRanges

Returns:

  • (Array<String>)


2016
2017
2018
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2016

def exclude_export_ranges
  @exclude_export_ranges
end

#exclude_import_rangesArray<String>

Optional. Hub routes overlapped/encompassed by exclude import ranges are excluded during import from hub. Corresponds to the JSON property excludeImportRanges

Returns:

  • (Array<String>)


2022
2023
2024
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2022

def exclude_import_ranges
  @exclude_import_ranges
end

#include_export_rangesArray<String>

Optional. Dynamic routes fully encompassed by include export ranges are included during export to hub. Corresponds to the JSON property includeExportRanges

Returns:

  • (Array<String>)


2028
2029
2030
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2028

def include_export_ranges
  @include_export_ranges
end

#include_import_rangesArray<String>

Optional. Hub routes fully encompassed by include import ranges are included during import from hub. Corresponds to the JSON property includeImportRanges

Returns:

  • (Array<String>)


2034
2035
2036
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2034

def include_import_ranges
  @include_import_ranges
end

#site_to_site_data_transferBoolean Also known as: site_to_site_data_transfer?

A value that controls whether site-to-site data transfer is enabled for these resources. Data transfer is available only in supported locations. Corresponds to the JSON property siteToSiteDataTransfer

Returns:

  • (Boolean)


2042
2043
2044
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2042

def site_to_site_data_transfer
  @site_to_site_data_transfer
end

#urisArray<String>

The URIs of linked VPN tunnel resources. Corresponds to the JSON property uris

Returns:

  • (Array<String>)


2048
2049
2050
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2048

def uris
  @uris
end

#vpc_networkString

Output only. The VPC network where these VPN tunnels are located. Corresponds to the JSON property vpcNetwork

Returns:

  • (String)


2053
2054
2055
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2053

def vpc_network
  @vpc_network
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2060
2061
2062
2063
2064
2065
2066
2067
2068
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2060

def update!(**args)
  @exclude_export_ranges = args[:exclude_export_ranges] if args.key?(:exclude_export_ranges)
  @exclude_import_ranges = args[:exclude_import_ranges] if args.key?(:exclude_import_ranges)
  @include_export_ranges = args[:include_export_ranges] if args.key?(:include_export_ranges)
  @include_import_ranges = args[:include_import_ranges] if args.key?(:include_import_ranges)
  @site_to_site_data_transfer = args[:site_to_site_data_transfer] if args.key?(:site_to_site_data_transfer)
  @uris = args[:uris] if args.key?(:uris)
  @vpc_network = args[:vpc_network] if args.key?(:vpc_network)
end