Class: Google::Apis::NetworkconnectivityV1::LinkedVpnTunnels

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

A collection of Cloud VPN tunnel resources. These resources should be redundant HA VPN tunnels that all advertise the same prefixes to Google Cloud. Alternatively, in a passive/active configuration, all tunnels should be capable of advertising the same prefixes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LinkedVpnTunnels

Returns a new instance of LinkedVpnTunnels.



1995
1996
1997
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1995

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#include_import_rangesArray<String>

Optional. Hub routes fully encompassed by include import ranges are included during import from hub. Corresponds to the JSON property includeImportRanges

Returns:

  • (Array<String>)


1974
1975
1976
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1974

def include_import_ranges
  @include_import_ranges
end

#site_to_site_data_transferBoolean Also known as: site_to_site_data_transfer?

A value that controls whether site-to-site data transfer is enabled for these resources. Data transfer is available only in supported locations. Corresponds to the JSON property siteToSiteDataTransfer

Returns:

  • (Boolean)


1982
1983
1984
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1982

def site_to_site_data_transfer
  @site_to_site_data_transfer
end

#urisArray<String>

The URIs of linked VPN tunnel resources. Corresponds to the JSON property uris

Returns:

  • (Array<String>)


1988
1989
1990
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1988

def uris
  @uris
end

#vpc_networkString

Output only. The VPC network where these VPN tunnels are located. Corresponds to the JSON property vpcNetwork

Returns:

  • (String)


1993
1994
1995
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1993

def vpc_network
  @vpc_network
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2000
2001
2002
2003
2004
2005
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2000

def update!(**args)
  @include_import_ranges = args[:include_import_ranges] if args.key?(:include_import_ranges)
  @site_to_site_data_transfer = args[:site_to_site_data_transfer] if args.key?(:site_to_site_data_transfer)
  @uris = args[:uris] if args.key?(:uris)
  @vpc_network = args[:vpc_network] if args.key?(:vpc_network)
end