Class: Google::Apis::NetworkconnectivityV1::LinkedVpnTunnels
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::LinkedVpnTunnels
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
A collection of Cloud VPN tunnel resources. These resources should be redundant HA VPN tunnels that all advertise the same prefixes to Google Cloud. Alternatively, in a passive/active configuration, all tunnels should be capable of advertising the same prefixes.
Instance Attribute Summary collapse
-
#include_import_ranges ⇒ Array<String>
Optional.
-
#site_to_site_data_transfer ⇒ Boolean
(also: #site_to_site_data_transfer?)
A value that controls whether site-to-site data transfer is enabled for these resources.
-
#uris ⇒ Array<String>
The URIs of linked VPN tunnel resources.
-
#vpc_network ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LinkedVpnTunnels
constructor
A new instance of LinkedVpnTunnels.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LinkedVpnTunnels
Returns a new instance of LinkedVpnTunnels.
1816 1817 1818 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1816 def initialize(**args) update!(**args) end |
Instance Attribute Details
#include_import_ranges ⇒ Array<String>
Optional. Hub routes fully encompassed by include import ranges are included
during import from hub.
Corresponds to the JSON property includeImportRanges
1795 1796 1797 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1795 def include_import_ranges @include_import_ranges end |
#site_to_site_data_transfer ⇒ Boolean Also known as: site_to_site_data_transfer?
A value that controls whether site-to-site data transfer is enabled for these
resources. Data transfer is available only in supported locations.
Corresponds to the JSON property siteToSiteDataTransfer
1803 1804 1805 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1803 def site_to_site_data_transfer @site_to_site_data_transfer end |
#uris ⇒ Array<String>
The URIs of linked VPN tunnel resources.
Corresponds to the JSON property uris
1809 1810 1811 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1809 def uris @uris end |
#vpc_network ⇒ String
Output only. The VPC network where these VPN tunnels are located.
Corresponds to the JSON property vpcNetwork
1814 1815 1816 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1814 def vpc_network @vpc_network end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1821 1822 1823 1824 1825 1826 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 1821 def update!(**args) @include_import_ranges = args[:include_import_ranges] if args.key?(:include_import_ranges) @site_to_site_data_transfer = args[:site_to_site_data_transfer] if args.key?(:site_to_site_data_transfer) @uris = args[:uris] if args.key?(:uris) @vpc_network = args[:vpc_network] if args.key?(:vpc_network) end |