Class: Google::Apis::NetworkconnectivityV1::ListGatewayAdvertisedRoutesResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::ListGatewayAdvertisedRoutesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
Response for HubService.ListGatewayAdvertisedRoutes method.
Instance Attribute Summary collapse
-
#gateway_advertised_routes ⇒ Array<Google::Apis::NetworkconnectivityV1::GatewayAdvertisedRoute>
The requested gateway advertised routes.
-
#next_page_token ⇒ String
The token for the next page of the response.
-
#unreachable ⇒ Array<String>
Hubs that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListGatewayAdvertisedRoutesResponse
constructor
A new instance of ListGatewayAdvertisedRoutesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListGatewayAdvertisedRoutesResponse
Returns a new instance of ListGatewayAdvertisedRoutesResponse.
2304 2305 2306 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2304 def initialize(**args) update!(**args) end |
Instance Attribute Details
#gateway_advertised_routes ⇒ Array<Google::Apis::NetworkconnectivityV1::GatewayAdvertisedRoute>
The requested gateway advertised routes.
Corresponds to the JSON property gatewayAdvertisedRoutes
2290 2291 2292 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2290 def gateway_advertised_routes @gateway_advertised_routes end |
#next_page_token ⇒ String
The token for the next page of the response. To see more results, use this
value as the page_token for your next request. If this value is empty, there
are no more results.
Corresponds to the JSON property nextPageToken
2297 2298 2299 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2297 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Hubs that could not be reached.
Corresponds to the JSON property unreachable
2302 2303 2304 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2302 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2309 2310 2311 2312 2313 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2309 def update!(**args) @gateway_advertised_routes = args[:gateway_advertised_routes] if args.key?(:gateway_advertised_routes) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |