Class: Google::Apis::NetworkconnectivityV1::ListMulticloudDataTransferSupportedServicesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

Response message to list the services in your project in regions that are eligible for Data Transfer Essentials configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListMulticloudDataTransferSupportedServicesResponse

Returns a new instance of ListMulticloudDataTransferSupportedServicesResponse.



2274
2275
2276
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2274

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#multicloud_data_transfer_supported_servicesArray<Google::Apis::NetworkconnectivityV1::MulticloudDataTransferSupportedService>

The list of supported services. Corresponds to the JSON property multicloudDataTransferSupportedServices



2267
2268
2269
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2267

def multicloud_data_transfer_supported_services
  @multicloud_data_transfer_supported_services
end

#next_page_tokenString

The next page token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2272
2273
2274
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2272

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2279
2280
2281
2282
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2279

def update!(**args)
  @multicloud_data_transfer_supported_services = args[:multicloud_data_transfer_supported_services] if args.key?(:multicloud_data_transfer_supported_services)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end