Class: Google::Apis::NetworkconnectivityV1::ListRouteTablesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

Response for HubService.ListRouteTables method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListRouteTablesResponse

Returns a new instance of ListRouteTablesResponse.



2159
2160
2161
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2159

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The token for the next page of the response. To see more results, use this value as the page_token for your next request. If this value is empty, there are no more results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2147
2148
2149
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2147

def next_page_token
  @next_page_token
end

#route_tablesArray<Google::Apis::NetworkconnectivityV1::RouteTable>

The requested route tables. Corresponds to the JSON property routeTables



2152
2153
2154
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2152

def route_tables
  @route_tables
end

#unreachableArray<String>

Hubs that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2157
2158
2159
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2157

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2164
2165
2166
2167
2168
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2164

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @route_tables = args[:route_tables] if args.key?(:route_tables)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end