Class: Google::Apis::NetworkconnectivityV1::ListSpokesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

The response for HubService.ListSpokes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListSpokesResponse

Returns a new instance of ListSpokesResponse.



2353
2354
2355
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2353

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The token for the next page of the response. To see more results, use this value as the page_token for your next request. If this value is empty, there are no more results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2341
2342
2343
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2341

def next_page_token
  @next_page_token
end

#spokesArray<Google::Apis::NetworkconnectivityV1::Spoke>

The requested spokes. Corresponds to the JSON property spokes



2346
2347
2348
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2346

def spokes
  @spokes
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2351
2352
2353
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2351

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2358
2359
2360
2361
2362
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2358

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @spokes = args[:spokes] if args.key?(:spokes)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end