Class: Google::Apis::NetworkconnectivityV1::ListTransportsResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::ListTransportsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
Message for response to listing Transports.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#transports ⇒ Array<Google::Apis::NetworkconnectivityV1::Transport>
The list of Transport.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListTransportsResponse
constructor
A new instance of ListTransportsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListTransportsResponse
Returns a new instance of ListTransportsResponse.
2689 2690 2691 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2689 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
2677 2678 2679 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2677 def next_page_token @next_page_token end |
#transports ⇒ Array<Google::Apis::NetworkconnectivityV1::Transport>
The list of Transport.
Corresponds to the JSON property transports
2682 2683 2684 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2682 def transports @transports end |
#unreachable ⇒ Array<String>
Unordered list. Locations that could not be reached.
Corresponds to the JSON property unreachable
2687 2688 2689 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2687 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2694 2695 2696 2697 2698 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2694 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @transports = args[:transports] if args.key?(:transports) @unreachable = args[:unreachable] if args.key?(:unreachable) end |