Class: Google::Apis::NetworkconnectivityV1::MulticloudDataTransferConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

The MulticloudDataTransferConfig resource. It lists the services that you configure for Data Transfer Essentials billing and metering.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MulticloudDataTransferConfig

Returns a new instance of MulticloudDataTransferConfig.



2741
2742
2743
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2741

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when the MulticloudDataTransferConfig resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2680
2681
2682
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2680

def create_time
  @create_time
end

#descriptionString

Optional. A description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


2685
2686
2687
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2685

def description
  @description
end

#destinations_active_countFixnum

Output only. The number of Destination resources in use with the MulticloudDataTransferConfig resource. Corresponds to the JSON property destinationsActiveCount

Returns:

  • (Fixnum)


2691
2692
2693
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2691

def destinations_active_count
  @destinations_active_count
end

#destinations_countFixnum

Output only. The number of Destination resources configured for the MulticloudDataTransferConfig resource. Corresponds to the JSON property destinationsCount

Returns:

  • (Fixnum)


2697
2698
2699
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2697

def destinations_count
  @destinations_count
end

#etagString

The etag is computed by the server, and might be sent with update and delete requests so that the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


2703
2704
2705
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2703

def etag
  @etag
end

#labelsHash<String,String>

Optional. User-defined labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2708
2709
2710
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2708

def labels
  @labels
end

#nameString

Identifier. The name of the MulticloudDataTransferConfig resource. Format: projects/project/locations/location/multicloudDataTransferConfigs/ multicloud_data_transfer_config`. Corresponds to the JSON propertyname`

Returns:

  • (String)


2715
2716
2717
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2715

def name
  @name
end

#servicesHash<String,Google::Apis::NetworkconnectivityV1::StateTimeline>

Optional. Maps services to their current or planned states. Service names are keys, and the associated values describe the state of the service. If a state change is expected, the value is either ADDING or DELETING, depending on the actions taken. Sample output: "services": "big-query": "states": [ " effectiveTime": "2024-12-12T08:00:00Z" "state": "ADDING",, ] , "cloud- storage": "states": [ "state": "ACTIVE", ] Corresponds to the JSON property services



2725
2726
2727
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2725

def services
  @services
end

#uidString

Output only. The Google-generated unique ID for the MulticloudDataTransferConfig resource. This value is unique across all MulticloudDataTransferConfig resources. If a resource is deleted and another with the same name is created, the new resource is assigned a different and unique ID. Corresponds to the JSON property uid

Returns:

  • (String)


2734
2735
2736
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2734

def uid
  @uid
end

#update_timeString

Output only. Time when the MulticloudDataTransferConfig resource was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2739
2740
2741
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2739

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2746
2747
2748
2749
2750
2751
2752
2753
2754
2755
2756
2757
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2746

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @destinations_active_count = args[:destinations_active_count] if args.key?(:destinations_active_count)
  @destinations_count = args[:destinations_count] if args.key?(:destinations_count)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @services = args[:services] if args.key?(:services)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end