Class: Google::Apis::NetworkconnectivityV1::MulticloudDataTransferConfig
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::MulticloudDataTransferConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
The MulticloudDataTransferConfig resource. It lists the services that you
configure for Data Transfer Essentials billing and metering.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#destinations_active_count ⇒ Fixnum
Output only.
-
#destinations_count ⇒ Fixnum
Output only.
-
#etag ⇒ String
The etag is computed by the server, and might be sent with update and delete requests so that the client has an up-to-date value before proceeding.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#services ⇒ Hash<String,Google::Apis::NetworkconnectivityV1::StateTimeline>
Optional.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MulticloudDataTransferConfig
constructor
A new instance of MulticloudDataTransferConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MulticloudDataTransferConfig
Returns a new instance of MulticloudDataTransferConfig.
2530 2531 2532 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2530 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Time when the MulticloudDataTransferConfig resource was created.
Corresponds to the JSON property createTime
2469 2470 2471 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2469 def create_time @create_time end |
#description ⇒ String
Optional. A description of this resource.
Corresponds to the JSON property description
2474 2475 2476 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2474 def description @description end |
#destinations_active_count ⇒ Fixnum
Output only. The number of Destination resources in use with the
MulticloudDataTransferConfig resource.
Corresponds to the JSON property destinationsActiveCount
2480 2481 2482 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2480 def destinations_active_count @destinations_active_count end |
#destinations_count ⇒ Fixnum
Output only. The number of Destination resources configured for the
MulticloudDataTransferConfig resource.
Corresponds to the JSON property destinationsCount
2486 2487 2488 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2486 def destinations_count @destinations_count end |
#etag ⇒ String
The etag is computed by the server, and might be sent with update and delete
requests so that the client has an up-to-date value before proceeding.
Corresponds to the JSON property etag
2492 2493 2494 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2492 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. User-defined labels.
Corresponds to the JSON property labels
2497 2498 2499 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2497 def labels @labels end |
#name ⇒ String
Identifier. The name of the MulticloudDataTransferConfig resource. Format:
projects/project/locations/location/multicloudDataTransferConfigs/
multicloud_data_transfer_config`.
Corresponds to the JSON propertyname`
2504 2505 2506 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2504 def name @name end |
#services ⇒ Hash<String,Google::Apis::NetworkconnectivityV1::StateTimeline>
Optional. Maps services to their current or planned states. Service names are
keys, and the associated values describe the state of the service. If a state
change is expected, the value is either ADDING or DELETING, depending on
the actions taken. Sample output: "services": "big-query": "states": [ "
effectiveTime": "2024-12-12T08:00:00Z" "state": "ADDING",, ] , "cloud-
storage": "states": [ "state": "ACTIVE", ]
Corresponds to the JSON property services
2514 2515 2516 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2514 def services @services end |
#uid ⇒ String
Output only. The Google-generated unique ID for the
MulticloudDataTransferConfig resource. This value is unique across all
MulticloudDataTransferConfig resources. If a resource is deleted and another
with the same name is created, the new resource is assigned a different and
unique ID.
Corresponds to the JSON property uid
2523 2524 2525 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2523 def uid @uid end |
#update_time ⇒ String
Output only. Time when the MulticloudDataTransferConfig resource was updated.
Corresponds to the JSON property updateTime
2528 2529 2530 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2528 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2535 2536 2537 2538 2539 2540 2541 2542 2543 2544 2545 2546 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2535 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @destinations_active_count = args[:destinations_active_count] if args.key?(:destinations_active_count) @destinations_count = args[:destinations_count] if args.key?(:destinations_count) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @services = args[:services] if args.key?(:services) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |