Class: Google::Apis::NetworkconnectivityV1::MulticloudDataTransferSupportedService
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::MulticloudDataTransferSupportedService
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
A service in your project in a region that is eligible for Data Transfer Essentials configuration.
Instance Attribute Summary collapse
-
#name ⇒ String
Identifier.
-
#service_configs ⇒ Array<Google::Apis::NetworkconnectivityV1::ServiceConfig>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MulticloudDataTransferSupportedService
constructor
A new instance of MulticloudDataTransferSupportedService.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MulticloudDataTransferSupportedService
Returns a new instance of MulticloudDataTransferSupportedService.
2776 2777 2778 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2776 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Identifier. The name of the service.
Corresponds to the JSON property name
2768 2769 2770 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2768 def name @name end |
#service_configs ⇒ Array<Google::Apis::NetworkconnectivityV1::ServiceConfig>
Output only. The network service tier or regional endpoint supported for the
service.
Corresponds to the JSON property serviceConfigs
2774 2775 2776 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2774 def service_configs @service_configs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2781 2782 2783 2784 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2781 def update!(**args) @name = args[:name] if args.key?(:name) @service_configs = args[:service_configs] if args.key?(:service_configs) end |