Class: Google::Apis::NetworkconnectivityV1::MulticloudDataTransferSupportedService
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::MulticloudDataTransferSupportedService
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
A service in your project in a region that is eligible for Data Transfer Essentials configuration.
Instance Attribute Summary collapse
-
#name ⇒ String
Identifier.
-
#service_configs ⇒ Array<Google::Apis::NetworkconnectivityV1::ServiceConfig>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MulticloudDataTransferSupportedService
constructor
A new instance of MulticloudDataTransferSupportedService.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MulticloudDataTransferSupportedService
Returns a new instance of MulticloudDataTransferSupportedService.
2565 2566 2567 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2565 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Identifier. The name of the service.
Corresponds to the JSON property name
2557 2558 2559 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2557 def name @name end |
#service_configs ⇒ Array<Google::Apis::NetworkconnectivityV1::ServiceConfig>
Output only. The network service tier or regional endpoint supported for the
service.
Corresponds to the JSON property serviceConfigs
2563 2564 2565 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2563 def service_configs @service_configs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2570 2571 2572 2573 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2570 def update!(**args) @name = args[:name] if args.key?(:name) @service_configs = args[:service_configs] if args.key?(:service_configs) end |