Class: Google::Apis::NetworkconnectivityV1::NextHopInterconnectAttachment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

A route next hop that leads to an interconnect attachment resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NextHopInterconnectAttachment

Returns a new instance of NextHopInterconnectAttachment.



2810
2811
2812
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2810

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#site_to_site_data_transferBoolean Also known as: site_to_site_data_transfer?

Indicates whether site-to-site data transfer is allowed for this interconnect attachment resource. Data transfer is available only in supported locations. Corresponds to the JSON property siteToSiteDataTransfer

Returns:

  • (Boolean)


2797
2798
2799
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2797

def site_to_site_data_transfer
  @site_to_site_data_transfer
end

#uriString

The URI of the interconnect attachment resource. Corresponds to the JSON property uri

Returns:

  • (String)


2803
2804
2805
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2803

def uri
  @uri
end

#vpc_networkString

The VPC network where this interconnect attachment is located. Corresponds to the JSON property vpcNetwork

Returns:

  • (String)


2808
2809
2810
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2808

def vpc_network
  @vpc_network
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2815
2816
2817
2818
2819
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2815

def update!(**args)
  @site_to_site_data_transfer = args[:site_to_site_data_transfer] if args.key?(:site_to_site_data_transfer)
  @uri = args[:uri] if args.key?(:uri)
  @vpc_network = args[:vpc_network] if args.key?(:vpc_network)
end