Class: Google::Apis::NetworkconnectivityV1::NextHopRouterApplianceInstance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

A route next hop that leads to a Router appliance instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NextHopRouterApplianceInstance

Returns a new instance of NextHopRouterApplianceInstance.



2970
2971
2972
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2970

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#site_to_site_data_transferBoolean Also known as: site_to_site_data_transfer?

Indicates whether site-to-site data transfer is allowed for this Router appliance instance resource. Data transfer is available only in supported locations. Corresponds to the JSON property siteToSiteDataTransfer

Returns:

  • (Boolean)


2957
2958
2959
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2957

def site_to_site_data_transfer
  @site_to_site_data_transfer
end

#uriString

The URI of the Router appliance instance. Corresponds to the JSON property uri

Returns:

  • (String)


2963
2964
2965
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2963

def uri
  @uri
end

#vpc_networkString

The VPC network where this VM is located. Corresponds to the JSON property vpcNetwork

Returns:

  • (String)


2968
2969
2970
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2968

def vpc_network
  @vpc_network
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2975
2976
2977
2978
2979
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2975

def update!(**args)
  @site_to_site_data_transfer = args[:site_to_site_data_transfer] if args.key?(:site_to_site_data_transfer)
  @uri = args[:uri] if args.key?(:uri)
  @vpc_network = args[:vpc_network] if args.key?(:vpc_network)
end