Class: Google::Apis::NetworkconnectivityV1::NextHopRouterApplianceInstance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

A route next hop that leads to a Router appliance instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NextHopRouterApplianceInstance

Returns a new instance of NextHopRouterApplianceInstance.



2634
2635
2636
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2634

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#site_to_site_data_transferBoolean Also known as: site_to_site_data_transfer?

Indicates whether site-to-site data transfer is allowed for this Router appliance instance resource. Data transfer is available only in supported locations. Corresponds to the JSON property siteToSiteDataTransfer

Returns:

  • (Boolean)


2621
2622
2623
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2621

def site_to_site_data_transfer
  @site_to_site_data_transfer
end

#uriString

The URI of the Router appliance instance. Corresponds to the JSON property uri

Returns:

  • (String)


2627
2628
2629
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2627

def uri
  @uri
end

#vpc_networkString

The VPC network where this VM is located. Corresponds to the JSON property vpcNetwork

Returns:

  • (String)


2632
2633
2634
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2632

def vpc_network
  @vpc_network
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2639
2640
2641
2642
2643
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2639

def update!(**args)
  @site_to_site_data_transfer = args[:site_to_site_data_transfer] if args.key?(:site_to_site_data_transfer)
  @uri = args[:uri] if args.key?(:uri)
  @vpc_network = args[:vpc_network] if args.key?(:vpc_network)
end