Class: Google::Apis::NetworkconnectivityV1::NextHopSpoke

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

A route next hop that leads to a spoke resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NextHopSpoke

Returns a new instance of NextHopSpoke.



2666
2667
2668
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2666

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#site_to_site_data_transferBoolean Also known as: site_to_site_data_transfer?

Indicates whether site-to-site data transfer is allowed for this spoke resource. Data transfer is available only in supported locations. Whether this route is accessible to other hybrid spokes with site-to-site data transfer enabled. If this is false, the route is only accessible to VPC spokes of the connected Hub. Corresponds to the JSON property siteToSiteDataTransfer

Returns:

  • (Boolean)


2658
2659
2660
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2658

def site_to_site_data_transfer
  @site_to_site_data_transfer
end

#uriString

The URI of the spoke resource. Corresponds to the JSON property uri

Returns:

  • (String)


2664
2665
2666
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2664

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2671
2672
2673
2674
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2671

def update!(**args)
  @site_to_site_data_transfer = args[:site_to_site_data_transfer] if args.key?(:site_to_site_data_transfer)
  @uri = args[:uri] if args.key?(:uri)
end