Class: Google::Apis::NetworkconnectivityV1::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

Represents the metadata of the long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



2774
2775
2776
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2774

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


2738
2739
2740
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2738

def api_version
  @api_version
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2743
2744
2745
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2743

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


2748
2749
2750
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2748

def end_time
  @end_time
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have been cancelled successfully have google. longrunning.Operation.error value with a google.rpc.Status.code of 1, corresponding to Code.CANCELLED. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


2756
2757
2758
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2756

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


2762
2763
2764
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2762

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


2767
2768
2769
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2767

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


2772
2773
2774
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2772

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2779
2780
2781
2782
2783
2784
2785
2786
2787
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 2779

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end