Class: Google::Apis::NetworkconnectivityV1::PscConfig
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::PscConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
Configuration used for Private Service Connect connections. Used when Infrastructure is PSC.
Instance Attribute Summary collapse
-
#allowed_google_producers_resource_hierarchy_level ⇒ Array<String>
Optional.
-
#limit ⇒ Fixnum
Optional.
-
#producer_instance_location ⇒ String
Optional.
-
#subnetworks ⇒ Array<String>
The resource paths of subnetworks to use for IP address management.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PscConfig
constructor
A new instance of PscConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PscConfig
Returns a new instance of PscConfig.
3279 3280 3281 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3279 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_google_producers_resource_hierarchy_level ⇒ Array<String>
Optional. List of Projects, Folders, or Organizations from where the Producer
instance can be within. For example, a network administrator can provide both '
organizations/foo' and 'projects/bar' as
allowed_google_producers_resource_hierarchy_levels. This allowlists this
network to connect with any Producer instance within the 'foo' organization or
the 'bar' project. By default,
allowed_google_producers_resource_hierarchy_level is empty. The format for
each allowed_google_producers_resource_hierarchy_level is / where is one of '
projects', 'folders', or 'organizations' and is either the ID or the number of
the resource type. Format for each
allowed_google_producers_resource_hierarchy_level value: 'projects/' or '
folders/' or 'organizations/' Eg. [projects/my-project-id, projects/567,
folders/891, organizations/123]
Corresponds to the JSON property allowedGoogleProducersResourceHierarchyLevel
3259 3260 3261 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3259 def allowed_google_producers_resource_hierarchy_level @allowed_google_producers_resource_hierarchy_level end |
#limit ⇒ Fixnum
Optional. Max number of PSC connections for this policy.
Corresponds to the JSON property limit
3264 3265 3266 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3264 def limit @limit end |
#producer_instance_location ⇒ String
Optional. ProducerInstanceLocation is used to specify which authorization
mechanism to use to determine which projects the Producer instance can be
within.
Corresponds to the JSON property producerInstanceLocation
3271 3272 3273 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3271 def producer_instance_location @producer_instance_location end |
#subnetworks ⇒ Array<String>
The resource paths of subnetworks to use for IP address management. Example:
projects/projectNumOrId/regions/region/subnetworks/resourceId.
Corresponds to the JSON property subnetworks
3277 3278 3279 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3277 def subnetworks @subnetworks end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3284 3285 3286 3287 3288 3289 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3284 def update!(**args) @allowed_google_producers_resource_hierarchy_level = args[:allowed_google_producers_resource_hierarchy_level] if args.key?(:allowed_google_producers_resource_hierarchy_level) @limit = args[:limit] if args.key?(:limit) @producer_instance_location = args[:producer_instance_location] if args.key?(:producer_instance_location) @subnetworks = args[:subnetworks] if args.key?(:subnetworks) end |