Class: Google::Apis::NetworkconnectivityV1::PscConnection

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

Information about a specific Private Service Connect connection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PscConnection

Returns a new instance of PscConnection.



3383
3384
3385
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3383

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumer_addressString

The resource reference of the consumer address. Corresponds to the JSON property consumerAddress

Returns:

  • (String)


3299
3300
3301
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3299

def consumer_address
  @consumer_address
end

#consumer_forwarding_ruleString

The resource reference of the PSC Forwarding Rule within the consumer VPC. Corresponds to the JSON property consumerForwardingRule

Returns:

  • (String)


3304
3305
3306
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3304

def consumer_forwarding_rule
  @consumer_forwarding_rule
end

#consumer_target_projectString

The project where the PSC connection is created. Corresponds to the JSON property consumerTargetProject

Returns:

  • (String)


3309
3310
3311
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3309

def consumer_target_project
  @consumer_target_project
end

#errorGoogle::Apis::NetworkconnectivityV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



3319
3320
3321
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3319

def error
  @error
end

#error_infoGoogle::Apis::NetworkconnectivityV1::GoogleRpcErrorInfo

Describes the cause of the error with structured details. Example of an error when contacting the "pubsub.googleapis.com" API when it is not enabled: " reason": "API_DISABLED" "domain": "googleapis.com" "metadata": "resource": " projects/123", "service": "pubsub.googleapis.com" This response indicates that the pubsub.googleapis.com API is not enabled. Example of an error that is returned when attempting to create a Spanner instance in a region that is out of stock: "reason": "STOCKOUT" "domain": "spanner.googleapis.com", "metadata" : "availableRegions": "us-central1,us-east2" Corresponds to the JSON property errorInfo



3331
3332
3333
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3331

def error_info
  @error_info
end

#error_typeString

The error type indicates whether the error is consumer facing, producer facing or system internal. Corresponds to the JSON property errorType

Returns:

  • (String)


3337
3338
3339
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3337

def error_type
  @error_type
end

#gce_operationString

The last Compute Engine operation to setup PSC connection. Corresponds to the JSON property gceOperation

Returns:

  • (String)


3342
3343
3344
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3342

def gce_operation
  @gce_operation
end

#ip_versionString

The requested IP version for the PSC connection. Corresponds to the JSON property ipVersion

Returns:

  • (String)


3347
3348
3349
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3347

def ip_version
  @ip_version
end

#producer_instance_idString

Immutable. Deprecated. Use producer_instance_metadata instead. An immutable identifier for the producer instance. Corresponds to the JSON property producerInstanceId

Returns:

  • (String)


3353
3354
3355
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3353

def producer_instance_id
  @producer_instance_id
end

#producer_instance_metadataHash<String,String>

Immutable. An immutable map for the producer instance metadata. Corresponds to the JSON property producerInstanceMetadata

Returns:

  • (Hash<String,String>)


3358
3359
3360
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3358

def 
  @producer_instance_metadata
end

#psc_connection_idString

The PSC connection id of the PSC forwarding rule. Corresponds to the JSON property pscConnectionId

Returns:

  • (String)


3363
3364
3365
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3363

def psc_connection_id
  @psc_connection_id
end

#selected_subnetworkString

Output only. The URI of the subnetwork selected to allocate IP address for this connection. Corresponds to the JSON property selectedSubnetwork

Returns:

  • (String)


3369
3370
3371
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3369

def selected_subnetwork
  @selected_subnetwork
end

#service_classString

Output only. [Output only] The service class associated with this PSC Connection. The value is derived from the SCPolicy and matches the service class name provided by the customer. Corresponds to the JSON property serviceClass

Returns:

  • (String)


3376
3377
3378
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3376

def service_class
  @service_class
end

#stateString

State of the PSC Connection Corresponds to the JSON property state

Returns:

  • (String)


3381
3382
3383
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3381

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3388
3389
3390
3391
3392
3393
3394
3395
3396
3397
3398
3399
3400
3401
3402
3403
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3388

def update!(**args)
  @consumer_address = args[:consumer_address] if args.key?(:consumer_address)
  @consumer_forwarding_rule = args[:consumer_forwarding_rule] if args.key?(:consumer_forwarding_rule)
  @consumer_target_project = args[:consumer_target_project] if args.key?(:consumer_target_project)
  @error = args[:error] if args.key?(:error)
  @error_info = args[:error_info] if args.key?(:error_info)
  @error_type = args[:error_type] if args.key?(:error_type)
  @gce_operation = args[:gce_operation] if args.key?(:gce_operation)
  @ip_version = args[:ip_version] if args.key?(:ip_version)
  @producer_instance_id = args[:producer_instance_id] if args.key?(:producer_instance_id)
  @producer_instance_metadata = args[:producer_instance_metadata] if args.key?(:producer_instance_metadata)
  @psc_connection_id = args[:psc_connection_id] if args.key?(:psc_connection_id)
  @selected_subnetwork = args[:selected_subnetwork] if args.key?(:selected_subnetwork)
  @service_class = args[:service_class] if args.key?(:service_class)
  @state = args[:state] if args.key?(:state)
end