Class: Google::Apis::NetworkconnectivityV1::PscConnection
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::PscConnection
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
Information about a specific Private Service Connect connection.
Instance Attribute Summary collapse
-
#consumer_address ⇒ String
The resource reference of the consumer address.
-
#consumer_forwarding_rule ⇒ String
The resource reference of the PSC Forwarding Rule within the consumer VPC.
-
#consumer_target_project ⇒ String
The project where the PSC connection is created.
-
#error ⇒ Google::Apis::NetworkconnectivityV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#error_info ⇒ Google::Apis::NetworkconnectivityV1::GoogleRpcErrorInfo
Describes the cause of the error with structured details.
-
#error_type ⇒ String
The error type indicates whether the error is consumer facing, producer facing or system internal.
-
#gce_operation ⇒ String
The last Compute Engine operation to setup PSC connection.
-
#ip_version ⇒ String
The requested IP version for the PSC connection.
-
#producer_instance_id ⇒ String
Immutable.
-
#producer_instance_metadata ⇒ Hash<String,String>
Immutable.
-
#psc_connection_id ⇒ String
The PSC connection id of the PSC forwarding rule.
-
#selected_subnetwork ⇒ String
Output only.
-
#service_class ⇒ String
Output only.
-
#state ⇒ String
State of the PSC Connection Corresponds to the JSON property
state.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PscConnection
constructor
A new instance of PscConnection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PscConnection
Returns a new instance of PscConnection.
3172 3173 3174 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3172 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consumer_address ⇒ String
The resource reference of the consumer address.
Corresponds to the JSON property consumerAddress
3088 3089 3090 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3088 def consumer_address @consumer_address end |
#consumer_forwarding_rule ⇒ String
The resource reference of the PSC Forwarding Rule within the consumer VPC.
Corresponds to the JSON property consumerForwardingRule
3093 3094 3095 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3093 def consumer_forwarding_rule @consumer_forwarding_rule end |
#consumer_target_project ⇒ String
The project where the PSC connection is created.
Corresponds to the JSON property consumerTargetProject
3098 3099 3100 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3098 def consumer_target_project @consumer_target_project end |
#error ⇒ Google::Apis::NetworkconnectivityV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
3108 3109 3110 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3108 def error @error end |
#error_info ⇒ Google::Apis::NetworkconnectivityV1::GoogleRpcErrorInfo
Describes the cause of the error with structured details. Example of an error
when contacting the "pubsub.googleapis.com" API when it is not enabled: "
reason": "API_DISABLED" "domain": "googleapis.com" "metadata": "resource": "
projects/123", "service": "pubsub.googleapis.com" This response indicates
that the pubsub.googleapis.com API is not enabled. Example of an error that is
returned when attempting to create a Spanner instance in a region that is out
of stock: "reason": "STOCKOUT" "domain": "spanner.googleapis.com", "metadata"
: "availableRegions": "us-central1,us-east2"
Corresponds to the JSON property errorInfo
3120 3121 3122 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3120 def error_info @error_info end |
#error_type ⇒ String
The error type indicates whether the error is consumer facing, producer facing
or system internal.
Corresponds to the JSON property errorType
3126 3127 3128 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3126 def error_type @error_type end |
#gce_operation ⇒ String
The last Compute Engine operation to setup PSC connection.
Corresponds to the JSON property gceOperation
3131 3132 3133 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3131 def gce_operation @gce_operation end |
#ip_version ⇒ String
The requested IP version for the PSC connection.
Corresponds to the JSON property ipVersion
3136 3137 3138 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3136 def ip_version @ip_version end |
#producer_instance_id ⇒ String
Immutable. Deprecated. Use producer_instance_metadata instead. An immutable
identifier for the producer instance.
Corresponds to the JSON property producerInstanceId
3142 3143 3144 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3142 def producer_instance_id @producer_instance_id end |
#producer_instance_metadata ⇒ Hash<String,String>
Immutable. An immutable map for the producer instance metadata.
Corresponds to the JSON property producerInstanceMetadata
3147 3148 3149 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3147 def @producer_instance_metadata end |
#psc_connection_id ⇒ String
The PSC connection id of the PSC forwarding rule.
Corresponds to the JSON property pscConnectionId
3152 3153 3154 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3152 def psc_connection_id @psc_connection_id end |
#selected_subnetwork ⇒ String
Output only. The URI of the subnetwork selected to allocate IP address for
this connection.
Corresponds to the JSON property selectedSubnetwork
3158 3159 3160 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3158 def selected_subnetwork @selected_subnetwork end |
#service_class ⇒ String
Output only. [Output only] The service class associated with this PSC
Connection. The value is derived from the SCPolicy and matches the service
class name provided by the customer.
Corresponds to the JSON property serviceClass
3165 3166 3167 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3165 def service_class @service_class end |
#state ⇒ String
State of the PSC Connection
Corresponds to the JSON property state
3170 3171 3172 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3170 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3177 3178 3179 3180 3181 3182 3183 3184 3185 3186 3187 3188 3189 3190 3191 3192 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3177 def update!(**args) @consumer_address = args[:consumer_address] if args.key?(:consumer_address) @consumer_forwarding_rule = args[:consumer_forwarding_rule] if args.key?(:consumer_forwarding_rule) @consumer_target_project = args[:consumer_target_project] if args.key?(:consumer_target_project) @error = args[:error] if args.key?(:error) @error_info = args[:error_info] if args.key?(:error_info) @error_type = args[:error_type] if args.key?(:error_type) @gce_operation = args[:gce_operation] if args.key?(:gce_operation) @ip_version = args[:ip_version] if args.key?(:ip_version) @producer_instance_id = args[:producer_instance_id] if args.key?(:producer_instance_id) @producer_instance_metadata = args[:producer_instance_metadata] if args.key?(:producer_instance_metadata) @psc_connection_id = args[:psc_connection_id] if args.key?(:psc_connection_id) @selected_subnetwork = args[:selected_subnetwork] if args.key?(:selected_subnetwork) @service_class = args[:service_class] if args.key?(:service_class) @state = args[:state] if args.key?(:state) end |