Class: Google::Apis::NetworkconnectivityV1::PscPropagationStatus
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::PscPropagationStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
The status of one or more propagated Private Service Connect connections in a hub.
Instance Attribute Summary collapse
-
#code ⇒ String
The propagation status.
-
#message ⇒ String
The human-readable summary of the Private Service Connect connection propagation status.
-
#source_forwarding_rule ⇒ String
The name of the forwarding rule exported to the hub.
-
#source_group ⇒ String
The name of the group that the source spoke belongs to.
-
#source_spoke ⇒ String
The name of the spoke that the source forwarding rule belongs to.
-
#target_group ⇒ String
The name of the group that the target spoke belongs to.
-
#target_spoke ⇒ String
The name of the spoke that the source forwarding rule propagates to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PscPropagationStatus
constructor
A new instance of PscPropagationStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PscPropagationStatus
Returns a new instance of PscPropagationStatus.
3754 3755 3756 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3754 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
The propagation status.
Corresponds to the JSON property code
3721 3722 3723 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3721 def code @code end |
#message ⇒ String
The human-readable summary of the Private Service Connect connection
propagation status.
Corresponds to the JSON property message
3727 3728 3729 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3727 def @message end |
#source_forwarding_rule ⇒ String
The name of the forwarding rule exported to the hub.
Corresponds to the JSON property sourceForwardingRule
3732 3733 3734 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3732 def source_forwarding_rule @source_forwarding_rule end |
#source_group ⇒ String
The name of the group that the source spoke belongs to.
Corresponds to the JSON property sourceGroup
3737 3738 3739 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3737 def source_group @source_group end |
#source_spoke ⇒ String
The name of the spoke that the source forwarding rule belongs to.
Corresponds to the JSON property sourceSpoke
3742 3743 3744 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3742 def source_spoke @source_spoke end |
#target_group ⇒ String
The name of the group that the target spoke belongs to.
Corresponds to the JSON property targetGroup
3747 3748 3749 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3747 def target_group @target_group end |
#target_spoke ⇒ String
The name of the spoke that the source forwarding rule propagates to.
Corresponds to the JSON property targetSpoke
3752 3753 3754 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3752 def target_spoke @target_spoke end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3759 3760 3761 3762 3763 3764 3765 3766 3767 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3759 def update!(**args) @code = args[:code] if args.key?(:code) @message = args[:message] if args.key?(:message) @source_forwarding_rule = args[:source_forwarding_rule] if args.key?(:source_forwarding_rule) @source_group = args[:source_group] if args.key?(:source_group) @source_spoke = args[:source_spoke] if args.key?(:source_spoke) @target_group = args[:target_group] if args.key?(:target_group) @target_spoke = args[:target_spoke] if args.key?(:target_spoke) end |