Class: Google::Apis::NetworkconnectivityV1::PscPropagationStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

The status of one or more propagated Private Service Connect connections in a hub.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PscPropagationStatus

Returns a new instance of PscPropagationStatus.



3572
3573
3574
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3572

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

The propagation status. Corresponds to the JSON property code

Returns:

  • (String)


3539
3540
3541
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3539

def code
  @code
end

#messageString

The human-readable summary of the Private Service Connect connection propagation status. Corresponds to the JSON property message

Returns:

  • (String)


3545
3546
3547
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3545

def message
  @message
end

#source_forwarding_ruleString

The name of the forwarding rule exported to the hub. Corresponds to the JSON property sourceForwardingRule

Returns:

  • (String)


3550
3551
3552
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3550

def source_forwarding_rule
  @source_forwarding_rule
end

#source_groupString

The name of the group that the source spoke belongs to. Corresponds to the JSON property sourceGroup

Returns:

  • (String)


3555
3556
3557
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3555

def source_group
  @source_group
end

#source_spokeString

The name of the spoke that the source forwarding rule belongs to. Corresponds to the JSON property sourceSpoke

Returns:

  • (String)


3560
3561
3562
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3560

def source_spoke
  @source_spoke
end

#target_groupString

The name of the group that the target spoke belongs to. Corresponds to the JSON property targetGroup

Returns:

  • (String)


3565
3566
3567
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3565

def target_group
  @target_group
end

#target_spokeString

The name of the spoke that the source forwarding rule propagates to. Corresponds to the JSON property targetSpoke

Returns:

  • (String)


3570
3571
3572
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3570

def target_spoke
  @target_spoke
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3577
3578
3579
3580
3581
3582
3583
3584
3585
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3577

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @message = args[:message] if args.key?(:message)
  @source_forwarding_rule = args[:source_forwarding_rule] if args.key?(:source_forwarding_rule)
  @source_group = args[:source_group] if args.key?(:source_group)
  @source_spoke = args[:source_spoke] if args.key?(:source_spoke)
  @target_group = args[:target_group] if args.key?(:target_group)
  @target_spoke = args[:target_spoke] if args.key?(:target_spoke)
end