Class: Google::Apis::NetworkconnectivityV1::PscPropagationStatus
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::PscPropagationStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
The status of one or more propagated Private Service Connect connections in a hub.
Instance Attribute Summary collapse
-
#code ⇒ String
The propagation status.
-
#message ⇒ String
The human-readable summary of the Private Service Connect connection propagation status.
-
#source_forwarding_rule ⇒ String
The name of the forwarding rule exported to the hub.
-
#source_group ⇒ String
The name of the group that the source spoke belongs to.
-
#source_spoke ⇒ String
The name of the spoke that the source forwarding rule belongs to.
-
#target_group ⇒ String
The name of the group that the target spoke belongs to.
-
#target_spoke ⇒ String
The name of the spoke that the source forwarding rule propagates to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PscPropagationStatus
constructor
A new instance of PscPropagationStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PscPropagationStatus
Returns a new instance of PscPropagationStatus.
3447 3448 3449 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3447 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
The propagation status.
Corresponds to the JSON property code
3414 3415 3416 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3414 def code @code end |
#message ⇒ String
The human-readable summary of the Private Service Connect connection
propagation status.
Corresponds to the JSON property message
3420 3421 3422 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3420 def @message end |
#source_forwarding_rule ⇒ String
The name of the forwarding rule exported to the hub.
Corresponds to the JSON property sourceForwardingRule
3425 3426 3427 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3425 def source_forwarding_rule @source_forwarding_rule end |
#source_group ⇒ String
The name of the group that the source spoke belongs to.
Corresponds to the JSON property sourceGroup
3430 3431 3432 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3430 def source_group @source_group end |
#source_spoke ⇒ String
The name of the spoke that the source forwarding rule belongs to.
Corresponds to the JSON property sourceSpoke
3435 3436 3437 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3435 def source_spoke @source_spoke end |
#target_group ⇒ String
The name of the group that the target spoke belongs to.
Corresponds to the JSON property targetGroup
3440 3441 3442 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3440 def target_group @target_group end |
#target_spoke ⇒ String
The name of the spoke that the source forwarding rule propagates to.
Corresponds to the JSON property targetSpoke
3445 3446 3447 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3445 def target_spoke @target_spoke end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3452 3453 3454 3455 3456 3457 3458 3459 3460 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3452 def update!(**args) @code = args[:code] if args.key?(:code) @message = args[:message] if args.key?(:message) @source_forwarding_rule = args[:source_forwarding_rule] if args.key?(:source_forwarding_rule) @source_group = args[:source_group] if args.key?(:source_group) @source_spoke = args[:source_spoke] if args.key?(:source_spoke) @target_group = args[:target_group] if args.key?(:target_group) @target_spoke = args[:target_spoke] if args.key?(:target_spoke) end |