Class: Google::Apis::NetworkconnectivityV1::PscPropagationStatus
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::PscPropagationStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
The status of one or more propagated Private Service Connect connections in a hub.
Instance Attribute Summary collapse
-
#code ⇒ String
The propagation status.
-
#message ⇒ String
The human-readable summary of the Private Service Connect connection propagation status.
-
#source_forwarding_rule ⇒ String
The name of the forwarding rule exported to the hub.
-
#source_group ⇒ String
The name of the group that the source spoke belongs to.
-
#source_spoke ⇒ String
The name of the spoke that the source forwarding rule belongs to.
-
#target_group ⇒ String
The name of the group that the target spoke belongs to.
-
#target_spoke ⇒ String
The name of the spoke that the source forwarding rule propagates to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PscPropagationStatus
constructor
A new instance of PscPropagationStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PscPropagationStatus
Returns a new instance of PscPropagationStatus.
3236 3237 3238 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3236 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
The propagation status.
Corresponds to the JSON property code
3203 3204 3205 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3203 def code @code end |
#message ⇒ String
The human-readable summary of the Private Service Connect connection
propagation status.
Corresponds to the JSON property message
3209 3210 3211 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3209 def @message end |
#source_forwarding_rule ⇒ String
The name of the forwarding rule exported to the hub.
Corresponds to the JSON property sourceForwardingRule
3214 3215 3216 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3214 def source_forwarding_rule @source_forwarding_rule end |
#source_group ⇒ String
The name of the group that the source spoke belongs to.
Corresponds to the JSON property sourceGroup
3219 3220 3221 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3219 def source_group @source_group end |
#source_spoke ⇒ String
The name of the spoke that the source forwarding rule belongs to.
Corresponds to the JSON property sourceSpoke
3224 3225 3226 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3224 def source_spoke @source_spoke end |
#target_group ⇒ String
The name of the group that the target spoke belongs to.
Corresponds to the JSON property targetGroup
3229 3230 3231 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3229 def target_group @target_group end |
#target_spoke ⇒ String
The name of the spoke that the source forwarding rule propagates to.
Corresponds to the JSON property targetSpoke
3234 3235 3236 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3234 def target_spoke @target_spoke end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3241 3242 3243 3244 3245 3246 3247 3248 3249 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3241 def update!(**args) @code = args[:code] if args.key?(:code) @message = args[:message] if args.key?(:message) @source_forwarding_rule = args[:source_forwarding_rule] if args.key?(:source_forwarding_rule) @source_group = args[:source_group] if args.key?(:source_group) @source_spoke = args[:source_spoke] if args.key?(:source_spoke) @target_group = args[:target_group] if args.key?(:target_group) @target_spoke = args[:target_spoke] if args.key?(:target_spoke) end |