Class: Google::Apis::NetworkconnectivityV1::QueryHubStatusResponse
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::QueryHubStatusResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
The response for HubService.QueryHubStatus.
Instance Attribute Summary collapse
-
#hub_status_entries ⇒ Array<Google::Apis::NetworkconnectivityV1::HubStatusEntry>
The list of hub status.
-
#next_page_token ⇒ String
The token for the next page of the response.
Instance Method Summary collapse
-
#initialize(**args) ⇒ QueryHubStatusResponse
constructor
A new instance of QueryHubStatusResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ QueryHubStatusResponse
Returns a new instance of QueryHubStatusResponse.
3268 3269 3270 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3268 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hub_status_entries ⇒ Array<Google::Apis::NetworkconnectivityV1::HubStatusEntry>
The list of hub status.
Corresponds to the JSON property hubStatusEntries
3259 3260 3261 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3259 def hub_status_entries @hub_status_entries end |
#next_page_token ⇒ String
The token for the next page of the response. To see more results, use this
value as the page_token for your next request. If this value is empty, there
are no more results.
Corresponds to the JSON property nextPageToken
3266 3267 3268 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3266 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3273 3274 3275 3276 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3273 def update!(**args) @hub_status_entries = args[:hub_status_entries] if args.key?(:hub_status_entries) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |