Class: Google::Apis::NetworkconnectivityV1::RegionalEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::RegionalEndpoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
The RegionalEndpoint resource.
Instance Attribute Summary collapse
-
#access_type ⇒ String
Required.
-
#address ⇒ String
Optional.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#ip_address ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
User-defined labels.
-
#name ⇒ String
Output only.
-
#network ⇒ String
Optional.
-
#psc_forwarding_rule ⇒ String
Output only.
-
#subnetwork ⇒ String
Optional.
-
#target_google_api ⇒ String
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionalEndpoint
constructor
A new instance of RegionalEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionalEndpoint
Returns a new instance of RegionalEndpoint.
3692 3693 3694 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3692 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_type ⇒ String
Required. The access type of this regional endpoint. This field is reflected
in the PSC Forwarding Rule configuration to enable global access.
Corresponds to the JSON property accessType
3623 3624 3625 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3623 def access_type @access_type end |
#address ⇒ String
Optional. The IP Address of the Regional Endpoint. When no address is provided,
an IP from the subnetwork is allocated. Use one of the following formats: *
IPv4 address as in 10.0.0.1 * Address resource URI as in projects/project/
regions/region/addresses/address_name`for an IPv4 or IPv6 address.
Corresponds to the JSON propertyaddress`
3631 3632 3633 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3631 def address @address end |
#create_time ⇒ String
Output only. Time when the RegionalEndpoint was created.
Corresponds to the JSON property createTime
3636 3637 3638 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3636 def create_time @create_time end |
#description ⇒ String
Optional. A description of this resource.
Corresponds to the JSON property description
3641 3642 3643 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3641 def description @description end |
#ip_address ⇒ String
Output only. The literal IP address of the PSC Forwarding Rule created on
behalf of the customer. This field is deprecated. Use address instead.
Corresponds to the JSON property ipAddress
3647 3648 3649 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3647 def ip_address @ip_address end |
#labels ⇒ Hash<String,String>
User-defined labels.
Corresponds to the JSON property labels
3652 3653 3654 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3652 def labels @labels end |
#name ⇒ String
Output only. The name of a RegionalEndpoint. Pattern: projects/project/
locations/location/regionalEndpoints/^[-a-z0-9](?:[-a-z0-9]0,44)[a-z0-9]$.
Corresponds to the JSON property name
3658 3659 3660 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3658 def name @name end |
#network ⇒ String
Optional. The name of the VPC network for this private regional endpoint.
Format: projects/project/global/networks/network`
Corresponds to the JSON propertynetwork`
3664 3665 3666 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3664 def network @network end |
#psc_forwarding_rule ⇒ String
Output only. The resource reference of the PSC Forwarding Rule created on
behalf of the customer. Format: //compute.googleapis.com/projects/project/
regions/region/forwardingRules/forwarding_rule_name`
Corresponds to the JSON propertypscForwardingRule`
3671 3672 3673 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3671 def psc_forwarding_rule @psc_forwarding_rule end |
#subnetwork ⇒ String
Optional. The name of the subnetwork from which the IP address will be
allocated. Format: projects/project/regions/region/subnetworks/
subnetwork`
Corresponds to the JSON propertysubnetwork`
3678 3679 3680 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3678 def subnetwork @subnetwork end |
#target_google_api ⇒ String
Required. The service endpoint this private regional endpoint connects to.
Format: `apiname.region.p.rep.googleapis.comExample: "cloudkms.us-
central1.p.rep.googleapis.com".
Corresponds to the JSON propertytargetGoogleApi`
3685 3686 3687 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3685 def target_google_api @target_google_api end |
#update_time ⇒ String
Output only. Time when the RegionalEndpoint was updated.
Corresponds to the JSON property updateTime
3690 3691 3692 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3690 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3697 3698 3699 3700 3701 3702 3703 3704 3705 3706 3707 3708 3709 3710 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3697 def update!(**args) @access_type = args[:access_type] if args.key?(:access_type) @address = args[:address] if args.key?(:address) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @ip_address = args[:ip_address] if args.key?(:ip_address) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @psc_forwarding_rule = args[:psc_forwarding_rule] if args.key?(:psc_forwarding_rule) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) @target_google_api = args[:target_google_api] if args.key?(:target_google_api) @update_time = args[:update_time] if args.key?(:update_time) end |