Class: Google::Apis::NetworkconnectivityV1::RegionalEndpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

The RegionalEndpoint resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionalEndpoint

Returns a new instance of RegionalEndpoint.



3567
3568
3569
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3567

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_typeString

Required. The access type of this regional endpoint. This field is reflected in the PSC Forwarding Rule configuration to enable global access. Corresponds to the JSON property accessType

Returns:

  • (String)


3498
3499
3500
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3498

def access_type
  @access_type
end

#addressString

Optional. The IP Address of the Regional Endpoint. When no address is provided, an IP from the subnetwork is allocated. Use one of the following formats: * IPv4 address as in 10.0.0.1 * Address resource URI as in projects/project/ regions/region/addresses/address_name`for an IPv4 or IPv6 address. Corresponds to the JSON propertyaddress`

Returns:

  • (String)


3506
3507
3508
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3506

def address
  @address
end

#create_timeString

Output only. Time when the RegionalEndpoint was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3511
3512
3513
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3511

def create_time
  @create_time
end

#descriptionString

Optional. A description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


3516
3517
3518
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3516

def description
  @description
end

#ip_addressString

Output only. The literal IP address of the PSC Forwarding Rule created on behalf of the customer. This field is deprecated. Use address instead. Corresponds to the JSON property ipAddress

Returns:

  • (String)


3522
3523
3524
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3522

def ip_address
  @ip_address
end

#labelsHash<String,String>

User-defined labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3527
3528
3529
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3527

def labels
  @labels
end

#nameString

Output only. The name of a RegionalEndpoint. Pattern: projects/project/ locations/location/regionalEndpoints/^[-a-z0-9](?:[-a-z0-9]0,44)[a-z0-9]$. Corresponds to the JSON property name

Returns:

  • (String)


3533
3534
3535
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3533

def name
  @name
end

#networkString

Optional. The name of the VPC network for this private regional endpoint. Format: projects/project/global/networks/network` Corresponds to the JSON propertynetwork`

Returns:

  • (String)


3539
3540
3541
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3539

def network
  @network
end

#psc_forwarding_ruleString

Output only. The resource reference of the PSC Forwarding Rule created on behalf of the customer. Format: //compute.googleapis.com/projects/project/ regions/region/forwardingRules/forwarding_rule_name` Corresponds to the JSON propertypscForwardingRule`

Returns:

  • (String)


3546
3547
3548
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3546

def psc_forwarding_rule
  @psc_forwarding_rule
end

#subnetworkString

Optional. The name of the subnetwork from which the IP address will be allocated. Format: projects/project/regions/region/subnetworks/ subnetwork` Corresponds to the JSON propertysubnetwork`

Returns:

  • (String)


3553
3554
3555
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3553

def subnetwork
  @subnetwork
end

#target_google_apiString

Required. The service endpoint this private regional endpoint connects to. Format: `apiname.region.p.rep.googleapis.comExample: "cloudkms.us- central1.p.rep.googleapis.com". Corresponds to the JSON propertytargetGoogleApi`

Returns:

  • (String)


3560
3561
3562
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3560

def target_google_api
  @target_google_api
end

#update_timeString

Output only. Time when the RegionalEndpoint was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3565
3566
3567
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3565

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3572
3573
3574
3575
3576
3577
3578
3579
3580
3581
3582
3583
3584
3585
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3572

def update!(**args)
  @access_type = args[:access_type] if args.key?(:access_type)
  @address = args[:address] if args.key?(:address)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @psc_forwarding_rule = args[:psc_forwarding_rule] if args.key?(:psc_forwarding_rule)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
  @target_google_api = args[:target_google_api] if args.key?(:target_google_api)
  @update_time = args[:update_time] if args.key?(:update_time)
end