Class: Google::Apis::NetworkconnectivityV1::RegionalEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::RegionalEndpoint
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
The RegionalEndpoint resource.
Instance Attribute Summary collapse
-
#access_type ⇒ String
Required.
-
#address ⇒ String
Optional.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#ip_address ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
User-defined labels.
-
#name ⇒ String
Output only.
-
#network ⇒ String
Optional.
-
#psc_forwarding_rule ⇒ String
Output only.
-
#subnetwork ⇒ String
Optional.
-
#target_google_api ⇒ String
Required.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionalEndpoint
constructor
A new instance of RegionalEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionalEndpoint
Returns a new instance of RegionalEndpoint.
3356 3357 3358 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3356 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_type ⇒ String
Required. The access type of this regional endpoint. This field is reflected
in the PSC Forwarding Rule configuration to enable global access.
Corresponds to the JSON property accessType
3287 3288 3289 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3287 def access_type @access_type end |
#address ⇒ String
Optional. The IP Address of the Regional Endpoint. When no address is provided,
an IP from the subnetwork is allocated. Use one of the following formats: *
IPv4 address as in 10.0.0.1 * Address resource URI as in projects/project/
regions/region/addresses/address_name`for an IPv4 or IPv6 address.
Corresponds to the JSON propertyaddress`
3295 3296 3297 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3295 def address @address end |
#create_time ⇒ String
Output only. Time when the RegionalEndpoint was created.
Corresponds to the JSON property createTime
3300 3301 3302 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3300 def create_time @create_time end |
#description ⇒ String
Optional. A description of this resource.
Corresponds to the JSON property description
3305 3306 3307 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3305 def description @description end |
#ip_address ⇒ String
Output only. The literal IP address of the PSC Forwarding Rule created on
behalf of the customer. This field is deprecated. Use address instead.
Corresponds to the JSON property ipAddress
3311 3312 3313 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3311 def ip_address @ip_address end |
#labels ⇒ Hash<String,String>
User-defined labels.
Corresponds to the JSON property labels
3316 3317 3318 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3316 def labels @labels end |
#name ⇒ String
Output only. The name of a RegionalEndpoint. Pattern: projects/project/
locations/location/regionalEndpoints/^[-a-z0-9](?:[-a-z0-9]0,44)[a-z0-9]$.
Corresponds to the JSON property name
3322 3323 3324 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3322 def name @name end |
#network ⇒ String
Optional. The name of the VPC network for this private regional endpoint.
Format: projects/project/global/networks/network`
Corresponds to the JSON propertynetwork`
3328 3329 3330 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3328 def network @network end |
#psc_forwarding_rule ⇒ String
Output only. The resource reference of the PSC Forwarding Rule created on
behalf of the customer. Format: //compute.googleapis.com/projects/project/
regions/region/forwardingRules/forwarding_rule_name`
Corresponds to the JSON propertypscForwardingRule`
3335 3336 3337 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3335 def psc_forwarding_rule @psc_forwarding_rule end |
#subnetwork ⇒ String
Optional. The name of the subnetwork from which the IP address will be
allocated. Format: projects/project/regions/region/subnetworks/
subnetwork`
Corresponds to the JSON propertysubnetwork`
3342 3343 3344 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3342 def subnetwork @subnetwork end |
#target_google_api ⇒ String
Required. The service endpoint this private regional endpoint connects to.
Format: `apiname.region.p.rep.googleapis.comExample: "cloudkms.us-
central1.p.rep.googleapis.com".
Corresponds to the JSON propertytargetGoogleApi`
3349 3350 3351 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3349 def target_google_api @target_google_api end |
#update_time ⇒ String
Output only. Time when the RegionalEndpoint was updated.
Corresponds to the JSON property updateTime
3354 3355 3356 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3354 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3361 3362 3363 3364 3365 3366 3367 3368 3369 3370 3371 3372 3373 3374 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3361 def update!(**args) @access_type = args[:access_type] if args.key?(:access_type) @address = args[:address] if args.key?(:address) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @ip_address = args[:ip_address] if args.key?(:ip_address) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @psc_forwarding_rule = args[:psc_forwarding_rule] if args.key?(:psc_forwarding_rule) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) @target_google_api = args[:target_google_api] if args.key?(:target_google_api) @update_time = args[:update_time] if args.key?(:update_time) end |