Class: Google::Apis::NetworkconnectivityV1::RejectHubSpokeRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

The request for HubService.RejectHubSpoke.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RejectHubSpokeRequest

Returns a new instance of RejectHubSpokeRequest.



3742
3743
3744
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3742

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detailsString

Optional. Additional information provided by the hub administrator. Corresponds to the JSON property details

Returns:

  • (String)


3720
3721
3722
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3720

def details
  @details
end

#request_idString

Optional. A request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server knows to ignore the request if it has already been completed. The server guarantees that a request doesn't result in creation of duplicate commitments for at least 60 minutes. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check to see whether the original operation was received. If it was, the server ignores the second request. This behavior prevents clients from mistakenly creating duplicate commitments. The request ID must be a valid UUID, with the exception that zero UUID is not supported (00000000-0000-0000-0000- 000000000000). Corresponds to the JSON property requestId

Returns:

  • (String)


3735
3736
3737
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3735

def request_id
  @request_id
end

#spoke_uriString

Required. The URI of the spoke to reject from the hub. Corresponds to the JSON property spokeUri

Returns:

  • (String)


3740
3741
3742
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3740

def spoke_uri
  @spoke_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3747
3748
3749
3750
3751
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3747

def update!(**args)
  @details = args[:details] if args.key?(:details)
  @request_id = args[:request_id] if args.key?(:request_id)
  @spoke_uri = args[:spoke_uri] if args.key?(:spoke_uri)
end