Class: Google::Apis::NetworkconnectivityV1::RejectSpokeUpdateRequest
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::RejectSpokeUpdateRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
The request for HubService.RejectSpokeUpdate.
Instance Attribute Summary collapse
-
#details ⇒ String
Optional.
-
#request_id ⇒ String
Optional.
-
#spoke_etag ⇒ String
Required.
-
#spoke_uri ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RejectSpokeUpdateRequest
constructor
A new instance of RejectSpokeUpdateRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RejectSpokeUpdateRequest
Returns a new instance of RejectSpokeUpdateRequest.
4102 4103 4104 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4102 def initialize(**args) update!(**args) end |
Instance Attribute Details
#details ⇒ String
Optional. Additional information provided by the hub administrator.
Corresponds to the JSON property details
4075 4076 4077 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4075 def details @details end |
#request_id ⇒ String
Optional. A request ID to identify requests. Specify a unique request ID so
that if you must retry your request, the server knows to ignore the request if
it has already been completed. The server guarantees that a request doesn't
result in creation of duplicate commitments for at least 60 minutes. For
example, consider a situation where you make an initial request and the
request times out. If you make the request again with the same request ID, the
server can check to see whether the original operation was received. If it was,
the server ignores the second request. This behavior prevents clients from
mistakenly creating duplicate commitments. The request ID must be a valid UUID,
with the exception that zero UUID is not supported (00000000-0000-0000-0000-
000000000000).
Corresponds to the JSON property requestId
4090 4091 4092 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4090 def request_id @request_id end |
#spoke_etag ⇒ String
Required. The etag of the spoke to reject update.
Corresponds to the JSON property spokeEtag
4095 4096 4097 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4095 def spoke_etag @spoke_etag end |
#spoke_uri ⇒ String
Required. The URI of the spoke to reject update.
Corresponds to the JSON property spokeUri
4100 4101 4102 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4100 def spoke_uri @spoke_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4107 4108 4109 4110 4111 4112 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4107 def update!(**args) @details = args[:details] if args.key?(:details) @request_id = args[:request_id] if args.key?(:request_id) @spoke_etag = args[:spoke_etag] if args.key?(:spoke_etag) @spoke_uri = args[:spoke_uri] if args.key?(:spoke_uri) end |