Class: Google::Apis::NetworkconnectivityV1::RejectSpokeUpdateRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

The request for HubService.RejectSpokeUpdate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RejectSpokeUpdateRequest

Returns a new instance of RejectSpokeUpdateRequest.



3811
3812
3813
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3811

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detailsString

Optional. Additional information provided by the hub administrator. Corresponds to the JSON property details

Returns:

  • (String)


3784
3785
3786
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3784

def details
  @details
end

#request_idString

Optional. A request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server knows to ignore the request if it has already been completed. The server guarantees that a request doesn't result in creation of duplicate commitments for at least 60 minutes. For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check to see whether the original operation was received. If it was, the server ignores the second request. This behavior prevents clients from mistakenly creating duplicate commitments. The request ID must be a valid UUID, with the exception that zero UUID is not supported (00000000-0000-0000-0000- 000000000000). Corresponds to the JSON property requestId

Returns:

  • (String)


3799
3800
3801
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3799

def request_id
  @request_id
end

#spoke_etagString

Required. The etag of the spoke to reject update. Corresponds to the JSON property spokeEtag

Returns:

  • (String)


3804
3805
3806
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3804

def spoke_etag
  @spoke_etag
end

#spoke_uriString

Required. The URI of the spoke to reject update. Corresponds to the JSON property spokeUri

Returns:

  • (String)


3809
3810
3811
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3809

def spoke_uri
  @spoke_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3816
3817
3818
3819
3820
3821
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3816

def update!(**args)
  @details = args[:details] if args.key?(:details)
  @request_id = args[:request_id] if args.key?(:request_id)
  @spoke_etag = args[:spoke_etag] if args.key?(:spoke_etag)
  @spoke_uri = args[:spoke_uri] if args.key?(:spoke_uri)
end