Class: Google::Apis::NetworkconnectivityV1::RemoteTransportProfile
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::RemoteTransportProfile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
Message describing RemoteTransportProfile object.
Instance Attribute Summary collapse
-
#description ⇒ String
Output only.
-
#display_name ⇒ String
Output only.
-
#flow ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Output only.
-
#name ⇒ String
Identifier.
-
#order_state ⇒ String
Output only.
-
#provider ⇒ String
Output only.
-
#provider_site ⇒ String
Output only.
-
#sla ⇒ String
Output only.
-
#supported_bandwidths ⇒ Array<String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemoteTransportProfile
constructor
A new instance of RemoteTransportProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemoteTransportProfile
Returns a new instance of RemoteTransportProfile.
4175 4176 4177 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4175 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Output only. Description of the profile.
Corresponds to the JSON property description
4122 4123 4124 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4122 def description @description end |
#display_name ⇒ String
Output only. Human readable name of this profile, used to identify this
profile in the UI.
Corresponds to the JSON property displayName
4128 4129 4130 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4128 def display_name @display_name end |
#flow ⇒ String
Output only. Type of provisioning flows supported by this profile.
Corresponds to the JSON property flow
4133 4134 4135 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4133 def flow @flow end |
#labels ⇒ Hash<String,String>
Output only. Labels as key value pairs.
Corresponds to the JSON property labels
4138 4139 4140 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4138 def labels @labels end |
#name ⇒ String
Identifier. Name of the resource in the format of $provider-$site.
Corresponds to the JSON property name
4143 4144 4145 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4143 def name @name end |
#order_state ⇒ String
Output only. Order state for this profile.
Corresponds to the JSON property orderState
4148 4149 4150 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4148 def order_state @order_state end |
#provider ⇒ String
Output only. Name of the provider on the other end of this profile. E.g. “
Amazon Web Services” or “Microsoft Azure”.
Corresponds to the JSON property provider
4154 4155 4156 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4154 def provider @provider end |
#provider_site ⇒ String
Output only. If the profile is a Cloud Service Provider with compute resources,
this is populated with the region where connectivity is being established. If
the profile provides facility-level selection, this is an identity of the
facility any connections on this profile are going through.
Corresponds to the JSON property providerSite
4162 4163 4164 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4162 def provider_site @provider_site end |
#sla ⇒ String
Output only. Availability class that will be configured for this particular
RemoteTransportProfile.
Corresponds to the JSON property sla
4168 4169 4170 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4168 def sla @sla end |
#supported_bandwidths ⇒ Array<String>
Output only. List of bandwidth enum values that are supported by this profile.
Corresponds to the JSON property supportedBandwidths
4173 4174 4175 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4173 def supported_bandwidths @supported_bandwidths end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4180 4181 4182 4183 4184 4185 4186 4187 4188 4189 4190 4191 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4180 def update!(**args) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @flow = args[:flow] if args.key?(:flow) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @order_state = args[:order_state] if args.key?(:order_state) @provider = args[:provider] if args.key?(:provider) @provider_site = args[:provider_site] if args.key?(:provider_site) @sla = args[:sla] if args.key?(:sla) @supported_bandwidths = args[:supported_bandwidths] if args.key?(:supported_bandwidths) end |