Class: Google::Apis::NetworkconnectivityV1::RemoteTransportProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

Message describing RemoteTransportProfile object.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RemoteTransportProfile

Returns a new instance of RemoteTransportProfile.



4066
4067
4068
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4066

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Output only. Description of the profile. Corresponds to the JSON property description

Returns:

  • (String)


4013
4014
4015
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4013

def description
  @description
end

#display_nameString

Output only. Human readable name of this profile, used to identify this profile in the UI. Corresponds to the JSON property displayName

Returns:

  • (String)


4019
4020
4021
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4019

def display_name
  @display_name
end

#flowString

Output only. Type of provisioning flows supported by this profile. Corresponds to the JSON property flow

Returns:

  • (String)


4024
4025
4026
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4024

def flow
  @flow
end

#labelsHash<String,String>

Output only. Labels as key value pairs. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4029
4030
4031
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4029

def labels
  @labels
end

#nameString

Identifier. Name of the resource in the format of $provider-$site. Corresponds to the JSON property name

Returns:

  • (String)


4034
4035
4036
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4034

def name
  @name
end

#order_stateString

Output only. Order state for this profile. Corresponds to the JSON property orderState

Returns:

  • (String)


4039
4040
4041
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4039

def order_state
  @order_state
end

#providerString

Output only. Name of the provider on the other end of this profile. E.g. “ Amazon Web Services” or “Microsoft Azure”. Corresponds to the JSON property provider

Returns:

  • (String)


4045
4046
4047
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4045

def provider
  @provider
end

#provider_siteString

Output only. If the profile is a Cloud Service Provider with compute resources, this is populated with the region where connectivity is being established. If the profile provides facility-level selection, this is an identity of the facility any connections on this profile are going through. Corresponds to the JSON property providerSite

Returns:

  • (String)


4053
4054
4055
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4053

def provider_site
  @provider_site
end

#slaString

Output only. Availability class that will be configured for this particular RemoteTransportProfile. Corresponds to the JSON property sla

Returns:

  • (String)


4059
4060
4061
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4059

def sla
  @sla
end

#supported_bandwidthsArray<String>

Output only. List of bandwidth enum values that are supported by this profile. Corresponds to the JSON property supportedBandwidths

Returns:

  • (Array<String>)


4064
4065
4066
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4064

def supported_bandwidths
  @supported_bandwidths
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4071
4072
4073
4074
4075
4076
4077
4078
4079
4080
4081
4082
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4071

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @flow = args[:flow] if args.key?(:flow)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @order_state = args[:order_state] if args.key?(:order_state)
  @provider = args[:provider] if args.key?(:provider)
  @provider_site = args[:provider_site] if args.key?(:provider_site)
  @sla = args[:sla] if args.key?(:sla)
  @supported_bandwidths = args[:supported_bandwidths] if args.key?(:supported_bandwidths)
end