Class: Google::Apis::NetworkconnectivityV1::RemoteTransportProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

Message describing RemoteTransportProfile object.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RemoteTransportProfile

Returns a new instance of RemoteTransportProfile.



3884
3885
3886
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3884

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Output only. Description of the profile. Corresponds to the JSON property description

Returns:

  • (String)


3831
3832
3833
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3831

def description
  @description
end

#display_nameString

Output only. Human readable name of this profile, used to identify this profile in the UI. Corresponds to the JSON property displayName

Returns:

  • (String)


3837
3838
3839
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3837

def display_name
  @display_name
end

#flowString

Output only. Type of provisioning flows supported by this profile. Corresponds to the JSON property flow

Returns:

  • (String)


3842
3843
3844
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3842

def flow
  @flow
end

#labelsHash<String,String>

Output only. Labels as key value pairs. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3847
3848
3849
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3847

def labels
  @labels
end

#nameString

Identifier. Name of the resource in the format of $provider-$site. Corresponds to the JSON property name

Returns:

  • (String)


3852
3853
3854
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3852

def name
  @name
end

#order_stateString

Output only. Order state for this profile. Corresponds to the JSON property orderState

Returns:

  • (String)


3857
3858
3859
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3857

def order_state
  @order_state
end

#providerString

Output only. Name of the provider on the other end of this profile. E.g. “ Amazon Web Services” or “Microsoft Azure”. Corresponds to the JSON property provider

Returns:

  • (String)


3863
3864
3865
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3863

def provider
  @provider
end

#provider_siteString

Output only. If the profile is a Cloud Service Provider with compute resources, this is populated with the region where connectivity is being established. If the profile provides facility-level selection, this is an identity of the facility any connections on this profile are going through. Corresponds to the JSON property providerSite

Returns:

  • (String)


3871
3872
3873
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3871

def provider_site
  @provider_site
end

#slaString

Output only. Availability class that will be configured for this particular RemoteTransportProfile. Corresponds to the JSON property sla

Returns:

  • (String)


3877
3878
3879
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3877

def sla
  @sla
end

#supported_bandwidthsArray<String>

Output only. List of bandwidth enum values that are supported by this profile. Corresponds to the JSON property supportedBandwidths

Returns:

  • (Array<String>)


3882
3883
3884
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3882

def supported_bandwidths
  @supported_bandwidths
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3889
3890
3891
3892
3893
3894
3895
3896
3897
3898
3899
3900
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3889

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @flow = args[:flow] if args.key?(:flow)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @order_state = args[:order_state] if args.key?(:order_state)
  @provider = args[:provider] if args.key?(:provider)
  @provider_site = args[:provider_site] if args.key?(:provider_site)
  @sla = args[:sla] if args.key?(:sla)
  @supported_bandwidths = args[:supported_bandwidths] if args.key?(:supported_bandwidths)
end