Class: Google::Apis::NetworkconnectivityV1::RemoteTransportProfile
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::RemoteTransportProfile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
Message describing RemoteTransportProfile object.
Instance Attribute Summary collapse
-
#description ⇒ String
Output only.
-
#display_name ⇒ String
Output only.
-
#flow ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Output only.
-
#name ⇒ String
Identifier.
-
#order_state ⇒ String
Output only.
-
#provider ⇒ String
Output only.
-
#provider_site ⇒ String
Output only.
-
#sla ⇒ String
Output only.
-
#supported_bandwidths ⇒ Array<String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemoteTransportProfile
constructor
A new instance of RemoteTransportProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemoteTransportProfile
Returns a new instance of RemoteTransportProfile.
3884 3885 3886 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3884 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Output only. Description of the profile.
Corresponds to the JSON property description
3831 3832 3833 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3831 def description @description end |
#display_name ⇒ String
Output only. Human readable name of this profile, used to identify this
profile in the UI.
Corresponds to the JSON property displayName
3837 3838 3839 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3837 def display_name @display_name end |
#flow ⇒ String
Output only. Type of provisioning flows supported by this profile.
Corresponds to the JSON property flow
3842 3843 3844 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3842 def flow @flow end |
#labels ⇒ Hash<String,String>
Output only. Labels as key value pairs.
Corresponds to the JSON property labels
3847 3848 3849 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3847 def labels @labels end |
#name ⇒ String
Identifier. Name of the resource in the format of $provider-$site.
Corresponds to the JSON property name
3852 3853 3854 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3852 def name @name end |
#order_state ⇒ String
Output only. Order state for this profile.
Corresponds to the JSON property orderState
3857 3858 3859 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3857 def order_state @order_state end |
#provider ⇒ String
Output only. Name of the provider on the other end of this profile. E.g. “
Amazon Web Services” or “Microsoft Azure”.
Corresponds to the JSON property provider
3863 3864 3865 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3863 def provider @provider end |
#provider_site ⇒ String
Output only. If the profile is a Cloud Service Provider with compute resources,
this is populated with the region where connectivity is being established. If
the profile provides facility-level selection, this is an identity of the
facility any connections on this profile are going through.
Corresponds to the JSON property providerSite
3871 3872 3873 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3871 def provider_site @provider_site end |
#sla ⇒ String
Output only. Availability class that will be configured for this particular
RemoteTransportProfile.
Corresponds to the JSON property sla
3877 3878 3879 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3877 def sla @sla end |
#supported_bandwidths ⇒ Array<String>
Output only. List of bandwidth enum values that are supported by this profile.
Corresponds to the JSON property supportedBandwidths
3882 3883 3884 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3882 def supported_bandwidths @supported_bandwidths end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3889 3890 3891 3892 3893 3894 3895 3896 3897 3898 3899 3900 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3889 def update!(**args) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @flow = args[:flow] if args.key?(:flow) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @order_state = args[:order_state] if args.key?(:order_state) @provider = args[:provider] if args.key?(:provider) @provider_site = args[:provider_site] if args.key?(:provider_site) @sla = args[:sla] if args.key?(:sla) @supported_bandwidths = args[:supported_bandwidths] if args.key?(:supported_bandwidths) end |