Class: Google::Apis::NetworkconnectivityV1::Route

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

A route defines a path from VM instances within a spoke to a specific destination resource. Only VPC spokes have routes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Route

Returns a new instance of Route.



4006
4007
4008
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4006

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time the route was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3911
3912
3913
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3911

def create_time
  @create_time
end

#descriptionString

An optional description of the route. Corresponds to the JSON property description

Returns:

  • (String)


3916
3917
3918
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3916

def description
  @description
end

#ip_cidr_rangeString

The destination IP address range. Corresponds to the JSON property ipCidrRange

Returns:

  • (String)


3921
3922
3923
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3921

def ip_cidr_range
  @ip_cidr_range
end

#labelsHash<String,String>

Optional labels in key-value pair format. For more information about labels, see Requirements for labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3928
3929
3930
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3928

def labels
  @labels
end

#locationString

Output only. The origin location of the route. Uses the following form: " projects/project/locations/location" Example: projects/1234/locations/us- central1 Corresponds to the JSON property location

Returns:

  • (String)


3935
3936
3937
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3935

def location
  @location
end

#nameString

Immutable. The name of the route. Route names must be unique. Route names use the following form: projects/project_number/locations/global/hubs/hub/ routeTables/route_table_id/routes/route_id` Corresponds to the JSON propertyname`

Returns:

  • (String)


3942
3943
3944
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3942

def name
  @name
end

#next_hop_interconnect_attachmentGoogle::Apis::NetworkconnectivityV1::NextHopInterconnectAttachment

A route next hop that leads to an interconnect attachment resource. Corresponds to the JSON property nextHopInterconnectAttachment



3947
3948
3949
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3947

def next_hop_interconnect_attachment
  @next_hop_interconnect_attachment
end

#next_hop_router_appliance_instanceGoogle::Apis::NetworkconnectivityV1::NextHopRouterApplianceInstance

A route next hop that leads to a Router appliance instance. Corresponds to the JSON property nextHopRouterApplianceInstance



3952
3953
3954
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3952

def next_hop_router_appliance_instance
  @next_hop_router_appliance_instance
end

#next_hop_spokeGoogle::Apis::NetworkconnectivityV1::NextHopSpoke

A route next hop that leads to a spoke resource. Corresponds to the JSON property nextHopSpoke



3957
3958
3959
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3957

def next_hop_spoke
  @next_hop_spoke
end

#next_hop_vpc_networkGoogle::Apis::NetworkconnectivityV1::NextHopVpcNetwork

Immutable. The destination VPC network for packets on this route. Corresponds to the JSON property nextHopVpcNetwork



3962
3963
3964
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3962

def next_hop_vpc_network
  @next_hop_vpc_network
end

#next_hop_vpn_tunnelGoogle::Apis::NetworkconnectivityV1::NextHopVpnTunnel

A route next hop that leads to a VPN tunnel resource. Corresponds to the JSON property nextHopVpnTunnel



3967
3968
3969
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3967

def next_hop_vpn_tunnel
  @next_hop_vpn_tunnel
end

#priorityFixnum

Output only. The priority of this route. Priority is used to break ties in cases where a destination matches more than one route. In these cases the route with the lowest-numbered priority value wins. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


3974
3975
3976
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3974

def priority
  @priority
end

#spokeString

Immutable. The spoke that this route leads to. Example: projects/12345/ locations/global/spokes/SPOKE Corresponds to the JSON property spoke

Returns:

  • (String)


3980
3981
3982
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3980

def spoke
  @spoke
end

#stateString

Output only. The current lifecycle state of the route. Corresponds to the JSON property state

Returns:

  • (String)


3985
3986
3987
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3985

def state
  @state
end

#typeString

Output only. The route's type. Its type is determined by the properties of its IP address range. Corresponds to the JSON property type

Returns:

  • (String)


3991
3992
3993
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3991

def type
  @type
end

#uidString

Output only. The Google-generated UUID for the route. This value is unique across all Network Connectivity Center route resources. If a route is deleted and another with the same name is created, the new route is assigned a different uid. Corresponds to the JSON property uid

Returns:

  • (String)


3999
4000
4001
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3999

def uid
  @uid
end

#update_timeString

Output only. The time the route was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4004
4005
4006
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4004

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4011

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range)
  @labels = args[:labels] if args.key?(:labels)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @next_hop_interconnect_attachment = args[:next_hop_interconnect_attachment] if args.key?(:next_hop_interconnect_attachment)
  @next_hop_router_appliance_instance = args[:next_hop_router_appliance_instance] if args.key?(:next_hop_router_appliance_instance)
  @next_hop_spoke = args[:next_hop_spoke] if args.key?(:next_hop_spoke)
  @next_hop_vpc_network = args[:next_hop_vpc_network] if args.key?(:next_hop_vpc_network)
  @next_hop_vpn_tunnel = args[:next_hop_vpn_tunnel] if args.key?(:next_hop_vpn_tunnel)
  @priority = args[:priority] if args.key?(:priority)
  @spoke = args[:spoke] if args.key?(:spoke)
  @state = args[:state] if args.key?(:state)
  @type = args[:type] if args.key?(:type)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end