Class: Google::Apis::NetworkconnectivityV1::Route
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::Route
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
A route defines a path from VM instances within a spoke to a specific destination resource. Only VPC spokes have routes.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
An optional description of the route.
-
#ip_cidr_range ⇒ String
The destination IP address range.
-
#labels ⇒ Hash<String,String>
Optional labels in key-value pair format.
-
#location ⇒ String
Output only.
-
#name ⇒ String
Immutable.
-
#next_hop_interconnect_attachment ⇒ Google::Apis::NetworkconnectivityV1::NextHopInterconnectAttachment
A route next hop that leads to an interconnect attachment resource.
-
#next_hop_router_appliance_instance ⇒ Google::Apis::NetworkconnectivityV1::NextHopRouterApplianceInstance
A route next hop that leads to a Router appliance instance.
-
#next_hop_spoke ⇒ Google::Apis::NetworkconnectivityV1::NextHopSpoke
A route next hop that leads to a spoke resource.
-
#next_hop_vpc_network ⇒ Google::Apis::NetworkconnectivityV1::NextHopVpcNetwork
Immutable.
-
#next_hop_vpn_tunnel ⇒ Google::Apis::NetworkconnectivityV1::NextHopVpnTunnel
A route next hop that leads to a VPN tunnel resource.
-
#priority ⇒ Fixnum
Output only.
-
#spoke ⇒ String
Immutable.
-
#state ⇒ String
Output only.
-
#type ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Route
constructor
A new instance of Route.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Route
Returns a new instance of Route.
3802 3803 3804 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3802 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time the route was created.
Corresponds to the JSON property createTime
3707 3708 3709 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3707 def create_time @create_time end |
#description ⇒ String
An optional description of the route.
Corresponds to the JSON property description
3712 3713 3714 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3712 def description @description end |
#ip_cidr_range ⇒ String
The destination IP address range.
Corresponds to the JSON property ipCidrRange
3717 3718 3719 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3717 def ip_cidr_range @ip_cidr_range end |
#labels ⇒ Hash<String,String>
Optional labels in key-value pair format. For more information about labels,
see Requirements for labels.
Corresponds to the JSON property labels
3724 3725 3726 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3724 def labels @labels end |
#location ⇒ String
Output only. The origin location of the route. Uses the following form: "
projects/project/locations/location" Example: projects/1234/locations/us-
central1
Corresponds to the JSON property location
3731 3732 3733 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3731 def location @location end |
#name ⇒ String
Immutable. The name of the route. Route names must be unique. Route names use
the following form: projects/project_number/locations/global/hubs/hub/
routeTables/route_table_id/routes/route_id`
Corresponds to the JSON propertyname`
3738 3739 3740 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3738 def name @name end |
#next_hop_interconnect_attachment ⇒ Google::Apis::NetworkconnectivityV1::NextHopInterconnectAttachment
A route next hop that leads to an interconnect attachment resource.
Corresponds to the JSON property nextHopInterconnectAttachment
3743 3744 3745 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3743 def @next_hop_interconnect_attachment end |
#next_hop_router_appliance_instance ⇒ Google::Apis::NetworkconnectivityV1::NextHopRouterApplianceInstance
A route next hop that leads to a Router appliance instance.
Corresponds to the JSON property nextHopRouterApplianceInstance
3748 3749 3750 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3748 def next_hop_router_appliance_instance @next_hop_router_appliance_instance end |
#next_hop_spoke ⇒ Google::Apis::NetworkconnectivityV1::NextHopSpoke
A route next hop that leads to a spoke resource.
Corresponds to the JSON property nextHopSpoke
3753 3754 3755 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3753 def next_hop_spoke @next_hop_spoke end |
#next_hop_vpc_network ⇒ Google::Apis::NetworkconnectivityV1::NextHopVpcNetwork
Immutable. The destination VPC network for packets on this route.
Corresponds to the JSON property nextHopVpcNetwork
3758 3759 3760 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3758 def next_hop_vpc_network @next_hop_vpc_network end |
#next_hop_vpn_tunnel ⇒ Google::Apis::NetworkconnectivityV1::NextHopVpnTunnel
A route next hop that leads to a VPN tunnel resource.
Corresponds to the JSON property nextHopVpnTunnel
3763 3764 3765 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3763 def next_hop_vpn_tunnel @next_hop_vpn_tunnel end |
#priority ⇒ Fixnum
Output only. The priority of this route. Priority is used to break ties in
cases where a destination matches more than one route. In these cases the
route with the lowest-numbered priority value wins.
Corresponds to the JSON property priority
3770 3771 3772 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3770 def priority @priority end |
#spoke ⇒ String
Immutable. The spoke that this route leads to. Example: projects/12345/
locations/global/spokes/SPOKE
Corresponds to the JSON property spoke
3776 3777 3778 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3776 def spoke @spoke end |
#state ⇒ String
Output only. The current lifecycle state of the route.
Corresponds to the JSON property state
3781 3782 3783 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3781 def state @state end |
#type ⇒ String
Output only. The route's type. Its type is determined by the properties of its
IP address range.
Corresponds to the JSON property type
3787 3788 3789 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3787 def type @type end |
#uid ⇒ String
Output only. The Google-generated UUID for the route. This value is unique
across all Network Connectivity Center route resources. If a route is deleted
and another with the same name is created, the new route is assigned a
different uid.
Corresponds to the JSON property uid
3795 3796 3797 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3795 def uid @uid end |
#update_time ⇒ String
Output only. The time the route was last updated.
Corresponds to the JSON property updateTime
3800 3801 3802 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3800 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3807 3808 3809 3810 3811 3812 3813 3814 3815 3816 3817 3818 3819 3820 3821 3822 3823 3824 3825 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3807 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range) @labels = args[:labels] if args.key?(:labels) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @next_hop_interconnect_attachment = args[:next_hop_interconnect_attachment] if args.key?(:next_hop_interconnect_attachment) @next_hop_router_appliance_instance = args[:next_hop_router_appliance_instance] if args.key?(:next_hop_router_appliance_instance) @next_hop_spoke = args[:next_hop_spoke] if args.key?(:next_hop_spoke) @next_hop_vpc_network = args[:next_hop_vpc_network] if args.key?(:next_hop_vpc_network) @next_hop_vpn_tunnel = args[:next_hop_vpn_tunnel] if args.key?(:next_hop_vpn_tunnel) @priority = args[:priority] if args.key?(:priority) @spoke = args[:spoke] if args.key?(:spoke) @state = args[:state] if args.key?(:state) @type = args[:type] if args.key?(:type) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |