Class: Google::Apis::NetworkconnectivityV1::Route
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::Route
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
A route defines a path from VM instances within a spoke to a specific destination resource. Only VPC spokes have routes.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
An optional description of the route.
-
#ip_cidr_range ⇒ String
The destination IP address range.
-
#labels ⇒ Hash<String,String>
Optional labels in key-value pair format.
-
#location ⇒ String
Output only.
-
#name ⇒ String
Immutable.
-
#next_hop_interconnect_attachment ⇒ Google::Apis::NetworkconnectivityV1::NextHopInterconnectAttachment
A route next hop that leads to an interconnect attachment resource.
-
#next_hop_router_appliance_instance ⇒ Google::Apis::NetworkconnectivityV1::NextHopRouterApplianceInstance
A route next hop that leads to a Router appliance instance.
-
#next_hop_spoke ⇒ Google::Apis::NetworkconnectivityV1::NextHopSpoke
A route next hop that leads to a spoke resource.
-
#next_hop_vpc_network ⇒ Google::Apis::NetworkconnectivityV1::NextHopVpcNetwork
Immutable.
-
#next_hop_vpn_tunnel ⇒ Google::Apis::NetworkconnectivityV1::NextHopVpnTunnel
A route next hop that leads to a VPN tunnel resource.
-
#priority ⇒ Fixnum
Output only.
-
#spoke ⇒ String
Immutable.
-
#state ⇒ String
Output only.
-
#type ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Route
constructor
A new instance of Route.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Route
Returns a new instance of Route.
3591 3592 3593 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3591 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time the route was created.
Corresponds to the JSON property createTime
3496 3497 3498 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3496 def create_time @create_time end |
#description ⇒ String
An optional description of the route.
Corresponds to the JSON property description
3501 3502 3503 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3501 def description @description end |
#ip_cidr_range ⇒ String
The destination IP address range.
Corresponds to the JSON property ipCidrRange
3506 3507 3508 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3506 def ip_cidr_range @ip_cidr_range end |
#labels ⇒ Hash<String,String>
Optional labels in key-value pair format. For more information about labels,
see Requirements for labels.
Corresponds to the JSON property labels
3513 3514 3515 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3513 def labels @labels end |
#location ⇒ String
Output only. The origin location of the route. Uses the following form: "
projects/project/locations/location" Example: projects/1234/locations/us-
central1
Corresponds to the JSON property location
3520 3521 3522 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3520 def location @location end |
#name ⇒ String
Immutable. The name of the route. Route names must be unique. Route names use
the following form: projects/project_number/locations/global/hubs/hub/
routeTables/route_table_id/routes/route_id`
Corresponds to the JSON propertyname`
3527 3528 3529 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3527 def name @name end |
#next_hop_interconnect_attachment ⇒ Google::Apis::NetworkconnectivityV1::NextHopInterconnectAttachment
A route next hop that leads to an interconnect attachment resource.
Corresponds to the JSON property nextHopInterconnectAttachment
3532 3533 3534 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3532 def @next_hop_interconnect_attachment end |
#next_hop_router_appliance_instance ⇒ Google::Apis::NetworkconnectivityV1::NextHopRouterApplianceInstance
A route next hop that leads to a Router appliance instance.
Corresponds to the JSON property nextHopRouterApplianceInstance
3537 3538 3539 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3537 def next_hop_router_appliance_instance @next_hop_router_appliance_instance end |
#next_hop_spoke ⇒ Google::Apis::NetworkconnectivityV1::NextHopSpoke
A route next hop that leads to a spoke resource.
Corresponds to the JSON property nextHopSpoke
3542 3543 3544 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3542 def next_hop_spoke @next_hop_spoke end |
#next_hop_vpc_network ⇒ Google::Apis::NetworkconnectivityV1::NextHopVpcNetwork
Immutable. The destination VPC network for packets on this route.
Corresponds to the JSON property nextHopVpcNetwork
3547 3548 3549 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3547 def next_hop_vpc_network @next_hop_vpc_network end |
#next_hop_vpn_tunnel ⇒ Google::Apis::NetworkconnectivityV1::NextHopVpnTunnel
A route next hop that leads to a VPN tunnel resource.
Corresponds to the JSON property nextHopVpnTunnel
3552 3553 3554 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3552 def next_hop_vpn_tunnel @next_hop_vpn_tunnel end |
#priority ⇒ Fixnum
Output only. The priority of this route. Priority is used to break ties in
cases where a destination matches more than one route. In these cases the
route with the lowest-numbered priority value wins.
Corresponds to the JSON property priority
3559 3560 3561 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3559 def priority @priority end |
#spoke ⇒ String
Immutable. The spoke that this route leads to. Example: projects/12345/
locations/global/spokes/SPOKE
Corresponds to the JSON property spoke
3565 3566 3567 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3565 def spoke @spoke end |
#state ⇒ String
Output only. The current lifecycle state of the route.
Corresponds to the JSON property state
3570 3571 3572 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3570 def state @state end |
#type ⇒ String
Output only. The route's type. Its type is determined by the properties of its
IP address range.
Corresponds to the JSON property type
3576 3577 3578 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3576 def type @type end |
#uid ⇒ String
Output only. The Google-generated UUID for the route. This value is unique
across all Network Connectivity Center route resources. If a route is deleted
and another with the same name is created, the new route is assigned a
different uid.
Corresponds to the JSON property uid
3584 3585 3586 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3584 def uid @uid end |
#update_time ⇒ String
Output only. The time the route was last updated.
Corresponds to the JSON property updateTime
3589 3590 3591 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3589 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3596 3597 3598 3599 3600 3601 3602 3603 3604 3605 3606 3607 3608 3609 3610 3611 3612 3613 3614 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3596 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range) @labels = args[:labels] if args.key?(:labels) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @next_hop_interconnect_attachment = args[:next_hop_interconnect_attachment] if args.key?(:next_hop_interconnect_attachment) @next_hop_router_appliance_instance = args[:next_hop_router_appliance_instance] if args.key?(:next_hop_router_appliance_instance) @next_hop_spoke = args[:next_hop_spoke] if args.key?(:next_hop_spoke) @next_hop_vpc_network = args[:next_hop_vpc_network] if args.key?(:next_hop_vpc_network) @next_hop_vpn_tunnel = args[:next_hop_vpn_tunnel] if args.key?(:next_hop_vpn_tunnel) @priority = args[:priority] if args.key?(:priority) @spoke = args[:spoke] if args.key?(:spoke) @state = args[:state] if args.key?(:state) @type = args[:type] if args.key?(:type) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |