Class: Google::Apis::NetworkconnectivityV1::RouteTable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouteTable

Returns a new instance of RouteTable.



4260
4261
4262
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4260

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time the route table was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4221
4222
4223
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4221

def create_time
  @create_time
end

#descriptionString

An optional description of the route table. Corresponds to the JSON property description

Returns:

  • (String)


4226
4227
4228
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4226

def description
  @description
end

#labelsHash<String,String>

Optional labels in key-value pair format. For more information about labels, see Requirements for labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4233
4234
4235
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4233

def labels
  @labels
end

#nameString

Immutable. The name of the route table. Route table names must be unique. They use the following form: projects/project_number/locations/global/hubs/hub/ routeTables/route_table_id` Corresponds to the JSON propertyname`

Returns:

  • (String)


4240
4241
4242
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4240

def name
  @name
end

#stateString

Output only. The current lifecycle state of this route table. Corresponds to the JSON property state

Returns:

  • (String)


4245
4246
4247
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4245

def state
  @state
end

#uidString

Output only. The Google-generated UUID for the route table. This value is unique across all route table resources. If a route table is deleted and another with the same name is created, the new route table is assigned a different uid. Corresponds to the JSON property uid

Returns:

  • (String)


4253
4254
4255
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4253

def uid
  @uid
end

#update_timeString

Output only. The time the route table was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4258
4259
4260
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4258

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4265
4266
4267
4268
4269
4270
4271
4272
4273
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4265

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end