Class: Google::Apis::NetworkconnectivityV1::RouteTable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouteTable

Returns a new instance of RouteTable.



3663
3664
3665
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3663

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time the route table was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3624
3625
3626
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3624

def create_time
  @create_time
end

#descriptionString

An optional description of the route table. Corresponds to the JSON property description

Returns:

  • (String)


3629
3630
3631
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3629

def description
  @description
end

#labelsHash<String,String>

Optional labels in key-value pair format. For more information about labels, see Requirements for labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3636
3637
3638
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3636

def labels
  @labels
end

#nameString

Immutable. The name of the route table. Route table names must be unique. They use the following form: projects/project_number/locations/global/hubs/hub/ routeTables/route_table_id` Corresponds to the JSON propertyname`

Returns:

  • (String)


3643
3644
3645
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3643

def name
  @name
end

#stateString

Output only. The current lifecycle state of this route table. Corresponds to the JSON property state

Returns:

  • (String)


3648
3649
3650
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3648

def state
  @state
end

#uidString

Output only. The Google-generated UUID for the route table. This value is unique across all route table resources. If a route table is deleted and another with the same name is created, the new route table is assigned a different uid. Corresponds to the JSON property uid

Returns:

  • (String)


3656
3657
3658
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3656

def uid
  @uid
end

#update_timeString

Output only. The time the route table was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3661
3662
3663
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3661

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3668
3669
3670
3671
3672
3673
3674
3675
3676
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3668

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end