Class: Google::Apis::NetworkconnectivityV1::RouterApplianceInstance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

A router appliance instance is a Compute Engine virtual machine (VM) instance that acts as a BGP speaker. A router appliance instance is specified by the URI of the VM and the internal IP address of one of the VM's network interfaces.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterApplianceInstance

Returns a new instance of RouterApplianceInstance.



4293
4294
4295
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4293

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_addressString

The IP address on the VM to use for peering. Corresponds to the JSON property ipAddress

Returns:

  • (String)


4286
4287
4288
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4286

def ip_address
  @ip_address
end

#virtual_machineString

The URI of the VM. Corresponds to the JSON property virtualMachine

Returns:

  • (String)


4291
4292
4293
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4291

def virtual_machine
  @virtual_machine
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4298
4299
4300
4301
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4298

def update!(**args)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @virtual_machine = args[:virtual_machine] if args.key?(:virtual_machine)
end