Class: Google::Apis::NetworkconnectivityV1::RouterApplianceInstance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

A router appliance instance is a Compute Engine virtual machine (VM) instance that acts as a BGP speaker. A router appliance instance is specified by the URI of the VM and the internal IP address of one of the VM's network interfaces.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterApplianceInstance

Returns a new instance of RouterApplianceInstance.



3696
3697
3698
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3696

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_addressString

The IP address on the VM to use for peering. Corresponds to the JSON property ipAddress

Returns:

  • (String)


3689
3690
3691
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3689

def ip_address
  @ip_address
end

#virtual_machineString

The URI of the VM. Corresponds to the JSON property virtualMachine

Returns:

  • (String)


3694
3695
3696
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3694

def virtual_machine
  @virtual_machine
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3701
3702
3703
3704
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3701

def update!(**args)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @virtual_machine = args[:virtual_machine] if args.key?(:virtual_machine)
end