Class: Google::Apis::NetworkconnectivityV1::RoutingVpc

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

RoutingVPC contains information about the VPC networks associated with the spokes of a Network Connectivity Center hub.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutingVpc

Returns a new instance of RoutingVpc.



4142
4143
4144
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4142

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#required_for_new_site_to_site_data_transfer_spokesBoolean Also known as: required_for_new_site_to_site_data_transfer_spokes?

Output only. If true, indicates that this VPC network is currently associated with spokes that use the data transfer feature (spokes where the site_to_site_data_transfer field is set to true). If you create new spokes that use data transfer, they must be associated with this VPC network. At most, one VPC network will have this field set to true. Corresponds to the JSON property requiredForNewSiteToSiteDataTransferSpokes

Returns:

  • (Boolean)


4134
4135
4136
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4134

def required_for_new_site_to_site_data_transfer_spokes
  @required_for_new_site_to_site_data_transfer_spokes
end

#uriString

The URI of the VPC network. Corresponds to the JSON property uri

Returns:

  • (String)


4140
4141
4142
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4140

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4147
4148
4149
4150
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4147

def update!(**args)
  @required_for_new_site_to_site_data_transfer_spokes = args[:required_for_new_site_to_site_data_transfer_spokes] if args.key?(:required_for_new_site_to_site_data_transfer_spokes)
  @uri = args[:uri] if args.key?(:uri)
end