Class: Google::Apis::NetworkconnectivityV1::ServiceClass
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::ServiceClass
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
The ServiceClass resource.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
A description of this resource.
-
#etag ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
User-defined labels.
-
#name ⇒ String
Immutable.
-
#service_class ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceClass
constructor
A new instance of ServiceClass.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceClass
Returns a new instance of ServiceClass.
4378 4379 4380 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4378 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Time when the ServiceClass was created.
Corresponds to the JSON property createTime
4342 4343 4344 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4342 def create_time @create_time end |
#description ⇒ String
A description of this resource.
Corresponds to the JSON property description
4347 4348 4349 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4347 def description @description end |
#etag ⇒ String
Optional. The etag is computed by the server, and may be sent on update and
delete requests to ensure the client has an up-to-date value before proceeding.
Corresponds to the JSON property etag
4353 4354 4355 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4353 def etag @etag end |
#labels ⇒ Hash<String,String>
User-defined labels.
Corresponds to the JSON property labels
4358 4359 4360 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4358 def labels @labels end |
#name ⇒ String
Immutable. The name of a ServiceClass resource. Format: projects/project/
locations/location/serviceClasses/service_class See: https://google.aip.
dev/122#fields-representing-resource-names
Corresponds to the JSON property name
4365 4366 4367 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4365 def name @name end |
#service_class ⇒ String
Output only. The generated service class name. Use this name to refer to the
Service class in Service Connection Maps and Service Connection Policies.
Corresponds to the JSON property serviceClass
4371 4372 4373 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4371 def service_class @service_class end |
#update_time ⇒ String
Output only. Time when the ServiceClass was updated.
Corresponds to the JSON property updateTime
4376 4377 4378 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4376 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4383 4384 4385 4386 4387 4388 4389 4390 4391 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4383 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @service_class = args[:service_class] if args.key?(:service_class) @update_time = args[:update_time] if args.key?(:update_time) end |