Class: Google::Apis::NetworkconnectivityV1::ServiceClass

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

The ServiceClass resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceClass

Returns a new instance of ServiceClass.



4196
4197
4198
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4196

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when the ServiceClass was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4160
4161
4162
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4160

def create_time
  @create_time
end

#descriptionString

A description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


4165
4166
4167
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4165

def description
  @description
end

#etagString

Optional. The etag is computed by the server, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


4171
4172
4173
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4171

def etag
  @etag
end

#labelsHash<String,String>

User-defined labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4176
4177
4178
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4176

def labels
  @labels
end

#nameString

Immutable. The name of a ServiceClass resource. Format: projects/project/ locations/location/serviceClasses/service_class See: https://google.aip. dev/122#fields-representing-resource-names Corresponds to the JSON property name

Returns:

  • (String)


4183
4184
4185
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4183

def name
  @name
end

#service_classString

Output only. The generated service class name. Use this name to refer to the Service class in Service Connection Maps and Service Connection Policies. Corresponds to the JSON property serviceClass

Returns:

  • (String)


4189
4190
4191
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4189

def service_class
  @service_class
end

#update_timeString

Output only. Time when the ServiceClass was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4194
4195
4196
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4194

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4201
4202
4203
4204
4205
4206
4207
4208
4209
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4201

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @service_class = args[:service_class] if args.key?(:service_class)
  @update_time = args[:update_time] if args.key?(:update_time)
end