Class: Google::Apis::NetworkconnectivityV1::ServiceClass

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

The ServiceClass resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceClass

Returns a new instance of ServiceClass.



3992
3993
3994
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3992

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when the ServiceClass was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3956
3957
3958
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3956

def create_time
  @create_time
end

#descriptionString

A description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


3961
3962
3963
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3961

def description
  @description
end

#etagString

Optional. The etag is computed by the server, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


3967
3968
3969
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3967

def etag
  @etag
end

#labelsHash<String,String>

User-defined labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3972
3973
3974
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3972

def labels
  @labels
end

#nameString

Immutable. The name of a ServiceClass resource. Format: projects/project/ locations/location/serviceClasses/service_class See: https://google.aip. dev/122#fields-representing-resource-names Corresponds to the JSON property name

Returns:

  • (String)


3979
3980
3981
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3979

def name
  @name
end

#service_classString

Output only. The generated service class name. Use this name to refer to the Service class in Service Connection Maps and Service Connection Policies. Corresponds to the JSON property serviceClass

Returns:

  • (String)


3985
3986
3987
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3985

def service_class
  @service_class
end

#update_timeString

Output only. Time when the ServiceClass was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3990
3991
3992
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3990

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3997
3998
3999
4000
4001
4002
4003
4004
4005
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3997

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @service_class = args[:service_class] if args.key?(:service_class)
  @update_time = args[:update_time] if args.key?(:update_time)
end