Class: Google::Apis::NetworkconnectivityV1::ServiceClass

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

The ServiceClass resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceClass

Returns a new instance of ServiceClass.



3781
3782
3783
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3781

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when the ServiceClass was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3745
3746
3747
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3745

def create_time
  @create_time
end

#descriptionString

A description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


3750
3751
3752
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3750

def description
  @description
end

#etagString

Optional. The etag is computed by the server, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


3756
3757
3758
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3756

def etag
  @etag
end

#labelsHash<String,String>

User-defined labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3761
3762
3763
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3761

def labels
  @labels
end

#nameString

Immutable. The name of a ServiceClass resource. Format: projects/project/ locations/location/serviceClasses/service_class See: https://google.aip. dev/122#fields-representing-resource-names Corresponds to the JSON property name

Returns:

  • (String)


3768
3769
3770
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3768

def name
  @name
end

#service_classString

Output only. The generated service class name. Use this name to refer to the Service class in Service Connection Maps and Service Connection Policies. Corresponds to the JSON property serviceClass

Returns:

  • (String)


3774
3775
3776
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3774

def service_class
  @service_class
end

#update_timeString

Output only. Time when the ServiceClass was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3779
3780
3781
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3779

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3786
3787
3788
3789
3790
3791
3792
3793
3794
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3786

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @service_class = args[:service_class] if args.key?(:service_class)
  @update_time = args[:update_time] if args.key?(:update_time)
end