Class: Google::Apis::NetworkconnectivityV1::ServiceConnectionMap
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::ServiceConnectionMap
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
The ServiceConnectionMap resource.
Instance Attribute Summary collapse
-
#consumer_psc_configs ⇒ Array<Google::Apis::NetworkconnectivityV1::ConsumerPscConfig>
The PSC configurations on consumer side.
-
#consumer_psc_connections ⇒ Array<Google::Apis::NetworkconnectivityV1::ConsumerPscConnection>
Output only.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
A description of this resource.
-
#etag ⇒ String
Optional.
-
#infrastructure ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
User-defined labels.
-
#name ⇒ String
Immutable.
-
#producer_psc_configs ⇒ Array<Google::Apis::NetworkconnectivityV1::ProducerPscConfig>
The PSC configurations on producer side.
-
#service_class ⇒ String
The service class identifier this ServiceConnectionMap is for.
-
#service_class_uri ⇒ String
Output only.
-
#token ⇒ String
The token provided by the consumer.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceConnectionMap
constructor
A new instance of ServiceConnectionMap.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceConnectionMap
Returns a new instance of ServiceConnectionMap.
4314 4315 4316 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4314 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consumer_psc_configs ⇒ Array<Google::Apis::NetworkconnectivityV1::ConsumerPscConfig>
The PSC configurations on consumer side.
Corresponds to the JSON property consumerPscConfigs
4245 4246 4247 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4245 def consumer_psc_configs @consumer_psc_configs end |
#consumer_psc_connections ⇒ Array<Google::Apis::NetworkconnectivityV1::ConsumerPscConnection>
Output only. PSC connection details on consumer side.
Corresponds to the JSON property consumerPscConnections
4250 4251 4252 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4250 def consumer_psc_connections @consumer_psc_connections end |
#create_time ⇒ String
Output only. Time when the ServiceConnectionMap was created.
Corresponds to the JSON property createTime
4255 4256 4257 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4255 def create_time @create_time end |
#description ⇒ String
A description of this resource.
Corresponds to the JSON property description
4260 4261 4262 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4260 def description @description end |
#etag ⇒ String
Optional. The etag is computed by the server, and may be sent on update and
delete requests to ensure the client has an up-to-date value before proceeding.
Corresponds to the JSON property etag
4266 4267 4268 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4266 def etag @etag end |
#infrastructure ⇒ String
Output only. The infrastructure used for connections between consumers/
producers.
Corresponds to the JSON property infrastructure
4272 4273 4274 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4272 def infrastructure @infrastructure end |
#labels ⇒ Hash<String,String>
User-defined labels.
Corresponds to the JSON property labels
4277 4278 4279 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4277 def labels @labels end |
#name ⇒ String
Immutable. The name of a ServiceConnectionMap. Format: projects/project/
locations/location/serviceConnectionMaps/service_connection_map See: https:
//google.aip.dev/122#fields-representing-resource-names
Corresponds to the JSON property name
4284 4285 4286 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4284 def name @name end |
#producer_psc_configs ⇒ Array<Google::Apis::NetworkconnectivityV1::ProducerPscConfig>
The PSC configurations on producer side.
Corresponds to the JSON property producerPscConfigs
4289 4290 4291 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4289 def producer_psc_configs @producer_psc_configs end |
#service_class ⇒ String
The service class identifier this ServiceConnectionMap is for. The user of
ServiceConnectionMap create API needs to have networkconnectivity.
serviceClasses.use IAM permission for the service class.
Corresponds to the JSON property serviceClass
4296 4297 4298 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4296 def service_class @service_class end |
#service_class_uri ⇒ String
Output only. The service class uri this ServiceConnectionMap is for.
Corresponds to the JSON property serviceClassUri
4301 4302 4303 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4301 def service_class_uri @service_class_uri end |
#token ⇒ String
The token provided by the consumer. This token authenticates that the consumer
can create a connection within the specified project and network.
Corresponds to the JSON property token
4307 4308 4309 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4307 def token @token end |
#update_time ⇒ String
Output only. Time when the ServiceConnectionMap was updated.
Corresponds to the JSON property updateTime
4312 4313 4314 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4312 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4319 4320 4321 4322 4323 4324 4325 4326 4327 4328 4329 4330 4331 4332 4333 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4319 def update!(**args) @consumer_psc_configs = args[:consumer_psc_configs] if args.key?(:consumer_psc_configs) @consumer_psc_connections = args[:consumer_psc_connections] if args.key?(:consumer_psc_connections) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @infrastructure = args[:infrastructure] if args.key?(:infrastructure) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @producer_psc_configs = args[:producer_psc_configs] if args.key?(:producer_psc_configs) @service_class = args[:service_class] if args.key?(:service_class) @service_class_uri = args[:service_class_uri] if args.key?(:service_class_uri) @token = args[:token] if args.key?(:token) @update_time = args[:update_time] if args.key?(:update_time) end |