Class: Google::Apis::NetworkconnectivityV1::ServiceConnectionMap
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::ServiceConnectionMap
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
The ServiceConnectionMap resource.
Instance Attribute Summary collapse
-
#consumer_psc_configs ⇒ Array<Google::Apis::NetworkconnectivityV1::ConsumerPscConfig>
The PSC configurations on consumer side.
-
#consumer_psc_connections ⇒ Array<Google::Apis::NetworkconnectivityV1::ConsumerPscConnection>
Output only.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
A description of this resource.
-
#etag ⇒ String
Optional.
-
#infrastructure ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
User-defined labels.
-
#name ⇒ String
Immutable.
-
#producer_psc_configs ⇒ Array<Google::Apis::NetworkconnectivityV1::ProducerPscConfig>
The PSC configurations on producer side.
-
#service_class ⇒ String
The service class identifier this ServiceConnectionMap is for.
-
#service_class_uri ⇒ String
Output only.
-
#token ⇒ String
The token provided by the consumer.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceConnectionMap
constructor
A new instance of ServiceConnectionMap.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceConnectionMap
Returns a new instance of ServiceConnectionMap.
4110 4111 4112 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4110 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consumer_psc_configs ⇒ Array<Google::Apis::NetworkconnectivityV1::ConsumerPscConfig>
The PSC configurations on consumer side.
Corresponds to the JSON property consumerPscConfigs
4041 4042 4043 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4041 def consumer_psc_configs @consumer_psc_configs end |
#consumer_psc_connections ⇒ Array<Google::Apis::NetworkconnectivityV1::ConsumerPscConnection>
Output only. PSC connection details on consumer side.
Corresponds to the JSON property consumerPscConnections
4046 4047 4048 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4046 def consumer_psc_connections @consumer_psc_connections end |
#create_time ⇒ String
Output only. Time when the ServiceConnectionMap was created.
Corresponds to the JSON property createTime
4051 4052 4053 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4051 def create_time @create_time end |
#description ⇒ String
A description of this resource.
Corresponds to the JSON property description
4056 4057 4058 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4056 def description @description end |
#etag ⇒ String
Optional. The etag is computed by the server, and may be sent on update and
delete requests to ensure the client has an up-to-date value before proceeding.
Corresponds to the JSON property etag
4062 4063 4064 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4062 def etag @etag end |
#infrastructure ⇒ String
Output only. The infrastructure used for connections between consumers/
producers.
Corresponds to the JSON property infrastructure
4068 4069 4070 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4068 def infrastructure @infrastructure end |
#labels ⇒ Hash<String,String>
User-defined labels.
Corresponds to the JSON property labels
4073 4074 4075 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4073 def labels @labels end |
#name ⇒ String
Immutable. The name of a ServiceConnectionMap. Format: projects/project/
locations/location/serviceConnectionMaps/service_connection_map See: https:
//google.aip.dev/122#fields-representing-resource-names
Corresponds to the JSON property name
4080 4081 4082 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4080 def name @name end |
#producer_psc_configs ⇒ Array<Google::Apis::NetworkconnectivityV1::ProducerPscConfig>
The PSC configurations on producer side.
Corresponds to the JSON property producerPscConfigs
4085 4086 4087 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4085 def producer_psc_configs @producer_psc_configs end |
#service_class ⇒ String
The service class identifier this ServiceConnectionMap is for. The user of
ServiceConnectionMap create API needs to have networkconnectivity.
serviceClasses.use IAM permission for the service class.
Corresponds to the JSON property serviceClass
4092 4093 4094 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4092 def service_class @service_class end |
#service_class_uri ⇒ String
Output only. The service class uri this ServiceConnectionMap is for.
Corresponds to the JSON property serviceClassUri
4097 4098 4099 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4097 def service_class_uri @service_class_uri end |
#token ⇒ String
The token provided by the consumer. This token authenticates that the consumer
can create a connection within the specified project and network.
Corresponds to the JSON property token
4103 4104 4105 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4103 def token @token end |
#update_time ⇒ String
Output only. Time when the ServiceConnectionMap was updated.
Corresponds to the JSON property updateTime
4108 4109 4110 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4108 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4115 4116 4117 4118 4119 4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4115 def update!(**args) @consumer_psc_configs = args[:consumer_psc_configs] if args.key?(:consumer_psc_configs) @consumer_psc_connections = args[:consumer_psc_connections] if args.key?(:consumer_psc_connections) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @infrastructure = args[:infrastructure] if args.key?(:infrastructure) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @producer_psc_configs = args[:producer_psc_configs] if args.key?(:producer_psc_configs) @service_class = args[:service_class] if args.key?(:service_class) @service_class_uri = args[:service_class_uri] if args.key?(:service_class_uri) @token = args[:token] if args.key?(:token) @update_time = args[:update_time] if args.key?(:update_time) end |