Class: Google::Apis::NetworkconnectivityV1::ServiceConnectionMap

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

The ServiceConnectionMap resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceConnectionMap

Returns a new instance of ServiceConnectionMap.



3899
3900
3901
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3899

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumer_psc_configsArray<Google::Apis::NetworkconnectivityV1::ConsumerPscConfig>

The PSC configurations on consumer side. Corresponds to the JSON property consumerPscConfigs



3830
3831
3832
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3830

def consumer_psc_configs
  @consumer_psc_configs
end

#consumer_psc_connectionsArray<Google::Apis::NetworkconnectivityV1::ConsumerPscConnection>

Output only. PSC connection details on consumer side. Corresponds to the JSON property consumerPscConnections



3835
3836
3837
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3835

def consumer_psc_connections
  @consumer_psc_connections
end

#create_timeString

Output only. Time when the ServiceConnectionMap was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3840
3841
3842
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3840

def create_time
  @create_time
end

#descriptionString

A description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


3845
3846
3847
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3845

def description
  @description
end

#etagString

Optional. The etag is computed by the server, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


3851
3852
3853
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3851

def etag
  @etag
end

#infrastructureString

Output only. The infrastructure used for connections between consumers/ producers. Corresponds to the JSON property infrastructure

Returns:

  • (String)


3857
3858
3859
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3857

def infrastructure
  @infrastructure
end

#labelsHash<String,String>

User-defined labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3862
3863
3864
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3862

def labels
  @labels
end

#nameString

Immutable. The name of a ServiceConnectionMap. Format: projects/project/ locations/location/serviceConnectionMaps/service_connection_map See: https: //google.aip.dev/122#fields-representing-resource-names Corresponds to the JSON property name

Returns:

  • (String)


3869
3870
3871
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3869

def name
  @name
end

#producer_psc_configsArray<Google::Apis::NetworkconnectivityV1::ProducerPscConfig>

The PSC configurations on producer side. Corresponds to the JSON property producerPscConfigs



3874
3875
3876
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3874

def producer_psc_configs
  @producer_psc_configs
end

#service_classString

The service class identifier this ServiceConnectionMap is for. The user of ServiceConnectionMap create API needs to have networkconnectivity. serviceClasses.use IAM permission for the service class. Corresponds to the JSON property serviceClass

Returns:

  • (String)


3881
3882
3883
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3881

def service_class
  @service_class
end

#service_class_uriString

Output only. The service class uri this ServiceConnectionMap is for. Corresponds to the JSON property serviceClassUri

Returns:

  • (String)


3886
3887
3888
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3886

def service_class_uri
  @service_class_uri
end

#tokenString

The token provided by the consumer. This token authenticates that the consumer can create a connection within the specified project and network. Corresponds to the JSON property token

Returns:

  • (String)


3892
3893
3894
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3892

def token
  @token
end

#update_timeString

Output only. Time when the ServiceConnectionMap was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3897
3898
3899
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3897

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3904
3905
3906
3907
3908
3909
3910
3911
3912
3913
3914
3915
3916
3917
3918
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 3904

def update!(**args)
  @consumer_psc_configs = args[:consumer_psc_configs] if args.key?(:consumer_psc_configs)
  @consumer_psc_connections = args[:consumer_psc_connections] if args.key?(:consumer_psc_connections)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @infrastructure = args[:infrastructure] if args.key?(:infrastructure)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @producer_psc_configs = args[:producer_psc_configs] if args.key?(:producer_psc_configs)
  @service_class = args[:service_class] if args.key?(:service_class)
  @service_class_uri = args[:service_class_uri] if args.key?(:service_class_uri)
  @token = args[:token] if args.key?(:token)
  @update_time = args[:update_time] if args.key?(:update_time)
end