Class: Google::Apis::NetworkconnectivityV1::ServiceConnectionToken

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

The ServiceConnectionToken resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceConnectionToken

Returns a new instance of ServiceConnectionToken.



4484
4485
4486
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4484

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when the ServiceConnectionToken was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4438
4439
4440
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4438

def create_time
  @create_time
end

#descriptionString

A description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


4443
4444
4445
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4443

def description
  @description
end

#etagString

Optional. The etag is computed by the server, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


4449
4450
4451
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4449

def etag
  @etag
end

#expire_timeString

Output only. The time to which this token is valid. Corresponds to the JSON property expireTime

Returns:

  • (String)


4454
4455
4456
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4454

def expire_time
  @expire_time
end

#labelsHash<String,String>

User-defined labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4459
4460
4461
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4459

def labels
  @labels
end

#nameString

Immutable. The name of a ServiceConnectionToken. Format: projects/project/ locations/location/ServiceConnectionTokens/service_connection_token See: https://google.aip.dev/122#fields-representing-resource-names Corresponds to the JSON property name

Returns:

  • (String)


4466
4467
4468
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4466

def name
  @name
end

#networkString

The resource path of the network associated with this token. Example: projects/ projectNumOrId/global/networks/resourceId. Corresponds to the JSON property network

Returns:

  • (String)


4472
4473
4474
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4472

def network
  @network
end

#tokenString

Output only. The token generated by Automation. Corresponds to the JSON property token

Returns:

  • (String)


4477
4478
4479
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4477

def token
  @token
end

#update_timeString

Output only. Time when the ServiceConnectionToken was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4482
4483
4484
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4482

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4489
4490
4491
4492
4493
4494
4495
4496
4497
4498
4499
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4489

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @token = args[:token] if args.key?(:token)
  @update_time = args[:update_time] if args.key?(:update_time)
end