Class: Google::Apis::NetworkconnectivityV1::ServiceConnectionToken

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

The ServiceConnectionToken resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceConnectionToken

Returns a new instance of ServiceConnectionToken.



4280
4281
4282
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4280

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when the ServiceConnectionToken was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4234
4235
4236
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4234

def create_time
  @create_time
end

#descriptionString

A description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


4239
4240
4241
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4239

def description
  @description
end

#etagString

Optional. The etag is computed by the server, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


4245
4246
4247
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4245

def etag
  @etag
end

#expire_timeString

Output only. The time to which this token is valid. Corresponds to the JSON property expireTime

Returns:

  • (String)


4250
4251
4252
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4250

def expire_time
  @expire_time
end

#labelsHash<String,String>

User-defined labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4255
4256
4257
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4255

def labels
  @labels
end

#nameString

Immutable. The name of a ServiceConnectionToken. Format: projects/project/ locations/location/ServiceConnectionTokens/service_connection_token See: https://google.aip.dev/122#fields-representing-resource-names Corresponds to the JSON property name

Returns:

  • (String)


4262
4263
4264
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4262

def name
  @name
end

#networkString

The resource path of the network associated with this token. Example: projects/ projectNumOrId/global/networks/resourceId. Corresponds to the JSON property network

Returns:

  • (String)


4268
4269
4270
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4268

def network
  @network
end

#tokenString

Output only. The token generated by Automation. Corresponds to the JSON property token

Returns:

  • (String)


4273
4274
4275
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4273

def token
  @token
end

#update_timeString

Output only. Time when the ServiceConnectionToken was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4278
4279
4280
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4278

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4285
4286
4287
4288
4289
4290
4291
4292
4293
4294
4295
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4285

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @token = args[:token] if args.key?(:token)
  @update_time = args[:update_time] if args.key?(:update_time)
end