Class: Google::Apis::NetworkconnectivityV1::ServiceConnectionToken
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::ServiceConnectionToken
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
The ServiceConnectionToken resource.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
A description of this resource.
-
#etag ⇒ String
Optional.
-
#expire_time ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
User-defined labels.
-
#name ⇒ String
Immutable.
-
#network ⇒ String
The resource path of the network associated with this token.
-
#token ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceConnectionToken
constructor
A new instance of ServiceConnectionToken.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceConnectionToken
Returns a new instance of ServiceConnectionToken.
4069 4070 4071 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4069 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Time when the ServiceConnectionToken was created.
Corresponds to the JSON property createTime
4023 4024 4025 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4023 def create_time @create_time end |
#description ⇒ String
A description of this resource.
Corresponds to the JSON property description
4028 4029 4030 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4028 def description @description end |
#etag ⇒ String
Optional. The etag is computed by the server, and may be sent on update and
delete requests to ensure the client has an up-to-date value before proceeding.
Corresponds to the JSON property etag
4034 4035 4036 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4034 def etag @etag end |
#expire_time ⇒ String
Output only. The time to which this token is valid.
Corresponds to the JSON property expireTime
4039 4040 4041 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4039 def expire_time @expire_time end |
#labels ⇒ Hash<String,String>
User-defined labels.
Corresponds to the JSON property labels
4044 4045 4046 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4044 def labels @labels end |
#name ⇒ String
Immutable. The name of a ServiceConnectionToken. Format: projects/project/
locations/location/ServiceConnectionTokens/service_connection_token See:
https://google.aip.dev/122#fields-representing-resource-names
Corresponds to the JSON property name
4051 4052 4053 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4051 def name @name end |
#network ⇒ String
The resource path of the network associated with this token. Example: projects/
projectNumOrId/global/networks/resourceId.
Corresponds to the JSON property network
4057 4058 4059 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4057 def network @network end |
#token ⇒ String
Output only. The token generated by Automation.
Corresponds to the JSON property token
4062 4063 4064 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4062 def token @token end |
#update_time ⇒ String
Output only. Time when the ServiceConnectionToken was updated.
Corresponds to the JSON property updateTime
4067 4068 4069 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4067 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4074 4075 4076 4077 4078 4079 4080 4081 4082 4083 4084 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4074 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @expire_time = args[:expire_time] if args.key?(:expire_time) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @token = args[:token] if args.key?(:token) @update_time = args[:update_time] if args.key?(:update_time) end |