Class: Google::Apis::NetworkconnectivityV1::Spoke
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::Spoke
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
A Network Connectivity Center spoke represents one or more network connectivity resources. When you create a spoke, you associate it with a hub. You must also identify a value for exactly one of the following fields: * linked_vpn_tunnels * linked_interconnect_attachments * linked_router_appliance_instances * linked_vpc_network
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#etag ⇒ String
Optional.
-
#field_paths_pending_update ⇒ Array<String>
Optional.
-
#gateway ⇒ Google::Apis::NetworkconnectivityV1::Gateway
A gateway that can apply specialized traffic processing.
-
#group ⇒ String
Optional.
-
#hub ⇒ String
Immutable.
-
#labels ⇒ Hash<String,String>
Optional labels in key-value pair format.
-
#linked_interconnect_attachments ⇒ Google::Apis::NetworkconnectivityV1::LinkedInterconnectAttachments
A collection of VLAN attachment resources.
-
#linked_producer_vpc_network ⇒ Google::Apis::NetworkconnectivityV1::LinkedProducerVpcNetwork
Optional.
-
#linked_router_appliance_instances ⇒ Google::Apis::NetworkconnectivityV1::LinkedRouterApplianceInstances
A collection of router appliance instances.
-
#linked_vpc_network ⇒ Google::Apis::NetworkconnectivityV1::LinkedVpcNetwork
An existing VPC network.
-
#linked_vpn_tunnels ⇒ Google::Apis::NetworkconnectivityV1::LinkedVpnTunnels
A collection of Cloud VPN tunnel resources.
-
#name ⇒ String
Immutable.
-
#reasons ⇒ Array<Google::Apis::NetworkconnectivityV1::StateReason>
Output only.
-
#spoke_type ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#unique_id ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Spoke
constructor
A new instance of Spoke.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Spoke
Returns a new instance of Spoke.
4966 4967 4968 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4966 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time the spoke was created.
Corresponds to the JSON property createTime
4857 4858 4859 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4857 def create_time @create_time end |
#description ⇒ String
Optional. An optional description of the spoke.
Corresponds to the JSON property description
4862 4863 4864 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4862 def description @description end |
#etag ⇒ String
Optional. This checksum is computed by the server based on the value of other
fields, and may be sent on update and delete requests to ensure the client has
an up-to-date value before proceeding.
Corresponds to the JSON property etag
4869 4870 4871 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4869 def etag @etag end |
#field_paths_pending_update ⇒ Array<String>
Optional. The list of fields waiting for hub administrator's approval.
Corresponds to the JSON property fieldPathsPendingUpdate
4874 4875 4876 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4874 def field_paths_pending_update @field_paths_pending_update end |
#gateway ⇒ Google::Apis::NetworkconnectivityV1::Gateway
A gateway that can apply specialized traffic processing.
Corresponds to the JSON property gateway
4879 4880 4881 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4879 def gateway @gateway end |
#group ⇒ String
Optional. The name of the group that this spoke is associated with.
Corresponds to the JSON property group
4884 4885 4886 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4884 def group @group end |
#hub ⇒ String
Immutable. The name of the hub that this spoke is attached to.
Corresponds to the JSON property hub
4889 4890 4891 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4889 def hub @hub end |
#labels ⇒ Hash<String,String>
Optional labels in key-value pair format. For more information about labels,
see Requirements for labels.
Corresponds to the JSON property labels
4896 4897 4898 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4896 def labels @labels end |
#linked_interconnect_attachments ⇒ Google::Apis::NetworkconnectivityV1::LinkedInterconnectAttachments
A collection of VLAN attachment resources. These resources should be redundant
attachments that all advertise the same prefixes to Google Cloud.
Alternatively, in active/passive configurations, all attachments should be
capable of advertising the same prefixes.
Corresponds to the JSON property linkedInterconnectAttachments
4904 4905 4906 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4904 def @linked_interconnect_attachments end |
#linked_producer_vpc_network ⇒ Google::Apis::NetworkconnectivityV1::LinkedProducerVpcNetwork
Optional. The linked producer VPC that is associated with the spoke.
Corresponds to the JSON property linkedProducerVpcNetwork
4909 4910 4911 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4909 def linked_producer_vpc_network @linked_producer_vpc_network end |
#linked_router_appliance_instances ⇒ Google::Apis::NetworkconnectivityV1::LinkedRouterApplianceInstances
A collection of router appliance instances. If you configure multiple router
appliance instances to receive data from the same set of sites outside of
Google Cloud, we recommend that you associate those instances with the same
spoke.
Corresponds to the JSON property linkedRouterApplianceInstances
4917 4918 4919 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4917 def linked_router_appliance_instances @linked_router_appliance_instances end |
#linked_vpc_network ⇒ Google::Apis::NetworkconnectivityV1::LinkedVpcNetwork
An existing VPC network.
Corresponds to the JSON property linkedVpcNetwork
4922 4923 4924 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4922 def linked_vpc_network @linked_vpc_network end |
#linked_vpn_tunnels ⇒ Google::Apis::NetworkconnectivityV1::LinkedVpnTunnels
A collection of Cloud VPN tunnel resources. These resources should be
redundant HA VPN tunnels that all advertise the same prefixes to Google Cloud.
Alternatively, in a passive/active configuration, all tunnels should be
capable of advertising the same prefixes.
Corresponds to the JSON property linkedVpnTunnels
4930 4931 4932 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4930 def linked_vpn_tunnels @linked_vpn_tunnels end |
#name ⇒ String
Immutable. The name of the spoke. Spoke names must be unique. They use the
following form: projects/project_number/locations/region/spokes/spoke_id
Corresponds to the JSON property name
4937 4938 4939 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4937 def name @name end |
#reasons ⇒ Array<Google::Apis::NetworkconnectivityV1::StateReason>
Output only. The reasons for current state of the spoke.
Corresponds to the JSON property reasons
4942 4943 4944 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4942 def reasons @reasons end |
#spoke_type ⇒ String
Output only. The type of resource associated with the spoke.
Corresponds to the JSON property spokeType
4947 4948 4949 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4947 def spoke_type @spoke_type end |
#state ⇒ String
Output only. The current lifecycle state of this spoke.
Corresponds to the JSON property state
4952 4953 4954 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4952 def state @state end |
#unique_id ⇒ String
Output only. The Google-generated UUID for the spoke. This value is unique
across all spoke resources. If a spoke is deleted and another with the same
name is created, the new spoke is assigned a different unique_id.
Corresponds to the JSON property uniqueId
4959 4960 4961 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4959 def unique_id @unique_id end |
#update_time ⇒ String
Output only. The time the spoke was last updated.
Corresponds to the JSON property updateTime
4964 4965 4966 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4964 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4971 4972 4973 4974 4975 4976 4977 4978 4979 4980 4981 4982 4983 4984 4985 4986 4987 4988 4989 4990 4991 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4971 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @field_paths_pending_update = args[:field_paths_pending_update] if args.key?(:field_paths_pending_update) @gateway = args[:gateway] if args.key?(:gateway) @group = args[:group] if args.key?(:group) @hub = args[:hub] if args.key?(:hub) @labels = args[:labels] if args.key?(:labels) @linked_interconnect_attachments = args[:linked_interconnect_attachments] if args.key?(:linked_interconnect_attachments) @linked_producer_vpc_network = args[:linked_producer_vpc_network] if args.key?(:linked_producer_vpc_network) @linked_router_appliance_instances = args[:linked_router_appliance_instances] if args.key?(:linked_router_appliance_instances) @linked_vpc_network = args[:linked_vpc_network] if args.key?(:linked_vpc_network) @linked_vpn_tunnels = args[:linked_vpn_tunnels] if args.key?(:linked_vpn_tunnels) @name = args[:name] if args.key?(:name) @reasons = args[:reasons] if args.key?(:reasons) @spoke_type = args[:spoke_type] if args.key?(:spoke_type) @state = args[:state] if args.key?(:state) @unique_id = args[:unique_id] if args.key?(:unique_id) @update_time = args[:update_time] if args.key?(:update_time) end |