Class: Google::Apis::NetworkconnectivityV1::Spoke

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

A Network Connectivity Center spoke represents one or more network connectivity resources. When you create a spoke, you associate it with a hub. You must also identify a value for exactly one of the following fields: * linked_vpn_tunnels * linked_interconnect_attachments * linked_router_appliance_instances * linked_vpc_network

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Spoke

Returns a new instance of Spoke.



4255
4256
4257
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4255

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time the spoke was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4151
4152
4153
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4151

def create_time
  @create_time
end

#descriptionString

Optional. An optional description of the spoke. Corresponds to the JSON property description

Returns:

  • (String)


4156
4157
4158
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4156

def description
  @description
end

#etagString

Optional. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. Corresponds to the JSON property etag

Returns:

  • (String)


4163
4164
4165
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4163

def etag
  @etag
end

#field_paths_pending_updateArray<String>

Optional. The list of fields waiting for hub administration's approval. Corresponds to the JSON property fieldPathsPendingUpdate

Returns:

  • (Array<String>)


4168
4169
4170
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4168

def field_paths_pending_update
  @field_paths_pending_update
end

#groupString

Optional. The name of the group that this spoke is associated with. Corresponds to the JSON property group

Returns:

  • (String)


4173
4174
4175
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4173

def group
  @group
end

#hubString

Immutable. The name of the hub that this spoke is attached to. Corresponds to the JSON property hub

Returns:

  • (String)


4178
4179
4180
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4178

def hub
  @hub
end

#labelsHash<String,String>

Optional labels in key-value pair format. For more information about labels, see Requirements for labels. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4185
4186
4187
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4185

def labels
  @labels
end

#linked_interconnect_attachmentsGoogle::Apis::NetworkconnectivityV1::LinkedInterconnectAttachments

A collection of VLAN attachment resources. These resources should be redundant attachments that all advertise the same prefixes to Google Cloud. Alternatively, in active/passive configurations, all attachments should be capable of advertising the same prefixes. Corresponds to the JSON property linkedInterconnectAttachments



4193
4194
4195
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4193

def linked_interconnect_attachments
  @linked_interconnect_attachments
end

#linked_producer_vpc_networkGoogle::Apis::NetworkconnectivityV1::LinkedProducerVpcNetwork

Optional. The linked producer VPC that is associated with the spoke. Corresponds to the JSON property linkedProducerVpcNetwork



4198
4199
4200
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4198

def linked_producer_vpc_network
  @linked_producer_vpc_network
end

#linked_router_appliance_instancesGoogle::Apis::NetworkconnectivityV1::LinkedRouterApplianceInstances

A collection of router appliance instances. If you configure multiple router appliance instances to receive data from the same set of sites outside of Google Cloud, we recommend that you associate those instances with the same spoke. Corresponds to the JSON property linkedRouterApplianceInstances



4206
4207
4208
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4206

def linked_router_appliance_instances
  @linked_router_appliance_instances
end

#linked_vpc_networkGoogle::Apis::NetworkconnectivityV1::LinkedVpcNetwork

An existing VPC network. Corresponds to the JSON property linkedVpcNetwork



4211
4212
4213
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4211

def linked_vpc_network
  @linked_vpc_network
end

#linked_vpn_tunnelsGoogle::Apis::NetworkconnectivityV1::LinkedVpnTunnels

A collection of Cloud VPN tunnel resources. These resources should be redundant HA VPN tunnels that all advertise the same prefixes to Google Cloud. Alternatively, in a passive/active configuration, all tunnels should be capable of advertising the same prefixes. Corresponds to the JSON property linkedVpnTunnels



4219
4220
4221
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4219

def linked_vpn_tunnels
  @linked_vpn_tunnels
end

#nameString

Immutable. The name of the spoke. Spoke names must be unique. They use the following form: projects/project_number/locations/region/spokes/spoke_id Corresponds to the JSON property name

Returns:

  • (String)


4226
4227
4228
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4226

def name
  @name
end

#reasonsArray<Google::Apis::NetworkconnectivityV1::StateReason>

Output only. The reasons for current state of the spoke. Corresponds to the JSON property reasons



4231
4232
4233
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4231

def reasons
  @reasons
end

#spoke_typeString

Output only. The type of resource associated with the spoke. Corresponds to the JSON property spokeType

Returns:

  • (String)


4236
4237
4238
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4236

def spoke_type
  @spoke_type
end

#stateString

Output only. The current lifecycle state of this spoke. Corresponds to the JSON property state

Returns:

  • (String)


4241
4242
4243
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4241

def state
  @state
end

#unique_idString

Output only. The Google-generated UUID for the spoke. This value is unique across all spoke resources. If a spoke is deleted and another with the same name is created, the new spoke is assigned a different unique_id. Corresponds to the JSON property uniqueId

Returns:

  • (String)


4248
4249
4250
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4248

def unique_id
  @unique_id
end

#update_timeString

Output only. The time the spoke was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4253
4254
4255
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4253

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4260
4261
4262
4263
4264
4265
4266
4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
4278
4279
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4260

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @field_paths_pending_update = args[:field_paths_pending_update] if args.key?(:field_paths_pending_update)
  @group = args[:group] if args.key?(:group)
  @hub = args[:hub] if args.key?(:hub)
  @labels = args[:labels] if args.key?(:labels)
  @linked_interconnect_attachments = args[:linked_interconnect_attachments] if args.key?(:linked_interconnect_attachments)
  @linked_producer_vpc_network = args[:linked_producer_vpc_network] if args.key?(:linked_producer_vpc_network)
  @linked_router_appliance_instances = args[:linked_router_appliance_instances] if args.key?(:linked_router_appliance_instances)
  @linked_vpc_network = args[:linked_vpc_network] if args.key?(:linked_vpc_network)
  @linked_vpn_tunnels = args[:linked_vpn_tunnels] if args.key?(:linked_vpn_tunnels)
  @name = args[:name] if args.key?(:name)
  @reasons = args[:reasons] if args.key?(:reasons)
  @spoke_type = args[:spoke_type] if args.key?(:spoke_type)
  @state = args[:state] if args.key?(:state)
  @unique_id = args[:unique_id] if args.key?(:unique_id)
  @update_time = args[:update_time] if args.key?(:update_time)
end