Class: Google::Apis::NetworkconnectivityV1::SpokeStateCount
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::SpokeStateCount
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
The number of spokes that are in a particular state and associated with a given hub.
Instance Attribute Summary collapse
-
#count ⇒ Fixnum
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SpokeStateCount
constructor
A new instance of SpokeStateCount.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SpokeStateCount
Returns a new instance of SpokeStateCount.
4901 4902 4903 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4901 def initialize(**args) update!(**args) end |
Instance Attribute Details
#count ⇒ Fixnum
Output only. The total number of spokes that are in this state and associated
with a given hub.
Corresponds to the JSON property count
4894 4895 4896 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4894 def count @count end |
#state ⇒ String
Output only. The state of the spokes.
Corresponds to the JSON property state
4899 4900 4901 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4899 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4906 4907 4908 4909 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4906 def update!(**args) @count = args[:count] if args.key?(:count) @state = args[:state] if args.key?(:state) end |