Class: Google::Apis::NetworkconnectivityV1::SpokeStateCount

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

The number of spokes that are in a particular state and associated with a given hub.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SpokeStateCount

Returns a new instance of SpokeStateCount.



4509
4510
4511
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4509

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

Output only. The total number of spokes that are in this state and associated with a given hub. Corresponds to the JSON property count

Returns:

  • (Fixnum)


4502
4503
4504
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4502

def count
  @count
end

#stateString

Output only. The state of the spokes. Corresponds to the JSON property state

Returns:

  • (String)


4507
4508
4509
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4507

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4514
4515
4516
4517
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4514

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @state = args[:state] if args.key?(:state)
end