Class: Google::Apis::NetworkconnectivityV1::SpokeStateCount

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

The number of spokes that are in a particular state and associated with a given hub.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SpokeStateCount

Returns a new instance of SpokeStateCount.



4298
4299
4300
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4298

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

Output only. The total number of spokes that are in this state and associated with a given hub. Corresponds to the JSON property count

Returns:

  • (Fixnum)


4291
4292
4293
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4291

def count
  @count
end

#stateString

Output only. The state of the spokes. Corresponds to the JSON property state

Returns:

  • (String)


4296
4297
4298
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4296

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4303
4304
4305
4306
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4303

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @state = args[:state] if args.key?(:state)
end