Class: Google::Apis::NetworkconnectivityV1::SpokeStateReasonCount

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

The number of spokes in the hub that are inactive for this reason.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SpokeStateReasonCount

Returns a new instance of SpokeStateReasonCount.



4324
4325
4326
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4324

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

Output only. The total number of spokes that are inactive for a particular reason and associated with a given hub. Corresponds to the JSON property count

Returns:

  • (Fixnum)


4317
4318
4319
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4317

def count
  @count
end

#state_reason_codeString

Output only. The reason that a spoke is inactive. Corresponds to the JSON property stateReasonCode

Returns:

  • (String)


4322
4323
4324
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4322

def state_reason_code
  @state_reason_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4329
4330
4331
4332
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4329

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @state_reason_code = args[:state_reason_code] if args.key?(:state_reason_code)
end