Class: Google::Apis::NetworkconnectivityV1::StateMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

The state and activation time details of the resource state.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StateMetadata

Returns a new instance of StateMetadata.



5019
5020
5021
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5019

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#effective_timeString

Output only. Accompanies only the transient states, which include ADDING, DELETING, and SUSPENDING, to denote the time until which the transient state of the resource will be effective. For instance, if the state is ADDING , this field shows the time when the resource state transitions to ACTIVE. Corresponds to the JSON property effectiveTime

Returns:

  • (String)


5012
5013
5014
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5012

def effective_time
  @effective_time
end

#stateString

Output only. The state of the resource. Corresponds to the JSON property state

Returns:

  • (String)


5017
5018
5019
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5017

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5024
5025
5026
5027
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5024

def update!(**args)
  @effective_time = args[:effective_time] if args.key?(:effective_time)
  @state = args[:state] if args.key?(:state)
end