Class: Google::Apis::NetworkconnectivityV1::StateMetadata
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::StateMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
The state and activation time details of the resource state.
Instance Attribute Summary collapse
-
#effective_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StateMetadata
constructor
A new instance of StateMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StateMetadata
Returns a new instance of StateMetadata.
4416 4417 4418 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4416 def initialize(**args) update!(**args) end |
Instance Attribute Details
#effective_time ⇒ String
Output only. Accompanies only the transient states, which include ADDING,
DELETING, and SUSPENDING, to denote the time until which the transient
state of the resource will be effective. For instance, if the state is ADDING
, this field shows the time when the resource state transitions to ACTIVE.
Corresponds to the JSON property effectiveTime
4409 4410 4411 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4409 def effective_time @effective_time end |
#state ⇒ String
Output only. The state of the resource.
Corresponds to the JSON property state
4414 4415 4416 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4414 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4421 4422 4423 4424 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4421 def update!(**args) @effective_time = args[:effective_time] if args.key?(:effective_time) @state = args[:state] if args.key?(:state) end |