Class: Google::Apis::NetworkconnectivityV1::StateReason

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

The reason for the current state of the spoke.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StateReason

Returns a new instance of StateReason.



4657
4658
4659
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4657

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

The code associated with this reason. Corresponds to the JSON property code

Returns:

  • (String)


4645
4646
4647
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4645

def code
  @code
end

#messageString

Human-readable details about this reason. Corresponds to the JSON property message

Returns:

  • (String)


4650
4651
4652
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4650

def message
  @message
end

#user_detailsString

Additional information provided by the user in the RejectSpoke call. Corresponds to the JSON property userDetails

Returns:

  • (String)


4655
4656
4657
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4655

def user_details
  @user_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4662
4663
4664
4665
4666
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4662

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @message = args[:message] if args.key?(:message)
  @user_details = args[:user_details] if args.key?(:user_details)
end