Class: Google::Apis::NetworkconnectivityV1::StateReason
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::StateReason
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
The reason for the current state of the spoke.
Instance Attribute Summary collapse
-
#code ⇒ String
The code associated with this reason.
-
#message ⇒ String
Human-readable details about this reason.
-
#user_details ⇒ String
Additional information provided by the user in the RejectSpoke call.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StateReason
constructor
A new instance of StateReason.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StateReason
Returns a new instance of StateReason.
4657 4658 4659 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4657 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
The code associated with this reason.
Corresponds to the JSON property code
4645 4646 4647 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4645 def code @code end |
#message ⇒ String
Human-readable details about this reason.
Corresponds to the JSON property message
4650 4651 4652 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4650 def @message end |
#user_details ⇒ String
Additional information provided by the user in the RejectSpoke call.
Corresponds to the JSON property userDetails
4655 4656 4657 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4655 def user_details @user_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4662 4663 4664 4665 4666 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4662 def update!(**args) @code = args[:code] if args.key?(:code) @message = args[:message] if args.key?(:message) @user_details = args[:user_details] if args.key?(:user_details) end |