Class: Google::Apis::NetworkconnectivityV1::StateReason
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::StateReason
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
The reason a spoke is inactive.
Instance Attribute Summary collapse
-
#code ⇒ String
The code associated with this reason.
-
#message ⇒ String
Human-readable details about this reason.
-
#user_details ⇒ String
Additional information provided by the user in the RejectSpoke call.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StateReason
constructor
A new instance of StateReason.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StateReason
Returns a new instance of StateReason.
4446 4447 4448 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4446 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
The code associated with this reason.
Corresponds to the JSON property code
4434 4435 4436 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4434 def code @code end |
#message ⇒ String
Human-readable details about this reason.
Corresponds to the JSON property message
4439 4440 4441 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4439 def @message end |
#user_details ⇒ String
Additional information provided by the user in the RejectSpoke call.
Corresponds to the JSON property userDetails
4444 4445 4446 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4444 def user_details @user_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4451 4452 4453 4454 4455 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4451 def update!(**args) @code = args[:code] if args.key?(:code) @message = args[:message] if args.key?(:message) @user_details = args[:user_details] if args.key?(:user_details) end |