Class: Google::Apis::NetworkconnectivityV1::StateTimeline

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

The timeline of the pending states for a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StateTimeline

Returns a new instance of StateTimeline.



4467
4468
4469
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4467

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#statesArray<Google::Apis::NetworkconnectivityV1::StateMetadata>

Output only. The state and activation time details of the resource state. Corresponds to the JSON property states



4465
4466
4467
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4465

def states
  @states
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4472
4473
4474
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4472

def update!(**args)
  @states = args[:states] if args.key?(:states)
end