Class: Google::Apis::NetworkconnectivityV1::Transport

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb

Overview

Message describing Transport object.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Transport

Returns a new instance of Transport.



5219
5220
5221
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5219

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertised_routesArray<String>

Optional. List of IP Prefixes that will be advertised to the remote provider. Both IPv4 and IPv6 addresses are supported. Corresponds to the JSON property advertisedRoutes

Returns:

  • (Array<String>)


5128
5129
5130
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5128

def advertised_routes
  @advertised_routes
end

#bandwidthString

Optional. Bandwidth of the Transport. This must be one of the supported bandwidths for the remote profile, and must be set when no activation key is being provided. Corresponds to the JSON property bandwidth

Returns:

  • (String)


5135
5136
5137
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5135

def bandwidth
  @bandwidth
end

#create_timeString

Output only. Create time stamp. Corresponds to the JSON property createTime

Returns:

  • (String)


5140
5141
5142
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5140

def create_time
  @create_time
end

#descriptionString

Optional. Description of the Transport. Corresponds to the JSON property description

Returns:

  • (String)


5145
5146
5147
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5145

def description
  @description
end

#generated_activation_keyString

Output only. Google-generated activation key. This is only output if the selected profile supports an OUTPUT key flow. Inputting this to the provider is only valid while the resource is in a PENDING_KEY state. Once the provider has accepted the key, the resource will move to the CONFIGURING state. Corresponds to the JSON property generatedActivationKey

Returns:

  • (String)


5153
5154
5155
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5153

def generated_activation_key
  @generated_activation_key
end

#labelsHash<String,String>

Optional. Labels as key value pairs. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


5158
5159
5160
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5158

def labels
  @labels
end

#mtu_limitFixnum

Output only. The maximum transmission unit (MTU) of a packet that can be sent over this transport. Corresponds to the JSON property mtuLimit

Returns:

  • (Fixnum)


5164
5165
5166
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5164

def mtu_limit
  @mtu_limit
end

#nameString

Identifier. Name of the resource. Corresponds to the JSON property name

Returns:

  • (String)


5169
5170
5171
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5169

def name
  @name
end

#networkString

Optional. Immutable. Resource URI of the Network that will be peered with this Transport. This field must be provided during resource creation and cannot be changed. Corresponds to the JSON property network

Returns:

  • (String)


5176
5177
5178
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5176

def network
  @network
end

#peering_networkString

Output only. VPC Network URI that was created for the VPC Peering connection to the provided network. If VPC Peering is disconnected, this can be used to re-establish. Corresponds to the JSON property peeringNetwork

Returns:

  • (String)


5183
5184
5185
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5183

def peering_network
  @peering_network
end

#provided_activation_keyString

Optional. Immutable. Key used for establishing a connection with the remote transport. This key can only be provided if the profile supports an INPUT key flow and the resource is in the PENDING_KEY state. Corresponds to the JSON property providedActivationKey

Returns:

  • (String)


5190
5191
5192
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5190

def provided_activation_key
  @provided_activation_key
end

#remote_account_idString

Optional. Immutable. The user supplied account id for the CSP associated with the remote profile. Corresponds to the JSON property remoteAccountId

Returns:

  • (String)


5196
5197
5198
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5196

def 
  @remote_account_id
end

#remote_profileString

Optional. Immutable. Name of the remoteTransportProfile that this Transport is connecting to. Corresponds to the JSON property remoteProfile

Returns:

  • (String)


5202
5203
5204
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5202

def remote_profile
  @remote_profile
end

#stack_typeString

Optional. IP version stack for the established connectivity. Corresponds to the JSON property stackType

Returns:

  • (String)


5207
5208
5209
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5207

def stack_type
  @stack_type
end

#stateString

Output only. State of the underlying connectivity. Corresponds to the JSON property state

Returns:

  • (String)


5212
5213
5214
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5212

def state
  @state
end

#update_timeString

Output only. Update time stamp. Corresponds to the JSON property updateTime

Returns:

  • (String)


5217
5218
5219
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5217

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5224
5225
5226
5227
5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5224

def update!(**args)
  @advertised_routes = args[:advertised_routes] if args.key?(:advertised_routes)
  @bandwidth = args[:bandwidth] if args.key?(:bandwidth)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @generated_activation_key = args[:generated_activation_key] if args.key?(:generated_activation_key)
  @labels = args[:labels] if args.key?(:labels)
  @mtu_limit = args[:mtu_limit] if args.key?(:mtu_limit)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @peering_network = args[:peering_network] if args.key?(:peering_network)
  @provided_activation_key = args[:provided_activation_key] if args.key?(:provided_activation_key)
  @remote_account_id = args[:remote_account_id] if args.key?(:remote_account_id)
  @remote_profile = args[:remote_profile] if args.key?(:remote_profile)
  @stack_type = args[:stack_type] if args.key?(:stack_type)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end