Class: Google::Apis::NetworkconnectivityV1::Transport
- Inherits:
-
Object
- Object
- Google::Apis::NetworkconnectivityV1::Transport
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/networkconnectivity_v1/classes.rb,
lib/google/apis/networkconnectivity_v1/representations.rb,
lib/google/apis/networkconnectivity_v1/representations.rb
Overview
Message describing Transport object.
Instance Attribute Summary collapse
-
#advertised_routes ⇒ Array<String>
Optional.
-
#bandwidth ⇒ String
Optional.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#generated_activation_key ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#mtu_limit ⇒ Fixnum
Output only.
-
#name ⇒ String
Identifier.
-
#network ⇒ String
Optional.
-
#peering_network ⇒ String
Output only.
-
#provided_activation_key ⇒ String
Optional.
-
#remote_account_id ⇒ String
Optional.
-
#remote_profile ⇒ String
Optional.
-
#stack_type ⇒ String
Optional.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Transport
constructor
A new instance of Transport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Transport
Returns a new instance of Transport.
5031 5032 5033 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5031 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertised_routes ⇒ Array<String>
Optional. List of IP Prefixes that will be advertised to the remote provider.
Both IPv4 and IPv6 addresses are supported.
Corresponds to the JSON property advertisedRoutes
4940 4941 4942 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4940 def advertised_routes @advertised_routes end |
#bandwidth ⇒ String
Optional. Bandwidth of the Transport. This must be one of the supported
bandwidths for the remote profile, and must be set when no activation key is
being provided.
Corresponds to the JSON property bandwidth
4947 4948 4949 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4947 def bandwidth @bandwidth end |
#create_time ⇒ String
Output only. Create time stamp.
Corresponds to the JSON property createTime
4952 4953 4954 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4952 def create_time @create_time end |
#description ⇒ String
Optional. Description of the Transport.
Corresponds to the JSON property description
4957 4958 4959 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4957 def description @description end |
#generated_activation_key ⇒ String
Output only. Google-generated activation key. This is only output if the
selected profile supports an OUTPUT key flow. Inputting this to the provider
is only valid while the resource is in a PENDING_KEY state. Once the provider
has accepted the key, the resource will move to the CONFIGURING state.
Corresponds to the JSON property generatedActivationKey
4965 4966 4967 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4965 def generated_activation_key @generated_activation_key end |
#labels ⇒ Hash<String,String>
Optional. Labels as key value pairs.
Corresponds to the JSON property labels
4970 4971 4972 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4970 def labels @labels end |
#mtu_limit ⇒ Fixnum
Output only. The maximum transmission unit (MTU) of a packet that can be sent
over this transport.
Corresponds to the JSON property mtuLimit
4976 4977 4978 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4976 def mtu_limit @mtu_limit end |
#name ⇒ String
Identifier. Name of the resource.
Corresponds to the JSON property name
4981 4982 4983 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4981 def name @name end |
#network ⇒ String
Optional. Immutable. Resource URI of the Network that will be peered with this
Transport. This field must be provided during resource creation and cannot be
changed.
Corresponds to the JSON property network
4988 4989 4990 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4988 def network @network end |
#peering_network ⇒ String
Output only. VPC Network URI that was created for the VPC Peering connection
to the provided network. If VPC Peering is disconnected, this can be used to
re-establish.
Corresponds to the JSON property peeringNetwork
4995 4996 4997 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 4995 def peering_network @peering_network end |
#provided_activation_key ⇒ String
Optional. Immutable. Key used for establishing a connection with the remote
transport. This key can only be provided if the profile supports an INPUT key
flow and the resource is in the PENDING_KEY state.
Corresponds to the JSON property providedActivationKey
5002 5003 5004 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5002 def provided_activation_key @provided_activation_key end |
#remote_account_id ⇒ String
Optional. Immutable. The user supplied account id for the CSP associated with
the remote profile.
Corresponds to the JSON property remoteAccountId
5008 5009 5010 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5008 def remote_account_id @remote_account_id end |
#remote_profile ⇒ String
Optional. Immutable. Name of the remoteTransportProfile that this Transport is
connecting to.
Corresponds to the JSON property remoteProfile
5014 5015 5016 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5014 def remote_profile @remote_profile end |
#stack_type ⇒ String
Optional. IP version stack for the established connectivity.
Corresponds to the JSON property stackType
5019 5020 5021 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5019 def stack_type @stack_type end |
#state ⇒ String
Output only. State of the underlying connectivity.
Corresponds to the JSON property state
5024 5025 5026 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5024 def state @state end |
#update_time ⇒ String
Output only. Update time stamp.
Corresponds to the JSON property updateTime
5029 5030 5031 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5029 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5036 5037 5038 5039 5040 5041 5042 5043 5044 5045 5046 5047 5048 5049 5050 5051 5052 5053 |
# File 'lib/google/apis/networkconnectivity_v1/classes.rb', line 5036 def update!(**args) @advertised_routes = args[:advertised_routes] if args.key?(:advertised_routes) @bandwidth = args[:bandwidth] if args.key?(:bandwidth) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @generated_activation_key = args[:generated_activation_key] if args.key?(:generated_activation_key) @labels = args[:labels] if args.key?(:labels) @mtu_limit = args[:mtu_limit] if args.key?(:mtu_limit) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @peering_network = args[:peering_network] if args.key?(:peering_network) @provided_activation_key = args[:provided_activation_key] if args.key?(:provided_activation_key) @remote_account_id = args[:remote_account_id] if args.key?(:remote_account_id) @remote_profile = args[:remote_profile] if args.key?(:remote_profile) @stack_type = args[:stack_type] if args.key?(:stack_type) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |